@@ -31,6 +31,10 @@
 #include <string.h>
 #include <ctype.h>
 
+#include <glib/gmem.h>
+#include <glib/gstrfuncs.h>
+#include <glib/gutils.h>
+
 static void filter_destroy (GMimeFilter *filter);
 static GMimeFilter *filter_copy (GMimeFilter *filter);
 static void filter_filter (GMimeFilter *filter, char *in, size_t len, 
@@ -109,12 +113,12 @@ check_size (GMimeFilter *filter, char *outptr, char **outend, size_t len)
 }
 
 /* 1 = non-email-address chars: "()<>@,;:\\\"/[]`'|\n\t "  */
-/* 2 = non-url chars:           "()<>,;\\\"[]`'|\n\t "   */
+/* 2 = non-url chars:           "()<>;\\\"[]`'|\n\t "   */
 /* 3 = trailing url garbage:    ",.!?;:>)]}\\`'-_|\n\t "  */
 static unsigned short special_chars[256] = {
 	 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0,
 	 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-	 7, 4, 3, 0, 0, 0, 0, 7, 3, 7, 0, 0, 7, 4, 4, 1,
+	 7, 4, 3, 0, 0, 0, 0, 7, 3, 7, 0, 0, 4, 4, 4, 1,
 	 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 7, 3, 0, 7, 4,
 	 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
 	 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 7, 3, 0, 4,
@@ -136,7 +140,7 @@ static unsigned short special_chars[256] = {
 #define IS_GARBAGE    (1 << 2)
 
 #define NON_EMAIL_CHARS         "()<>@,;:\\\"/[]`'|\n\t "
-#define NON_URL_CHARS           "()<>,;\\\"[]`'|\n\t "
+#define NON_URL_CHARS           "()<>;\\\"[]`'|\n\t "
 #define TRAILING_URL_GARBAGE    ",.!?;:>)}\\`'-_|\n\t "
 
 #define is_addr_char(c) (isprint ((int) c) && !(special_chars[(unsigned char) c] & IS_NON_ADDR))
