@@ -47,7 +47,7 @@ static void message_set_header (GMimeObject *object, const char *header, const c
 static const char *message_get_header (GMimeObject *object, const char *header);
 static void message_remove_header (GMimeObject *object, const char *header);
 static char *message_get_headers (GMimeObject *object);
-static ssize_t message_write_to_stream (GMimeObject *object, GMimeStream *stream);
+static gssize message_write_to_stream (GMimeObject *object, GMimeStream *stream);
 
 static void message_set_sender (GMimeMessage *message, const char *sender);
 static void message_set_reply_to (GMimeMessage *message, const char *reply_to);
@@ -384,11 +384,11 @@ message_get_headers (GMimeObject *object)
 	return str;
 }
 
-static ssize_t
+static gssize
 message_write_to_stream (GMimeObject *object, GMimeStream *stream)
 {
 	GMimeMessage *message = (GMimeMessage *) object;
-	ssize_t nwritten, total = 0;
+	gssize nwritten, total = 0;
 	
 	/* write the content headers */
 	nwritten = g_mime_header_write_to_stream (object->headers, stream);
@@ -904,7 +904,7 @@ g_mime_message_set_mime_part (GMimeMessage *message, GMimeObject *mime_part)
  *
  * Returns -1 on fail.
  **/
-ssize_t
+gssize
 g_mime_message_write_to_stream (GMimeMessage *message, GMimeStream *stream)
 {
 	g_return_val_if_fail (GMIME_IS_MESSAGE (message), -1);
