@@ -1394,7 +1394,7 @@ rfc2047_encode_phrase_get_words (const unsigned char *in)
 		newinptr = g_utf8_next_char (inptr);
 		c = g_utf8_get_char (inptr);
 		if (newinptr == NULL || !g_unichar_validate (c)) {
-			w(g_warning ("Invalid UTF-8 sequence encountered"));
+			d(g_warning ("Invalid UTF-8 sequence encountered"));
 			inptr++;
 			continue;
 		}
