@@ -34,6 +34,10 @@
 #include "gmime-utils.h"
 #include "gmime-iconv-utils.h"
 
+#include <glib/gmem.h>
+#include <glib/gmessages.h>
+#include <glib/gstring.h>
+#include <glib/gstrfuncs.h>
 
 #define w(x) x
 #define d(x)
