@@ -24,7 +24,6 @@
 #include <gtk/gtk.h>
 
 #include <pan/base/article.h>
-#include <pan/base/fnmatch.h>
 #include <pan/base/pan-i18n.h>
 #include <pan/base/pan-glib-extensions.h>
 
@@ -57,21 +56,34 @@ typedef struct
 	gboolean unread_only;
 	gboolean case_sensitive;
 
-	const char *author;
-	const char *subject;
-	const char *message_id;
+	GPatternSpec * author;
+	GPatternSpec * subject;
+	GPatternSpec * msgid;
 } 
 header_compare_data;
 
+static gboolean
+test_phrase (GPatternSpec * pattern, const char * phrase, gboolean case_sensitive)
+{
+	gboolean retval;
+	char * down = NULL;
+
+	if (!case_sensitive)
+		phrase = down = g_utf8_strdown (phrase, -1);
+	retval = g_pattern_match (pattern, strlen(phrase), phrase, NULL);
+	if (down != NULL)
+		g_free (down);
+
+	return retval;
+}
+
 /**
  * Return 0 if equal
  */
 static gboolean
-compare_article (const Article* article,
-                 const header_compare_data* header )
+compare_article (const Article              * article,
+                 const header_compare_data  * header)
 {
-	int flags = header->case_sensitive ? 0 : PAN_CASEFOLD;
-
 	/* if it ain't an article, it ain't a match */
 	if (!article)
 		return -1;
@@ -81,72 +93,72 @@ compare_article (const Article* article,
 		return -1;
 
 	/* make sure the author (if user specified one) matches.. */
-	if (header->author && (!article->author_real || fnmatch(header->author,article->author_real,flags))
-	                   && (!article->author_addr || fnmatch(header->author,article->author_addr,flags)) )
-		return -1;
+	if (header->author != NULL) {
+		char buf[512] = { '\0' };
+		article_get_author_str (article, buf, sizeof(buf));
+		if (!test_phrase (header->author, buf, header->case_sensitive))
+			return -1;
+	}
 
 	/* make sure the subject (if user specified one) matches.. */
-	if (header->subject && fnmatch(header->subject,article_get_subject(article),flags))
+	if (header->subject && !test_phrase (header->subject, article_get_subject(article), header->case_sensitive))
 		return -1;
 
 	/* make sure the message-id (if user specified one) matches.. */
-	if (header->message_id && fnmatch(header->message_id,article_get_message_id(article),flags))
+	if (header->msgid && !test_phrase (header->msgid, article_get_message_id(article), header->case_sensitive))
 		return -1;
 
 	/* hooray, a match */
 	return 0;
 }
 
+static GPatternSpec*
+create_pattern (const char * pch, gboolean case_sensitive)
+{
+	GPatternSpec * retval = NULL;
+
+	if (pch != NULL)
+	{
+		char * tmp = g_strdup (pch);
+		g_strstrip (tmp);
+		if (is_nonempty_string (tmp))
+		{
+			/* wrap the key in wildcards to make it a substring search...
+			   unless there are already wildcards present, indicating the
+			   user already knows what he wants */
+			if (!strchr (tmp, '*'))
+				replace_gstr (&tmp, g_strdup_printf ("*%s*", tmp));
+			if (!case_sensitive)
+				replace_gstr (&tmp, g_utf8_strdown (tmp, -1));
+			retval = g_pattern_spec_new (tmp);
+		}
+
+		g_free (tmp);
+	}
+
+	return retval;
+}
+
 static void
-find_article (const char* author,
-              const char* subject,
-              const char* message_id,
-              gboolean case_sensitive,
-              gboolean unread_only,
-              gboolean reverse)
+find_article (const char   * author,
+              const char   * subject,
+              const char   * message_id,
+              gboolean       case_sensitive,
+              gboolean       unread_only,
+              gboolean       reverse)
 {
-	char * author_tmp;
-	char * subject_tmp;
-	char * message_id_tmp;
 	GtkCTreeNode * sel;
 	GtkCTreeNode * tmp;
 	GtkCTree* tree = GTK_CTREE(Pan.article_ctree);
 	header_compare_data header_data;
 
-	/* wrap the key in wildcards to make it a substring search...
-	   unless there are already wildcards present, indicating the
-	   user already knows what he wants */
-	subject_tmp = NULL;
-	if (subject != NULL) {
-		if (strchr(subject,'*'))
-			subject_tmp = g_strdup (subject);
-		else
-			subject_tmp = g_strdup_printf ("*%s*", subject);
-	}
-
-	author_tmp = NULL;
-	if (author != NULL) {
-		if (strchr(author,'*'))
-			author_tmp = g_strdup (author);
-		else
-			author_tmp = g_strdup_printf ("*%s*", author);
-	}
-
-	message_id_tmp = NULL;
-	if (message_id != NULL) {
-		if (strchr(message_id,'*'))
-			message_id_tmp = g_strdup (message_id);
-		else
-			message_id_tmp = g_strdup_printf ("*%s*", message_id);
-	}
-
 	/* sanity checks */
 	g_return_if_fail (articlelist_get_group()!=NULL);
 
 	/* set up search function struct */
-	header_data.author = author_tmp;
-	header_data.subject = subject_tmp;
-	header_data.message_id = message_id_tmp;
+	header_data.author = create_pattern (author, case_sensitive);
+	header_data.subject = create_pattern (subject, case_sensitive);
+	header_data.msgid = create_pattern (message_id, case_sensitive);
 	header_data.unread_only = unread_only;
 	header_data.case_sensitive = case_sensitive;
 
@@ -189,8 +201,12 @@ find_article (const char* author,
 		articlelist_set_selected_nodes_nolock (&tmp, 1);
 
 	/* cleanup */
-	g_free (author_tmp);
-	g_free (subject_tmp);
+	if (header_data.author)
+		g_pattern_spec_free (header_data.author);
+	if (header_data.subject)
+		g_pattern_spec_free (header_data.subject);
+	if (header_data.msgid)
+		g_pattern_spec_free (header_data.msgid);
 }
 
 static char * find_article__author = NULL;
