@@ -48,7 +48,7 @@ static GtkWidget * _filter_phrase_entry = NULL;
  */
 
 static char * _filter_phrase = NULL;
-static FilterPhraseState _filter_phrase_state = FILTER_PHRASE_SUBJECT;
+static PhraseKeyType _phrase_key_type = PHRASE_KEY_SUBJECT;
 static Filter* _filter = NULL;
 static Filter* _raw_filter = NULL;
 
@@ -85,10 +85,10 @@ update_filter_phrase (void)
 	return changed;
 }
 
-static FilterPhraseState
-get_filter_phrase_state (void)
+static PhraseKeyType
+get_phrase_key_type (void)
 {
-	return _filter_phrase_state;
+	return _phrase_key_type;
 }
 
 
@@ -96,9 +96,9 @@ static Filter*
 merge_filter_with_phrase (Filter * filter)
 {
 	Filter * retval = NULL;
-	char * phrase_str = get_filter_phrase ();
+	char * key = get_filter_phrase ();
 
-	if (is_nonempty_string (phrase_str))
+	if (is_nonempty_string (key))
 	{
 		Filter * phrase_filter = filter_phrase_new ();
 		Filter * children[2];
@@ -107,9 +107,9 @@ merge_filter_with_phrase (Filter * filter)
 		children[1] = phrase_filter;
 
 		filter_phrase_set (FILTER_PHRASE(phrase_filter),
-		                   get_filter_phrase_state(),
-		                   phrase_str,
-		                   FALSE);
+		                   PHRASE_MATCH_CONTAINS,
+		                   get_phrase_key_type(),
+		                   key);
 
 		retval = filter_aggregate_new ();
 		filter_aggregate_add (FILTER_AGGREGATE(retval), children, G_N_ELEMENTS(children));
@@ -120,7 +120,7 @@ merge_filter_with_phrase (Filter * filter)
 	else retval = filter;
 
 	/* cleanup */
-	g_free (phrase_str);
+	g_free (key);
 	return retval;
 }
 
@@ -199,13 +199,13 @@ article_phrase_activate_cb (void)
 }
 
 static void
-set_filter_mode_cb (GtkMenuItem * item, gpointer data)
+set_key_type_cb (GtkMenuItem * item, gpointer data)
 {
-	FilterPhraseState tmp = GPOINTER_TO_INT(data);
+	PhraseKeyType key_type = GPOINTER_TO_INT(data);
 	
-	if (tmp != _filter_phrase_state)
+	if (key_type != _phrase_key_type)
 	{
-		_filter_phrase_state = tmp;
+		_phrase_key_type = key_type;
 		rebuild_filters ();
 		fire_user_changed_filter ();
 	}
@@ -254,8 +254,8 @@ entry_focus_out_cb (GtkWidget * w, GdkEventKey * event, gpointer unused) {
 
 typedef struct
 {
-	const gchar * name;
-	FilterPhraseState state;
+	const char * name;
+	PhraseKeyType state;
 }
 ArticleToolbarOptionMenuStruct;
 
@@ -303,9 +303,9 @@ article_toolbar_new (void)
 		int index = 0;
 		int i;
 		ArticleToolbarOptionMenuStruct foo[] = {
-			{NULL, FILTER_PHRASE_SUBJECT},
-			{NULL, FILTER_PHRASE_AUTHOR},
-			{NULL, FILTER_PHRASE_MESSAGE_ID}
+			{NULL, PHRASE_KEY_SUBJECT},
+			{NULL, PHRASE_KEY_AUTHOR},
+			{NULL, PHRASE_KEY_MESSAGE_ID}
 		};
 		const int row_qty = G_N_ELEMENTS (foo);
 		foo[0].name = _("Subject");
@@ -314,7 +314,7 @@ article_toolbar_new (void)
 		for (i=0; i<row_qty; ++i) {
 			GtkWidget * item = gtk_menu_item_new_with_label (foo[i].name);
 			gtk_signal_connect (GTK_OBJECT(item), "activate",
-			                    GTK_SIGNAL_FUNC(set_filter_mode_cb), GINT_TO_POINTER(foo[i].state));
+			                    GTK_SIGNAL_FUNC(set_key_type_cb), GINT_TO_POINTER(foo[i].state));
 			gtk_menu_append (GTK_MENU(menu), item);
 			gtk_widget_show (item);
 		}
