@@ -152,6 +152,8 @@ static GtkStyle * read_style[2]                  = { NULL, NULL };
 static GtkStyle * watched_style[2]               = { NULL, NULL };
 static GtkStyle * killfile_style[2]              = { NULL, NULL };
 
+GdkColor read_color;
+GdkColor unread_color;
 GdkColor killfile_color;
 GdkColor watched_color;
 
@@ -262,7 +264,7 @@ articlelist_get_selected_articles_nolock (void)
 	GList * list;
 	debug_enter ("articlelist_get_selected_articles_nolock");
 
-	retval = g_ptr_array_sized_new (64);
+	retval = g_ptr_array_sized_new (256);
 	list = _article_clist->selection;
 	for (; list!=NULL; list=list->next)
 	{
@@ -276,6 +278,51 @@ articlelist_get_selected_articles_nolock (void)
 	return retval;
 }
 
+GPtrArray*
+articlelist_get_active_articles_nolock (void)
+{
+	guint i;
+	GPtrArray * nodes;
+	GPtrArray * retval;
+	GPtrArray * parents;
+	debug_enter ("articlelist_get_active_articles_nolock");
+
+	parents = g_ptr_array_sized_new (128);
+	retval = g_ptr_array_sized_new (128);
+
+	/* add collapsed && !leaves to "parents", all others to "retval" */
+	nodes = articlelist_get_selected_nodes_nolock ();
+	for (i=0; i<nodes->len; ++i)
+	{
+		GtkCTreeNode * n = GTK_CTREE_NODE (g_ptr_array_index (nodes, i));
+		Article * a = articlelist_get_article_from_node(n);
+		GtkCTreeRow * row;
+
+		if (a == NULL)
+			continue;
+
+		row = GTK_CTREE_ROW (n);
+		if (row->is_leaf || row->expanded)
+			g_ptr_array_add (retval, a);
+		else
+			g_ptr_array_add (parents, a);
+	}
+
+	/* if any parents, get the entire subthreads and add to retval */
+	if (parents->len) {
+		GPtrArray * tmp = article_get_unique_threads (parents, GET_SUBTHREAD);
+		pan_g_ptr_array_append (retval, tmp->pdata, tmp->len);
+		g_ptr_array_free (tmp, TRUE);
+	}
+
+	/* cleanup */
+	g_ptr_array_free (parents, TRUE);
+	g_ptr_array_free (nodes, TRUE);
+
+	debug_exit ("articlelist_get_active_articles_nolock");
+	return retval;
+}
+
 guint
 articlelist_get_selected_count_nolock (void)
 {
@@ -610,7 +657,7 @@ articlelist_read_article (Article * article)
 
 	if (article == NULL)
 	{
-		g_string_assign (cur_message_id, "");
+		g_string_truncate (cur_message_id, 0);
 		text_set_from_identifiers (NULL, NULL, NULL, NULL, 0);
 	}
 	else
@@ -660,9 +707,26 @@ articlelist_read_article (Article * article)
 void
 articlelist_read_selected (void)
 {
-	GtkCTreeNode * node = articlelist_get_selected_node ();
-	Article * article = node==NULL ? NULL : articlelist_get_article_from_node (node);
-	articlelist_read_article (article);
+	GPtrArray * sel;
+	GtkCTreeNode * first_node;
+	Article  * first_article;
+	debug_enter ("articlelist_read_selected");
+
+	/* read the first one */
+	first_node = articlelist_get_selected_node ();
+	first_article = first_node==NULL ? NULL : articlelist_get_article_from_node (first_node);
+	articlelist_read_article (first_article);
+
+	/* download all the others */
+       	sel = articlelist_get_active_articles_nolock ();
+	if (sel->len)
+		g_ptr_array_remove (sel, first_article);
+	if (sel->len)
+		queue_add (TASK(task_bodies_new_from_articles ((const Article**)sel->pdata, sel->len)));
+
+	/* cleanup */
+	g_ptr_array_free (sel, TRUE);
+	debug_exit ("articlelist_read_selected");
 }
 
 void
@@ -1102,13 +1166,16 @@ remove_article_nolock (const Article * article)
 		GSList *l=NULL, *l2;
 		GtkCTreeNode * child;
 
-		/* make a list of children */
+		/* make a list of children.  the list has to be reversed
+		 * to preserve the children's order when we move them
+		 * up next to GTK_CTREE_NODE(node)->sibling -- as each
+		 * node is moved, the ones previously moved get bumped down.
+		 */
 		child = GTK_CTREE_ROW(node)->children;
 		while (child != NULL) {
 			l = g_slist_prepend (l, child);
 			child = GTK_CTREE_ROW(child)->sibling;
 		}
-		l = g_slist_reverse (l);
 
 		/* for each child, reparent to the granparent */
 		for (l2=l; l2!=NULL; l2=l2->next) {
@@ -1180,10 +1247,29 @@ articles_removed_mainthread (gpointer p)
 		pan_unlock ();
 		g_static_mutex_unlock (&article_ctree_lock);
 
-		/* remove them from our array */
-		for (i=0; i<articles->len; ++i) {
-			const Article * needle = ARTICLE(g_ptr_array_index(articles,i));
-			g_ptr_array_remove (my_articles, (gpointer)needle);
+		/* remove them from our array.  for small numbers g_ptr_array_remove() is
+		 * okay, but for huge groups we're better off just rebuilding my_articles
+		 * than to memmove thousands of pointers thousands of times */
+		if (articles->len < 5) {
+			/* low overhead, good if user just hit 'delete' key on an article */
+			for (i=0; i<articles->len; ++i)
+				g_ptr_array_remove (my_articles, g_ptr_array_index (articles, i));
+		} else {
+			/* more overhead, but scales better */
+			GHashTable * del_hash = g_hash_table_new (g_str_hash, g_str_equal);
+			GPtrArray * survivors = g_ptr_array_sized_new (my_articles->len);
+			for (i=0; i<articles->len; ++i) {
+				Article * a = ARTICLE (g_ptr_array_index (articles, i));
+				g_hash_table_insert (del_hash, (gpointer)article_get_message_id(a), a);
+			}
+			for (i=0; i<my_articles->len; ++i) {
+				Article * a = ARTICLE (g_ptr_array_index (my_articles, i));
+				if (g_hash_table_lookup (del_hash, article_get_message_id (a)) == NULL)
+					g_ptr_array_add (survivors, a);
+			}
+			pan_g_ptr_array_assign (my_articles, survivors->pdata, survivors->len);
+			g_ptr_array_free (survivors, TRUE);
+			g_hash_table_destroy (del_hash);
 		}
 	}
 
@@ -1233,7 +1319,7 @@ articlelist_selected_mark_unread_nolock (void)
 	GPtrArray * sel;
 	debug_enter ("articlelist_selected_mark_unread_nolock");
 
-	sel = articlelist_get_selected_articles_nolock ();
+	sel = articlelist_get_active_articles_nolock ();
 	if (sel->len != 0)
 		articlelist_mark_articles_nolock (sel, FALSE);
 	g_ptr_array_free (sel, TRUE);
@@ -1246,7 +1332,7 @@ articlelist_selected_mark_read_nolock (void)
 	GPtrArray * sel;
 	debug_enter ("articlelist_selected_mark_read_nolock");
 
-       	sel = articlelist_get_selected_articles_nolock ();
+       	sel = articlelist_get_active_articles_nolock ();
 	if (sel->len != 0)
 		articlelist_mark_articles_nolock (sel, TRUE);
 	g_ptr_array_free (sel, TRUE);
@@ -1255,57 +1341,6 @@ articlelist_selected_mark_read_nolock (void)
 }
 
 
-/**
- * http://bugzilla.gnome.org/show_bug.cgi?id=90388
- * ``I think that selecting the thread is more common than selecting the top
- *   article. That's why I think that any operation should operate just like in
- *   Agent i.e. on the entire thread if it is closed and on the top article
- *   otherwise.''
- */
-static GPtrArray*
-get_flag_articles (void)
-{
-	guint i;
-	GPtrArray * nodes;
-	GPtrArray * retval;
-	GPtrArray * parents;
-	debug_enter ("get_flag_articles");
-
-	parents = g_ptr_array_sized_new (128);
-	retval = g_ptr_array_sized_new (128);
-
-	/* add collapsed && !leaves to "parents", all others to "retval" */
-	nodes = articlelist_get_selected_nodes_nolock ();
-	for (i=0; i<nodes->len; ++i)
-	{
-		GtkCTreeNode * n = GTK_CTREE_NODE (g_ptr_array_index (nodes, i));
-		Article * a = articlelist_get_article_from_node(n);
-		GtkCTreeRow * row;
-
-		if (a == NULL)
-			continue;
-
-		row = GTK_CTREE_ROW (n);
-		if (row->is_leaf || row->expanded)
-			g_ptr_array_add (retval, a);
-		else
-			g_ptr_array_add (parents, a);
-	}
-
-	/* if any parents, get the entire subthreads and add to retval */
-	if (parents->len) {
-		GPtrArray * tmp = article_get_unique_threads (parents, GET_SUBTHREAD);
-		pan_g_ptr_array_append (retval, tmp->pdata, tmp->len);
-		g_ptr_array_free (tmp, TRUE);
-	}
-
-	/* cleanup */
-	g_ptr_array_free (parents, TRUE);
-	g_ptr_array_free (nodes, TRUE);
-
-	debug_exit ("get_flag_articles");
-	return retval;
-}
 
 void
 articlelist_selected_unflag_for_dl_nolock (void)
@@ -1313,7 +1348,7 @@ articlelist_selected_unflag_for_dl_nolock (void)
 	GPtrArray * s;
 	debug_enter ("articlelist_selected_unflag_for_dl_nolock");
 
-       	s = get_flag_articles ();
+	s = articlelist_get_active_articles_nolock ();
 	if (s->len) {
 		flagset_remove_articles ((const Article **)s->pdata, s->len);
 		messageidset_add_articles (messages_needing_refresh, (const Article **)s->pdata, s->len);
@@ -1329,7 +1364,7 @@ articlelist_selected_flag_for_dl_nolock (void)
 	GPtrArray * s;
 	debug_enter ("articlelist_selected_unflag_for_dl_nolock");
 
-       	s = get_flag_articles ();
+	s = articlelist_get_active_articles_nolock ();
 	if (s->len) {
 		flagset_add_articles ((const Article **)s->pdata, s->len);
 		messageidset_add_articles (messages_needing_refresh, (const Article **)s->pdata, s->len);
@@ -1418,7 +1453,7 @@ articlelist_selected_download_nolock (void)
 	g_return_if_fail (my_group != NULL);
 
 	/* add the task */
-       	sel = articlelist_get_selected_articles_nolock ();
+       	sel = articlelist_get_active_articles_nolock ();
 	if (sel->len)
 		queue_add (TASK(task_bodies_new_from_articles ((const Article**)sel->pdata, sel->len)));
 
@@ -1587,30 +1622,10 @@ articlelist_set_node_style_nolock (GtkCTreeNode   * node,
 	if (rebuild_style)
 	{
 		int i;
-		double lo;
-		double hi;
-		GdkColor bg;
-		GdkColor fg;
-		GdkColor unread_color;
-		GdkColor read_color;
 		GtkStyle * s = gtk_widget_get_style (GTK_WIDGET(Pan.window));
 
 		rebuild_style = FALSE;
 
-		/* read color should be mostly the background color with a little foreground */
-		bg = s->bg[0];
-		fg = unread_color = s->fg[0];
-		hi = MAX (fg.red, bg.red);
-		lo = MIN (fg.red, bg.red);
-		read_color.red = (guint16)(lo + ((lo==bg.red ? 0.2 : 0.8) * (hi-lo)));
-		hi = MAX (fg.green, bg.green);
-		lo = MIN (fg.green, bg.green);
-		read_color.green = (guint16)(lo + ((lo==bg.green ? 0.2 : 0.8) * (hi-lo)));
-		hi = MAX (fg.blue, bg.blue);
-		lo = MIN (fg.blue, bg.blue);
-		read_color.blue = (guint16)(lo + ((lo==bg.blue ? 0.2 : 0.8) * (hi-lo)));
-		gdk_color_alloc (cmap, &read_color);
-
 		/* build the styles */
 		for (i=0; i<2; ++i)
 		{
@@ -2137,7 +2152,7 @@ articlelist_selection_changed_cb (gpointer call_object,
 {
 	GPtrArray * articles;
 	Article * a = NULL;
-	const gboolean activate = !_modifiers && _mb==1 && _button_click_count >= (single_click_selects ? 2 : 1);
+	const gboolean activate = !_modifiers && _mb==1 && _button_click_count >= (single_click_selects_headers ? 2 : 1);
 	debug_enter ("articlelist_selection_changed_cb");
 
 	/* did user activate this article? */
@@ -2191,6 +2206,7 @@ articlelist_key_press (GtkWidget      * widget,
                        GdkEventKey    * event,
                        gpointer         data)
 {
+	GtkCTreeNode * node;
 	gboolean retval = FALSE;
 
 	switch (event->keyval)
@@ -2206,6 +2222,22 @@ articlelist_key_press (GtkWidget      * widget,
 			articlelist_expand_selected_threads ();
 			retval = TRUE;
 			break;
+
+		case GDK_Home:
+			/* go to the first thread */
+			node = gtk_ctree_node_nth (_article_ctree, 1);
+			if (node != NULL)
+				select_node_nolock (node);
+			break;
+
+		case GDK_End:
+			/* go to the last thread */
+			node = gtk_ctree_node_nth (_article_ctree, 0);
+			if (node != NULL)
+				node = gtk_ctree_last (_article_ctree, node);
+			if (node != NULL)
+				select_node_nolock (node);
+			break;
 	}
 
 	return retval;
@@ -2633,7 +2665,7 @@ copy_to_folder_cb (gpointer user_data, int index, GtkWidget * w)
 	folder = GROUP (g_ptr_array_index (folders, index));
 
 	/* get selected articles */
-       	articles = articlelist_get_selected_articles_nolock ();
+       	articles = articlelist_get_active_articles_nolock ();
 
 	/* copy them */
 	article_copy_articles_to_folder (folder,
