@@ -31,6 +31,8 @@
 
 #include <pan/filters/filter.h>
 
+extern GdkColor read_color;
+extern GdkColor unread_color;
 extern GdkColor killfile_color;
 extern GdkColor watched_color;
 
@@ -51,6 +53,18 @@ Article*       articlelist_get_selected_article_nolock  (void);
 GPtrArray*     articlelist_get_selected_articles_nolock (void);
 guint          articlelist_get_selected_count_nolock    (void);
 
+/**
+ * "active" articles is the set of articles that an operation should
+ * usually be performed on.  It's all the selected articles, plus if
+ * any of the selected articles have collapsed subthreads, then also
+ * the articles in those collapsed subthread.
+ *
+ * For example, that way a `delete articles'  or `flag articles'
+ * function would know to also operate on the collapsed subthreads
+ * even though they're not selected.
+ */
+GPtrArray*     articlelist_get_active_articles_nolock   (void);
+
 /**
 ***  Stepping Through the Articles
 **/
