@@ -688,7 +688,7 @@ acache_set_message (const char    * key,
 
 	/* find out where to write the message */
 	if (acache_get_filename (filename, sizeof(filename), apath->path, message_id))
-		fp = fopen (filename, "w+");
+		fp = fopen (filename, "wb+");
 
 	if (fp != NULL)
 	{
@@ -746,7 +746,7 @@ acache_get_message_file_stream (const AcacheEntry * entry)
 	{
 		FILE * fp;
 		errno = 0;
-		fp = fopen (filename, "r");
+		fp = fopen (filename, "rb");
 		if (!fp)
 			log_add_va (LOG_ERROR, _("Error opening file \"%s\": %s"), filename, g_strerror(errno));
 		else
