@@ -44,17 +44,15 @@ int            acache_expire              (void);
 
 int            acache_expire_all          (void);
 
-void           acache_expire_messages     (const char   ** message_id,
-                                           int             message_id_qty);
+void           acache_expire_messages     (const char            * key,
+                                           const char           ** message_id,
+                                           int                     message_id_qty);
 /**
 ***  Path
 **/
 
 void           acache_add_folder          (const char            * key);
 
-void           acache_add_path            (const char            * key,
-                                           const char            * path);
-
 typedef void (*AcachePathForeachFunc)     (GMimeMessage          * message,
                                            gpointer                user_data);
 
@@ -66,14 +64,16 @@ void           acache_path_foreach        (const char            * key,
 ***  Messages
 **/
 
-gboolean       acache_has_message         (const char            * message_id);
-
-GMimeMessage*  acache_get_message         (MessageIdentifier    ** mids,
-	                                   int                     mid_qty);
-
 extern const char * ACACHE_DEFAULT_KEY;
 
-void           acache_set_message         (const char            * key,
+gboolean       acache_has_message         (const char            * path_key,
+                                           const char            * message_id);
+
+GMimeMessage*  acache_get_message         (const char            * path_key,
+                                           MessageIdentifier    ** mids,
+	                                   int                     mid_qty);
+
+void           acache_set_message         (const char            * path_key,
                                            const char            * message_id,
                                            const char            * text,
                                            guint                   message_len);
@@ -82,19 +82,29 @@ void           acache_set_message         (const char            * key,
 ***  Refcount
 **/
 
-void           acache_checkout            (MessageIdentifier    ** messages,
+void           acache_checkout            (const char            * path_key,
+                                           MessageIdentifier    ** messages,
                                            int                     message_qty);
 
-void           acache_checkin             (MessageIdentifier    ** messages,
+void           acache_checkin             (const char            * path_key,
+                                           MessageIdentifier    ** messages,
                                            int                     message_qty);
 
 /**
 ***  Callbacks
 **/
 
-extern PanCallback* acache_bodies_added_callback;
- 
-extern PanCallback* acache_bodies_removed_callback;
+/**
+ * @call_obj: const char ** message_ids
+ * @call_arg: int: message_id qty
+ */
+extern PanCallback* acache_get_bodies_added_callback (void);
+
+/**
+ * @call_obj: const char ** message_ids
+ * @call_arg: int: message_id qty
+ */
+extern PanCallback* acache_get_bodies_removed_callback (void);
 
 
 #endif /* __ACACHE_H__ */
