@@ -18,6 +18,8 @@
  */
 
 #include <pan/base/argset.h>
+#include <pan/base/log.h>
+#include <pan/base/pan-i18n.h>
 
 ArgSet*
 argset_new (void) {
@@ -88,7 +90,11 @@ argset_free (ArgSet * argset) {
 }
 
 void
-run_in_worker_thread (WorkerFunc func, gpointer arg)
-{
-	g_thread_create (func, arg, FALSE, NULL);
+run_in_worker_thread (WorkerFunc func, gpointer arg) {
+	GError * err = NULL;
+	g_thread_create (func, arg, FALSE, &err);
+	if (err != NULL) {
+		log_add_va (LOG_ERROR, _("Unable to create thread: %s"), err->message);
+		g_error_free (err);
+	}
 }
