@@ -78,14 +78,14 @@ normalize_subject (char * buf, const Article * a)
 	if (!_inited) {
 		int i;
 		for (i=0; i<=UCHAR_MAX; ++i) {
-			guchar uch = (guchar)i;
+			const guchar uch = (guchar)i;
 			_keep_chars[i] = isalnum(uch) || isdigit(uch) || isspace(uch);
 		}
 		_inited = TRUE;
 	}
 
 	/* skip the leading noise */
-	while (*in && !isalnum(*in))
+	while (*in && isspace(*in))
 		++in;
 
 	while (*in)
@@ -105,7 +105,7 @@ normalize_subject (char * buf, const Article * a)
 
 		/* strip out junk that breaks sorting */
 		if (_keep_chars[*in])
-			*out++ = tolower(*in);
+			*out++ = (char) tolower(*in);
 
 		++in;
 	}
@@ -199,8 +199,8 @@ static int
 compare_pN_to_pN_by_subject (const void * va, const void * vb)
 {
 	register int value;
-	const register Norm * a = (const Norm *)va;
-	const register Norm * b = (const Norm *)vb;
+	register const Norm * a = (const Norm *)va;
+	register const Norm * b = (const Norm *)vb;
 
 	/* subject is the primary key, of course... */
 	if ((value = *a->subject - *b->subject))
@@ -230,40 +230,25 @@ compare_pN_to_pN_by_subject (const void * va, const void * vb)
 static int
 compare_ppA_to_ppA_by_linecount (const void* va, const void* vb)
 {
-        const register Article * a = *(const Article**)va;
-        const register Article * b = *(const Article**)vb;
+        register const Article * a = *(const Article**)va;
+        register const Article * b = *(const Article**)vb;
 	return article_get_combined_linecount(a) - article_get_combined_linecount(b);
 }
 
 static int
 compare_ppA_to_ppA_by_action (const void * va, const void * vb)
 {
-	const register Article * a = *(const Article **)va;
-	const register Article * b = *(const Article **)vb;
+	register const Article * a = *(const Article **)va;
+	register const Article * b = *(const Article **)vb;
 	int ia, ib;
 
-#if 0
-	ia = article
-	ia = article_flag_on (a, STATE_SAVE_QUEUED) ? 1 : 0;
-	ib = article_flag_on (b, STATE_SAVE_QUEUED) ? 1 : 0;
-	if (ia != ib)
-		return ib - ia;
-
-	ia = article_flag_on (a, STATE_DOWNLOAD_FLAGGED) ? 1 : 0;
-	ib = article_flag_on (b, STATE_DOWNLOAD_FLAGGED) ? 1 : 0;
-	if (ia != ib)
-		return ib - ia;
-#else
-#warning fixme -- how to sort on queue?
-#endif
-
 	ia = article_flag_on (a, STATE_DECODED) ? 1 : 0;
 	ib = article_flag_on (b, STATE_DECODED) ? 1 : 0;
 	if (ia != ib)
 		return ib - ia;
 
-	ia = acache_has_message (a->message_id) ? 1 : 0;
-	ib = acache_has_message (b->message_id) ? 1 : 0;
+	ia = acache_has_message (group_get_acache_key(a->group), a->message_id) ? 1 : 0;
+	ib = acache_has_message (group_get_acache_key(b->group), b->message_id) ? 1 : 0;
 	if (ia != ib)
 		return ib - ia;
 
@@ -273,8 +258,8 @@ compare_ppA_to_ppA_by_action (const void * va, const void * vb)
 static int
 compare_ppA_to_ppA_by_read (const void * va, const void * vb)
 {
-	const register Article * a = *(const Article **)va;
-	const register Article * b = *(const Article **)vb;
+	register const Article * a = *(const Article **)va;
+	register const Article * b = *(const Article **)vb;
 	const gboolean a_is_read = article_is_read (a);
 	const gboolean b_is_read = article_is_read (b);
 	const gboolean a_is_new = article_is_new (a);
@@ -452,10 +437,14 @@ is_child_of (const Article * child,
 }
 
 static guint
-article_get_part_state (Article * a)
+article_root_get_part_state (const Article * a)
 {
 	guint retval;
 
+	/* sanity clause */
+	g_return_val_if_fail (a!=NULL, 0u);
+	g_return_val_if_fail (a->parent==NULL, 0u);
+
 	/* not a multipart */
 	if (a->parts<1)
 		retval = 0;
@@ -465,7 +454,7 @@ article_get_part_state (Article * a)
 		retval = 0;
 
 	/* incomplete multipart */
-	else if (a->part>1 && a->parent==NULL)
+	else if (a->part>1)
 		retval = STATE_MULTIPART_SOME;
 
 	/* someone's posted a followup to a multipart */
@@ -486,7 +475,7 @@ article_get_part_state (Article * a)
 }
 
 static void
-set_children_part_state (Article * a, guint state)
+set_children_part_state (Article * a, const guint state)
 {
 	gint part;
 	GSList * l;
@@ -686,7 +675,10 @@ thread_articles (GPtrArray    * articles)
 		a->threads = g_slist_sort (a->threads, compare_pA_to_pA_by_part);
 	}
 
-	/* calculate new/unread child counts */
+	/**
+	***  Calculate new/unread child counts
+	**/
+
 	for (i=0; i!=qty; ++i)
 	{
 		Article * a;
@@ -702,12 +694,18 @@ thread_articles (GPtrArray    * articles)
 				++a->new_children;
 	}
 
-	/* check multipart count */
+	/**
+	***  Calculate multipart states
+	**/
+
 	for (i=0; i!=articles->len; ++i) {
 		Article * a = ARTICLE(g_ptr_array_index(articles,i));
 		a->state &= ~(STATE_MULTIPART_ALL|STATE_MULTIPART_SOME);
+	}
+	for (i=0; i!=articles->len; ++i) {
+		Article * a = ARTICLE(g_ptr_array_index(articles,i));
 		if (a->parent == NULL)
-			set_children_part_state (a, article_get_part_state(a));
+			set_children_part_state (a, article_root_get_part_state(a));
 	}
 
 	/* cleanup */
