@@ -84,6 +84,7 @@ article_constructor (Article * article, Group * group)
 	article->part = (gint16)0;
 	article->parts = (gint16)0;
 	article->score = (gint16)0;
+	article->byte_qty = (gulong)0;
 	article->linecount = (guint16)0;
 	article->state = (guint16)0;
 	article->unread_children = (guint16)0;
@@ -608,14 +609,14 @@ article_get_unique_threads (const GPtrArray    * articles,
 
 	/* get the thread for each article passed in */
 	thread = g_ptr_array_sized_new (128);
-	all = g_hash_table_new (g_str_hash, g_str_equal);
+	all = g_hash_table_new (g_direct_hash, g_direct_equal);
 	for (i=0; i<articles->len; ++i)
 	{
 		int j;
 		Article * a = ARTICLE(g_ptr_array_index(articles,i));
 
 		/* if we already have the article, then we have its thread, so skip */
-		if (g_hash_table_lookup (all, article_get_message_id(a)) != NULL)
+		if (g_hash_table_lookup (all, a) != NULL)
 			continue;
 
 		/* get the thread associated with sel... */
@@ -626,20 +627,14 @@ article_get_unique_threads (const GPtrArray    * articles,
 			article_get_entire_thread (a, thread);
 
 		/* add the articles into "all" hash */
-		for (j=0; j<thread->len; ++j)
-		{
-			Article * b = ARTICLE(g_ptr_array_index(thread,j));
-			const char * message_id = article_get_message_id (b);
-
-			if (g_hash_table_lookup (all, message_id) == NULL)
-			{
-				g_hash_table_insert (all, (gpointer)article_get_message_id(b), (gpointer)b);
-				g_ptr_array_add (retval, b);
-			}
+		for (j=0; j<thread->len; ++j) {
+			Article * b = ARTICLE (g_ptr_array_index(thread,j));
+			g_hash_table_insert (all, b, b);
 		}
 	}
 
 	/* cleanup */
+	pan_hash_to_ptr_array (all, retval);
 	g_hash_table_destroy (all);
 	g_ptr_array_free (thread, TRUE);
 	debug_exit ("article_get_unique_threads");
@@ -767,11 +762,14 @@ xref_foreach (const char         * xref_string,
 			const char * delimit = g_strstr_len (run_str, run_len, ":");
 			if (delimit != NULL)
 			{
+				char group_name[1024];
+				const int group_name_len = MIN (delimit-run_str, sizeof(group_name)-1);
 				const gulong number = strtoul (delimit+1, NULL, 10);
 				Group * group = NULL;
-				char * group_name;
 
-				pan_strndup_alloca (group_name, run_str, delimit-run_str);
+				memcpy (group_name, run_str, group_name_len);
+				group_name[group_name_len] = '\0';
+
 				group = server_get_named_group_in_type (server, group_name, set);
 				if (group!=NULL && group!=skip)
 					(*func)(server, group, number, user_data);
@@ -860,11 +858,30 @@ article_format_author_str (const char * author_addr,
 {
 	const gboolean have_addr = is_nonempty_string (author_addr);
 	const gboolean have_name = is_nonempty_string (author_real);
+	const int name_len = have_name ? strlen (author_real) : 0;
+	const int addr_len = have_addr ? strlen (author_addr) : 0;
 
 	*buf = '\0';
 
 	if (have_addr && have_name)
-		g_snprintf (buf, bufsize, "\"%s\" <%s>", author_real, author_addr);
+	{
+		if (name_len + addr_len + 6 > bufsize)
+			g_snprintf (buf, bufsize, "\"%s\" <%s>", author_real, author_addr);
+		else
+		{
+			char * pch = buf;
+			*pch++ = '"';
+			memcpy (pch, author_real, name_len);
+			pch += name_len;
+			*pch++ = '"';
+			*pch++ = ' ';
+			*pch++ = '<';
+			memcpy (pch, author_addr, addr_len);
+			pch += addr_len;
+			*pch++ = '>';
+			*pch++ = '\0';
+		}
+	}
 	else if (have_addr)
 		g_strlcpy (buf, author_addr, bufsize);
 	else if (have_name)
