@@ -1,13 +1,11 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Author: Charles Kerr <charles@rebelbase.com>
- *
- * Copyright (C) 2000, 2001  Pan Development Team <pan@rebelbase.com>
+ * Pan - A Newsreader for Gtk+
+ * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation; version 2 of the License.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,7 +15,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * 
  */
 
 #ifndef __FILE_HEADERS_H__
@@ -26,6 +23,8 @@
 #include <stdio.h>
 #include <glib.h>
 
+#include <gmime/memchunk.h>
+
 #include <pan/base/group.h>
 #include <pan/base/status-item.h>
 
@@ -35,6 +34,8 @@ void     file_headers_load             (Group * group, StatusItem * status);
 
 void     file_headers_save             (Group * group, StatusItem * status);
 
-long     get_string_offset             (GHashTable *, GMemChunk *, const gchar *, FILE *, glong *);
+void     file_headers_save_noref       (Group * group, StatusItem * status);
+
+long     get_string_offset             (GHashTable *, MemChunk *, const gchar *, FILE *, glong *);
 
 #endif
