@@ -498,7 +498,7 @@ gnksa_split_from (const gchar  * from,
 		  gint         * addrtype,
 		  gboolean       strict)
 {
-	gchar * begin;
+	gchar * begin, * addr_buf_rangle;
 	gchar * end;
 	gchar * work;
 	gchar * lparen;
@@ -528,8 +528,8 @@ gnksa_split_from (const gchar  * from,
 
 		/* copy route address from inside the <> brackets */
 		g_strlcpy (addr_buf, begin+1, addr_max);
-		*strchr(addr_buf, '>') = '\0';
-
+		if (((addr_buf_rangle = strchr (addr_buf, '>'))) != NULL)
+			*addr_buf_rangle = '\0';
 		/* From: [plain-phrase space] "<" address ">" */
 		*begin = '\0';
 		if (strict) {
