@@ -67,7 +67,7 @@ group_constructor (Group                * g,
 	pan_warn_if_fail (g!=NULL);
 	pan_warn_if_fail (is_nonempty_string(name));
 
-	g->article_mutex = g_mutex_new ();
+	g->article_mutex = NULL;
 	g->loaded_since_last_fetch = FALSE;
 	g->articles_dirty = FALSE;
 	g->flags = (gint8)0;
@@ -98,6 +98,17 @@ group_constructor (Group                * g,
 	g->_one_big_chunk = NULL;
 }
 
+static GMutex*
+group_get_article_mutex (Group * g)
+{
+       g_return_val_if_fail (group_is_valid(g), NULL);
+
+       if (g->article_mutex == NULL)
+               g->article_mutex = g_mutex_new ();
+
+       return g->article_mutex;
+}
+
 static void
 destroy_articles_ghfunc (gpointer key, gpointer val, gpointer user_data)
 {
@@ -148,7 +159,10 @@ group_destructor (Group * o)
 		memchunk_destroy (g->_article_chunk);
 		g->_article_chunk = NULL;
 	}
-	g_mutex_free (g->article_mutex);
+	if (g->article_mutex != NULL) {
+		g_mutex_free (g->article_mutex);
+		g->article_mutex = NULL;
+	}
 }
 
 /***
@@ -182,6 +196,7 @@ groups_set_subscribed (Group ** groups, gint qty, gboolean subscribed)
 	gint i;
 	ServerGroupsType type;
 	Server * server = NULL;
+	debug_enter ("groups_set_subscribed");
 
 	/* sanity clause */
 	g_return_if_fail (groups != NULL);
@@ -209,6 +224,8 @@ groups_set_subscribed (Group ** groups, gint qty, gboolean subscribed)
 		server_save_grouplist_if_dirty (server, NULL);
 
 	fire_groups_changed (groups, qty);
+
+	debug_exit ("groups_set_subscribed");
 }
 
 gboolean 
@@ -240,6 +257,8 @@ void
 group_set_default_charset (Group * group,
                            const char * default_charset)
 {
+	debug_enter ("group_set_default_charset");
+
 	g_return_if_fail (group_is_valid(group));
 
 	if (!is_nonempty_string (default_charset))
@@ -249,6 +268,8 @@ group_set_default_charset (Group * group,
 
 	group_set_dirty (group);
 	fire_groups_changed (&group, 1);
+
+	debug_exit ("group_set_default_charset");
 }
 
 const char*
@@ -350,36 +371,68 @@ group_mark_new_article_number (Group         * group,
 	group->article_high_old = everything_above_this_is_new;
 }
 
-void
-group_set_article_qty (Group * group, gint article_qty)
+static void
+group_set_article_qty_impl (Group * group, int article_qty)
 {
+	debug_enter ("group_set_article_qty_impl");
+
 	g_return_if_fail (group_is_valid(group));
 
 	if (article_qty != group->article_qty)
 	{
 		group->article_qty = article_qty;
 		group_set_dirty (group);
-		fire_groups_changed (&group, 1);
 	}
+
+	debug_exit ("group_set_article_qty_impl");
 }
 
 void
-group_set_article_read_qty (Group * group, gint article_read_qty)
+group_set_article_qty (Group * group, gint article_qty)
 {
+	debug_enter ("group_set_article_qty");
+
+	group_set_article_qty_impl (group, article_qty);
+	fire_groups_changed (&group, 1);
+
+	debug_exit ("group_set_article_qty");
+}
+
+static void
+group_set_article_read_qty_impl (Group * group, gint article_read_qty)
+{
+	debug_enter ("group_set_article_read_qty_impl");
+
 	g_return_if_fail (group_is_valid(group));
 
 	article_read_qty = MAX (article_read_qty, 0);
 	group->article_read_qty = article_read_qty;
 	group_set_dirty (group);
+
+	debug_exit ("group_set_article_read_qty_impl");
+}
+
+void
+group_set_article_read_qty (Group * group, gint article_read_qty)
+{
+	debug_enter ("group_set_article_read_qty");
+
+	group_set_article_read_qty_impl (group, article_read_qty);
 	fire_groups_changed (&group, 1);
+
+	debug_exit ("group_set_article_read_qty");
 }
 void
 group_inc_article_read_qty (Group * group, gint inc)
 {
+	debug_enter ("group_inc_article_read_qty");
+
 	g_return_if_fail (group_is_valid(group));
 
 	if (inc != 0)
 		group_set_article_read_qty (group, group->article_read_qty + inc);
+
+	debug_exit ("group_inc_article_read_qty");
 }
 
 void
@@ -399,12 +452,12 @@ group_mark_all_read (Group * g, gboolean read)
 	   because that updates all the unread_children fields, marks 
 	   crossposts as read, etc... */
 
-	g_mutex_lock (g->article_mutex);
+	g_mutex_lock (group_get_article_mutex (g));
 	articles = group_get_article_array (g);
 	if (articles->len > 0)
 		articles_set_read  ((Article**)articles->pdata, articles->len, TRUE);
 	g_ptr_array_free (articles, TRUE);
-	g_mutex_unlock (g->article_mutex);
+	g_mutex_unlock (group_get_article_mutex (g));
 
 	/**
 	 * Wipe the entire newsgroup's article range as read.
@@ -445,7 +498,6 @@ group_is_valid (const Group * group)
 {
 	g_return_val_if_fail (group!=NULL, FALSE);
 	g_return_val_if_fail (server_is_valid (group->server), FALSE);
-	g_return_val_if_fail (group->article_mutex!=NULL, FALSE);
 	g_return_val_if_fail (is_nonempty_string(group->name), FALSE);
 
 	return TRUE;
@@ -519,12 +571,15 @@ group_empty (Group * group, gboolean clear_counts)
 	g_ptr_array_free (a, TRUE);
 
 	/* reset the counters */
-	group_set_article_qty (group, 0);
-	group_set_article_read_qty (group, 0);
+	group_set_article_qty_impl (group, 0);
+	group_set_article_read_qty_impl (group, 0);
+	newsrc_mark_all (group_get_purged(group), FALSE);
 
 	/* if user wants to clear the range, do that too */
 	if (clear_counts)
 		group_set_article_range (group, 0, 0);
+
+	fire_groups_changed (&group, 1);
 }
 
 /***
@@ -605,19 +660,6 @@ folder_remove_message  (Group         * folder,
 ****
 ***/
 
-static void
-group_add_articles_ghfunc (gpointer key, gpointer val, gpointer data)
-{
-	Group * group = GROUP(key);
-	GPtrArray * articles = (GPtrArray*)val;
-
-	/* remove the articles from the other group */
-	group_remove_articles (group, articles);
-
-	/* clean up */
-	g_ptr_array_free (articles, TRUE);
-}
-
 void
 group_add_article (Group * group, Article * article)
 {
@@ -658,49 +700,9 @@ group_add_articles_impl (Group             * group,
 	if (!articles->len) return;
 	g_return_if_fail (articles->len>0);
 	g_return_if_fail (articles_are_valid ((const Article**)articles->pdata, articles->len));
+	for (i=0; i<articles->len; ++i)
+		g_return_if_fail (ARTICLE(g_ptr_array_index(articles,i))->group == group);
 
-	/**
-	***  Remove the articles from their old groups.
-	***  Batching the removal makes the code uglier but
-	***  it runs faster.
-	**/
-
-	if (1)
-	{
-		GHashTable * remove_from_old = NULL;
-
-		for (i=0; i!=articles->len; ++i)
-		{
-			Article * article = ARTICLE(g_ptr_array_index(articles,i));
-			Group * oldgroup = article->group;
-			gboolean array_existed;
-			GPtrArray * to_remove;
-
-			if (oldgroup==NULL || oldgroup==group)
-				continue;
-
-			/* ensure the hash table exists */
-			if (remove_from_old == NULL)
-				remove_from_old = g_hash_table_new (g_direct_hash, g_direct_equal);
-
-			/* add this array to the array of articles to remove from its group */
-			to_remove = g_hash_table_lookup (remove_from_old, oldgroup);
-			array_existed = to_remove != NULL;
-			if (!array_existed)
-				to_remove = g_ptr_array_new ();
-			g_ptr_array_add (to_remove, article);
-
-			/* we hash the 'remove these' array by group */
-			if (!array_existed)
-				g_hash_table_insert (remove_from_old, oldgroup, to_remove);
-		}
-
-		if (remove_from_old != NULL)
-		{
-			g_hash_table_foreach (remove_from_old, group_add_articles_ghfunc, NULL);
-			g_hash_table_destroy (remove_from_old);
-		}
-	}
 
 	/**
 	***  Get a handle on our current stats...
@@ -719,7 +721,7 @@ group_add_articles_impl (Group             * group,
 	purged = group_get_purged (group);
 
 	if (lock_group) {
-		g_mutex_lock (group->article_mutex);
+		g_mutex_lock (group_get_article_mutex (group));
 	}
 
 	ours = group_get_articles (group);
@@ -764,7 +766,7 @@ group_add_articles_impl (Group             * group,
 	**/
 
 	if (lock_group) {
-		g_mutex_unlock (group->article_mutex);
+		g_mutex_unlock (group_get_article_mutex (group));
 	}
 
 	/**
@@ -778,10 +780,10 @@ group_add_articles_impl (Group             * group,
 			group_set_article_range (group, low, high);
 
 		/* update the group article stats */
-		group_set_article_qty (group, g_hash_table_size(ours));
+		group_set_article_qty_impl (group, g_hash_table_size(ours));
 		if (old_qty != 0)
 			new_read_qty += group->article_read_qty;
-		group_set_article_read_qty (group, new_read_qty);
+		group_set_article_read_qty_impl (group, new_read_qty);
 		group_set_articles_dirty (group);
 		fire_groups_changed (&group, 1);
 
@@ -911,7 +913,7 @@ group_remove_articles (Group * group, const GPtrArray * articles)
 	***  Try to remove the articles
 	**/
 
-	g_mutex_lock (group->article_mutex);
+	g_mutex_lock (group_get_article_mutex (group));
 	ours = group_get_articles (group);
 	removed_read = 0;
 	removed = g_ptr_array_new ();
@@ -941,7 +943,7 @@ group_remove_articles (Group * group, const GPtrArray * articles)
 	if (removed->len)
 	{
 		GPtrArray * rethread_a = article_get_unique_threads (removed, GET_WHOLE_THREAD);
-		GHashTable * rethread_hash = g_hash_table_new (g_str_hash, g_str_equal);
+		GHashTable * rethread_hash = g_hash_table_new (g_direct_hash, g_direct_equal);
 
 		/* add removed articles to the 'deleted' list */
 		if (group->_deleted_articles == NULL)
@@ -951,12 +953,12 @@ group_remove_articles (Group * group, const GPtrArray * articles)
 		/* build a hash table of the articles that need to be rethreaded */
 		for (i=0; i!=rethread_a->len; ++i) {
 			Article * a = ARTICLE(g_ptr_array_index(rethread_a, i));
-			g_hash_table_insert (rethread_hash, (gpointer)a->message_id, a);
+			g_hash_table_insert (rethread_hash, a, a);
 		}
 		/* remove the deleted articles from this rethread list */
 		for (i=0; i!=removed->len; ++i) {
 			Article * a = ARTICLE(g_ptr_array_index(removed, i));
-			g_hash_table_remove (rethread_hash, a->message_id);
+			g_hash_table_remove (rethread_hash, a);
 		}
 
 		/* rethread the affected articles */
@@ -974,7 +976,7 @@ group_remove_articles (Group * group, const GPtrArray * articles)
 	***  Unlock the lock
 	**/
 
-	g_mutex_unlock (group->article_mutex);
+	g_mutex_unlock (group_get_article_mutex (group));
 
 	/**
 	***  Update the stats
@@ -1072,10 +1074,9 @@ group_ref_articles (Group * group, StatusItem * status)
 	g_static_mutex_lock (&article_refcount_mutex);
 	if (++group->_articles_refcount == 1)
 	{
-		g_mutex_lock (group->article_mutex);
+		g_mutex_lock (group_get_article_mutex (group));
 		file_headers_load (group, status);
-		group_set_article_qty (group, g_hash_table_size(group->_articles));
-		g_mutex_unlock (group->article_mutex);
+		g_mutex_unlock (group_get_article_mutex (group));
 	}
 	g_static_mutex_unlock (&article_refcount_mutex);
 
@@ -1095,7 +1096,7 @@ group_unref_articles (Group * group, StatusItem * status)
 	g_static_mutex_lock (&article_refcount_mutex);
 	if (group->_articles_refcount == 1)
 	{
-		g_mutex_lock (group->article_mutex);
+		g_mutex_lock (group_get_article_mutex (group));
 		file_headers_save_noref (group, status);
 		server_save_grouplist_if_dirty (group->server, status);
 
@@ -1120,7 +1121,7 @@ group_unref_articles (Group * group, StatusItem * status)
 			g_string_chunk_free (group->chunk);
 			group->chunk = NULL;
 		}
-		g_mutex_unlock (group->article_mutex);
+		g_mutex_unlock (group_get_article_mutex (group));
 	}
 	--group->_articles_refcount;
 	g_static_mutex_unlock (&article_refcount_mutex);
@@ -1396,8 +1397,11 @@ static void
 fire_groups_changed (Group ** g, gint qty)
 {
 	g_return_if_fail (g!=NULL);
+	debug_enter ("fire_groups_changed");
 
 	pan_callback_call (group_get_groups_changed_callback(), g, GINT_TO_POINTER(qty));
+
+	debug_exit ("fire_groups_changed");
 }
 
 PanCallback*
