@@ -1,13 +1,11 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Author: Charles Kerr <charles@rebelbase.com>
- *
- * Copyright (C) 2000, 2001  Pan Development Team <pan@rebelbase.com>
+ * Pan - A Newsreader for Gtk+
+ * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation; version 2 of the License.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,7 +15,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * 
  */
 
 #include <config.h>
@@ -124,13 +121,13 @@ log_add_entry (LogEntry * entry)
 }
 
 static LogEntry*
-log_entry_new (LogSeverity severity, const gchar * msg)
+log_entry_new (LogSeverity severity, const char * msg)
 {
 	LogEntry * entry;
 
 	if (!_inited)
 		log_init ();
-       
+
 	entry = (LogEntry*) memchunk_alloc (_entries);
 	entry->message = g_strchomp (g_string_chunk_insert (_strings, msg));
 	entry->date = time(NULL);
@@ -139,7 +136,7 @@ log_entry_new (LogSeverity severity, const gchar * msg)
 }
 
 void
-log_add (LogSeverity severity, const gchar * message)
+log_add (LogSeverity severity, const char * message)
 {
 	LogEntry * entry;
 	g_static_mutex_lock (&_log_mutex);
@@ -150,10 +147,10 @@ log_add (LogSeverity severity, const gchar * message)
 }
 
 void
-log_add_va (LogSeverity severity, const gchar * format, ...)
+log_add_va (LogSeverity severity, const char * format, ...)
 {
 	va_list args;
-	gchar * message;
+	char * message;
 	LogEntry * entry;
 	g_return_if_fail (format != NULL);
 
