@@ -29,6 +29,7 @@
 #include <gmime/internet-address.h>
 
 #include <pan/base/article.h>
+#include <pan/base/base-prefs.h>
 #include <pan/base/gnksa.h>
 #include <pan/base/message-check.h>
 #include <pan/base/pan-i18n.h>
@@ -60,6 +61,91 @@ get_nntp_rcpts (const gchar *to)
 ****  OUTGOING MESSAGE CHECKS
 ***/
 
+static char*
+strip_attribution_and_signature (const char * body, GMimeMessage * message)
+{
+	char * retval = NULL;
+	char * attribution;
+	const char * sig;
+
+	g_return_val_if_fail (body!=NULL, NULL);
+	g_return_val_if_fail (message!=NULL, NULL);
+
+	retval = g_strdup (body);
+
+	/* strip out the attribution */
+	attribution = g_strdup (g_mime_message_get_header (message, PAN_ATTRIBUTION));
+	if (is_nonempty_string (attribution)) {
+		const char * attribution_start_pos = strstr (body, attribution);
+		if (attribution_start_pos != NULL) {
+			const int attribution_start_index = attribution_start_pos - body;
+			const int attribution_len = strlen(attribution) + 2; /* +2: trim out the following carriage returns */
+			char * body2 = g_strdup (body);
+			g_memmove (body2 + attribution_start_index,
+				body + attribution_start_index + attribution_len,
+				strlen(body) - attribution_len - attribution_start_index + 1);
+			replace_gstr (&retval, body2);
+		}
+	}
+
+	/* strip out the signature */
+	if (((sig = strstr (body, "\n-- \n"))) != NULL) {
+		char * body2 = g_strndup (retval, sig-body);
+		g_strstrip (body2);
+		replace_gstr (&retval, body2);
+	}
+
+	g_free (attribution);
+	return retval;
+}
+
+/**
+ * Check to see if the user is top-posting.
+ */
+static void
+check_topposting (GPtrArray      * setme_errors,
+                  GoodnessLevel  * setme_goodness,
+                  const char     * body,
+		  GMimeMessage   * message)
+{
+	char * freeme = NULL;
+	int line_len;
+	const char * march;
+	const char * line_begin;
+	gboolean original_found_after_quoted = FALSE;
+	gboolean quoted_found = FALSE;
+
+	/* sanity clause */
+	g_return_if_fail (setme_errors!=NULL);
+	g_return_if_fail (setme_goodness!=NULL);
+	g_return_if_fail (body!=NULL);
+	g_return_if_fail (message!=NULL);
+
+	/* if it's not a reply, then top-posting check is moot */
+	if (g_mime_message_get_header (message, HEADER_REFERENCES) == NULL)
+		return;
+
+	/* walk through the body, looking for an original line after a quoted one */
+	march = body = freeme = strip_attribution_and_signature (body, message);
+	while ((get_next_token_run (march, '\n', &march, &line_begin, &line_len))) {
+		if (is_quote_char ((guchar)line_begin[0])) /* check for quoted */
+			quoted_found = TRUE;
+		else if (quoted_found) /* check for non-quoted after quoted */
+			original_found_after_quoted = TRUE;
+	}
+
+	/* did they put anything after the quote? */
+	if (quoted_found && !original_found_after_quoted) {
+		g_ptr_array_add (setme_errors, g_strdup(
+			_("WARNING: Reply seems to be top-posted.")));
+		*setme_goodness = MAX (*setme_goodness, WARN);
+	}
+
+	/* cleanup */
+	g_free (freeme);
+}
+
+
 /**
  * Check to see if the signature (if found) is within the McQuary limit of
  * four lines and 80 columns per line.
@@ -254,70 +340,37 @@ check_mostly_quoted (GPtrArray      * setme_errors,
 static void
 check_all_quoted (GPtrArray      * setme_errors,
                   GoodnessLevel  * setme_goodness,
-	          const gchar    * body,
+	          const char     * body,
 		  GMimeMessage   * message)
 {
-	gchar * body2;
-	const gchar * pch;
-	gchar * attribution;
-	gint line_len;
-	const gchar * line_begin;
+	int line_len;
+	char * freeme;
+	const char * line_begin;
+	const char * march;
 
 	g_return_if_fail (is_nonempty_string(body));
 
-	/* (1) */
-	attribution = g_strdup (g_mime_message_get_header (message, PAN_ATTRIBUTION));
-	body2 = g_strdup (body);
-
-	/* (2) */
-	if (is_nonempty_string (attribution))
-		g_strdelimit (attribution, "\n", ' ');
-
-	/* (3) */
-	if (is_nonempty_string (attribution)) {
-		pch = pan_strstr (body2, attribution);
-		if (pch != NULL)
-		{	
-			char * src;
-			char * tgt;
-			int    attribution_len = strlen (attribution);
-			int    attribution_start_index = pch - body2;
-		
-			src = body2 + attribution_start_index + attribution_len;
-			tgt = body2 + attribution_start_index;
-			while (*src)
-				*tgt++ = *src++;
-			*tgt = '\0';
-		}
-	}
-	g_free (attribution);
-
-	/* (4) */
-	pch = body2;
-	while (get_next_token_run (pch, '\n', &pch, &line_begin, &line_len))
+	march = body = freeme = strip_attribution_and_signature (body, message);
+	while (get_next_token_run (march, '\n', &march, &line_begin, &line_len))
 	{
-		const gchar * pch = line_begin;
-		const gchar * end = line_begin + line_len;
-
-		/* check for sig reached */
-		if (line_len==3 && !strncmp(line_begin,"-- ",3))
-			break;
-
-		while (pch!=end && isspace((guchar)*pch))
-			++pch;
-		if (pch==end) /* blank line */
+		const char * march = line_begin;
+		const char * end = line_begin + line_len;
+		while (march!=end && isspace((guchar)*march))
+			++march;
+		if (march==end) /* blank line */
 			continue;
-
-		if (*pch != '>') { /* found new content */
-			g_free (body2);
+		if (!is_quote_char ((guchar)*march)) { /* found new content */
+			g_free (freeme);
 			return;
 		}
 	}
-	g_free (body2);
 
 	g_ptr_array_add (setme_errors, g_strdup(
 		_("ERROR: Message appears to have no new content.")));
 	*setme_goodness = MAX (*setme_goodness, REFUSE);
+
+	/* cleanup */
+	g_free (freeme);
 }
 
 static void
@@ -339,6 +392,7 @@ check_body (GPtrArray       * setme_errors,
 		check_signature (setme_errors, setme_goodness, body);
 		check_mostly_quoted (setme_errors, setme_goodness, body);
 		check_all_quoted (setme_errors, setme_goodness, body, message);
+		check_topposting (setme_errors, setme_goodness, body, message);
 	}
 }
 
