@@ -1,13 +1,11 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Author: Charles Kerr <charles@rebelbase.com>
- *
- * Copyright (C) 2000, 2001  Pan Development Team <pan@rebelbase.com>
+ * Pan - A Newsreader for Gtk+
+ * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation; version 2 of the License.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,15 +15,14 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * 
  */
 
 #ifndef __MESSAGE_CHECK_H__
 #define __MESSAGE_CHECK_H__
 
 #include <glib.h>
-
-#include <pan/base/article.h>
+#include <gmime/gmime-message.h>
+#include <pan/base/server.h>
 
 typedef enum
 {
@@ -35,7 +32,7 @@ typedef enum
 }
 GoodnessLevel;
 
-void check_article            (const Article    * article_to_post,
+void message_check            (GMimeMessage     * message,
                                Server           * server_to_post_article,
                                GPtrArray        * appendme_error_strings,
                                GoodnessLevel    * setme_goodness_level);
