@@ -35,6 +35,7 @@ static void
 pan_message_identifier_init (MessageIdentifier * mid, MessageIdentifierClass * klass)
 {
 	mid->line_qty = 0ul;
+	mid->byte_qty = 0ul;
 	mid->message_id = NULL;
 	mid->readable_name = NULL;
 	mid->message_sources = g_ptr_array_new ();
@@ -161,6 +162,7 @@ message_identifier_add_source_from_article  (MessageIdentifier  * mid,
 	g_return_if_fail (article_is_valid(article));
 
 	mid->line_qty = article->linecount;
+	mid->byte_qty = article->byte_qty;
 	message_identifier_add_source (mid, article->group->server->name, article->group->name, article->number);
 	article_xref_foreach (article, add_source_from_article_xreffunc, mid, SERVER_GROUPS_ALL, FALSE);
 }
