@@ -93,7 +93,10 @@ newsrc_import (Server         * server,
 	g_return_if_fail (is_nonempty_string(filename_in));
 
 	/* make sure the file exists */
-	filename = pan_substitute (filename_in, "~", g_get_home_dir());
+	filename = strchr (filename_in, '~') == NULL
+		? g_strdup (filename_in)
+		: pan_substitute (filename_in, "~", g_get_home_dir());
+	filename_in = NULL;
 	g_return_if_fail (pan_file_exists (filename));
 
 	/* read the file into 'body'*/
@@ -207,7 +210,9 @@ newsrc_export (Server          * server,
 	/* sanity clause */
 	g_return_if_fail (server_is_valid (server));
 	g_return_if_fail (is_nonempty_string(filename_in));
-	filename = pan_substitute (filename_in, "~", g_get_home_dir());
+	filename = strchr (filename_in, '~') == NULL
+		? g_strdup (filename_in)
+		: pan_substitute (filename_in, "~", g_get_home_dir());
 	filename_in = NULL;
 
 	/* open a temp file to write to */
