@@ -162,8 +162,8 @@ init_read (Newsrc * n)
 static int
 compare_pulong_to_pRange (const void * a, const void * b)
 {
-	const register gulong number = *(gulong *)a;
-	const register Range * range = (const Range*) b;
+	register const gulong number = *(gulong *)a;
+	register const Range * range = (const Range*) b;
 	int retval;
 
 	if (number < range->low)
