@@ -16,6 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+
 /*
  * ABOUT PAN-CALLBACK
  *
@@ -50,26 +51,17 @@
 
 #include <glib.h>
 
-typedef void (*PanCallbackFunc)(gpointer call_object,
-                                gpointer call_arg,
-                                gpointer user_data);
 
-typedef struct
-{
-	gpointer impl;
-}
-PanCallback;
+typedef struct PanCallbackStruct PanCallback;
 
-extern PanCallback* pan_callback_new (void);
+PanCallback* pan_callback_new (void);
+void pan_callback_free (PanCallback*);
 
-extern void pan_callback_free (PanCallback*);
+typedef void (*PanCallbackFunc)(gpointer call_object, gpointer call_arg, gpointer user_data);
+void pan_callback_add (PanCallback*, PanCallbackFunc, gpointer);
+void pan_callback_remove (PanCallback*, PanCallbackFunc, gpointer);
 
-extern void pan_callback_call (PanCallback*,
-                               gpointer call_object,
-                               gpointer call_arg);
+void pan_callback_call (PanCallback*, gpointer call_object, gpointer call_arg);
 
-extern void pan_callback_add (PanCallback*, PanCallbackFunc, gpointer);
-
-extern void pan_callback_remove (PanCallback*, PanCallbackFunc, gpointer);
 
 #endif /* PAN_CALLBACK_H */
