@@ -351,7 +351,7 @@ write_node (GNode * node, gpointer data)
 }
 
 static void
-pan_config_save ()
+pan_config_save (void)
 {
 	GString * output;
 	char      fname[PATH_MAX];
@@ -500,7 +500,7 @@ pan_config_load_ini (void)
 
 	/* read the ini file */
 	log_add (LOG_INFO, "can't find config.xml file; trying to import for ~/.gnome/Pan");
-	filename = g_strdup_printf ("%s/.gnome/Pan", g_get_home_dir());
+	filename = g_build_filename (g_get_home_dir(), ".gnome", "Pan", NULL);
 	g_file_get_contents (filename, &file, NULL, NULL);
 
 	/* march through the file */
