@@ -35,6 +35,7 @@
 #include <gmime/gmime-iconv-utils.h>
 
 #include <pan/base/log.h>
+#include <pan/base/pan-i18n.h>
 #include <pan/base/pan-glib-extensions.h>
 
 
@@ -60,7 +61,7 @@ int
 pan_strcmp (const char * a,
             const char * b)
 {
-	gint retval;
+	int retval;
 
 	if (a == b)
 		retval = 0;
@@ -74,26 +75,6 @@ pan_strcmp (const char * a,
 	return retval;
 }
 
-gboolean
-string_ends_with (const char * str,
-                  const char * end)
-{
-	size_t str_len;
-	size_t end_len;
-	gboolean retval = FALSE;
-
-	g_return_val_if_fail (end!=NULL, FALSE);
-	g_return_val_if_fail (str!=NULL, FALSE);
-
-	str_len = strlen (str);
-	end_len = strlen (end);
-	if (end_len <= str_len)
-		retval = !memcmp(end, str+str_len-end_len, end_len);
- 
-	return retval;
-}
-
-
 void
 replace_gstr (char   ** oldaddr,
               char    * newval)
@@ -626,7 +607,7 @@ pan_str_unescape (const char * escaped)
 			long ch;
 			src += 2;
 			if ((ch = strtoul(src, &endp, 0))) {
-				*tgt++ = ch;
+				*tgt++ = (char) ch;
 				src = endp + 1;
 			}
 		}
@@ -775,8 +756,22 @@ pan_utf8ize (const char    * str,
 
 	if (!is_nonempty_string (str))
 		retval = *g_freeme = g_strdup ("");
-	else if  (!g_utf8_validate (str, len, NULL))
-		retval = *g_freeme = g_locale_to_utf8 (str, len, NULL, NULL, NULL);
+	else if  (!g_utf8_validate (str, len, NULL)) {
+		GError * err = NULL;
+		retval = *g_freeme = g_locale_to_utf8 (str, len, NULL, NULL, &err);
+
+		if (err != NULL) {
+			g_error_free (err);
+			err = NULL;
+			/* last resort ... */
+			retval = *g_freeme = g_convert (str, len, "UTF-8", "ISO-8859-1", NULL, NULL, &err);
+		}
+
+		if (err != NULL) {
+			log_add_va (LOG_ERROR, _("Error converting string \"%*s\" to utf8: %d - %s"), len, str, err->code, err->message);
+			g_error_free (err);
+		}
+	}
 	else {
 		*g_freeme = NULL;
 		retval = str;
