@@ -169,12 +169,12 @@ pan_file_copy (const char * old_filename,
 	g_return_val_if_fail (is_nonempty_string(old_filename), -1);
 	g_return_val_if_fail (is_nonempty_string(new_filename), -1);
 
-	in = fopen (old_filename, "r");
+	in = fopen (old_filename, "rb");
 	if (in == NULL) {
 		log_add_va (LOG_ERROR, _("Error opening file \"%s\": %s"), old_filename, g_strerror(errno));
 		return -1;
 	}
-	out = fopen (new_filename, "w+");
+	out = fopen (new_filename, "wb+");
 	if (out == NULL) {
 		log_add_va (LOG_ERROR, _("Error opening file \"%s\": %s"), new_filename, g_strerror(errno));
 		fclose (in);
@@ -217,10 +217,24 @@ static int
 pan_mkdir (const char * path, gulong mode)
 {
 	int retval = 0;
+
+	g_return_val_if_fail (is_nonempty_string(path), retval);
+
+	if (strlen(path)==2 && isalpha((guchar)path[0]) && path[1]==':')
+	{
+		/* smells like a windows pathname.. skipping */
+	}
+	else
+	{
+		errno = 0;
 #ifdef MKDIR_TAKES_ONE_ARG
-	retval = mkdir (path);
+		retval = mkdir (path);
 #else
-	retval = mkdir (path, mode);
+		retval = mkdir (path, mode);
 #endif
+		if (errno == EEXIST)
+			retval = 0;
+	}
+	
 	return retval;
 }
