@@ -175,7 +175,7 @@ yenc_parse_begin_line (const char  * b,
 	ll = __yenc_extract_tag_val_int (b, YENC_TAG_LINE);
 	g_return_val_if_fail (ll != 0, -1);
 
-	// part is optional
+	/* part is optional */
 	part_num = __yenc_extract_tag_val_int (b, YENC_TAG_PART);
 	
 	a_sz = __yenc_extract_tag_val_int( b, YENC_TAG_SIZE );
@@ -203,7 +203,7 @@ yenc_parse_begin_line (const char  * b,
  * of the part inside the end file
  */
 static int
-yenc_parse_part_line (const char * b, int *begin_offset, int *end_offset)
+yenc_parse_part_line (const char * b, guint *begin_offset, guint *end_offset)
 {
 	int bg;
 	int end;
@@ -224,21 +224,6 @@ yenc_parse_part_line (const char * b, int *begin_offset, int *end_offset)
 	return 0;
 }
 
-
-#if 0
-static gboolean
-is_yenc_line (const char * line, int len)
-{
-	if (len != YENC_FULL_LINE_LEN || len != YENC_HALF_LINE_LEN) {
-		if (len != YENC_FULL_LINE_LEN + 1 || YENC_HALF_LINE_LEN + 1)
-			return FALSE;
-	}
-	
-	// TODO if +1 than line length check for escape chars at the end
-	return TRUE;
-}
-#endif
-
 /**
  * yenc_is_beginning
  * @param line line to test & see if it's the beginning of a yenc block
@@ -413,7 +398,7 @@ static guint
 stream_readln (GMimeStream *stream, GByteArray *line, off_t* startpos)
 {
 	char linebuf[1024];
-	ssize_t len;
+	gssize len;
 
 	/* sanity clause */
 	g_return_val_if_fail (stream!=NULL, 0u);
@@ -469,7 +454,6 @@ separate_encoded_parts (GMimeStream * istream,
 	gboolean yenc_looking_for_part_line = FALSE;
 	off_t linestart_pos = 0;
 	off_t sub_begin = 0;
-	off_t sub_end = 0;
 	guint line_len;
 
 	/* sanity clause */
@@ -477,7 +461,6 @@ separate_encoded_parts (GMimeStream * istream,
 	g_return_if_fail (appendme_file_parts!=NULL);
 
 	sub_begin = 0;
-	sub_end = 0;
 	line = g_byte_array_sized_new (4096);
 	while ((line_len = stream_readln (istream, line, &linestart_pos)))
 	{
@@ -615,6 +598,7 @@ separate_encoded_parts (GMimeStream * istream,
 			g_mime_stream_cat_add_source (GMIME_STREAM_CAT(cur->cat), stream);
 			g_mime_stream_unref (stream);
 		}
+		cur->type = ENC_PLAIN; /* just in case someone started with "yenc" or "begin 644 asf" in a text message to fuck with unwary newsreaders */
 		g_ptr_array_add (appendme_file_parts, cur);
 		cur = NULL;
 		type = ENC_PLAIN;
@@ -628,7 +612,7 @@ guess_part_type_from_filename (const char   * filename,
                                const char  ** setme_type,
                                const char  ** setme_subtype)
 {
-	const static struct {
+	static const struct {
 		const char * suffix;
 		const char * type;
 		const char * subtype;
@@ -663,7 +647,7 @@ guess_part_type_from_filename (const char   * filename,
 		{ ".xsl",   "text",         "xml" },
 		{ ".zip",   "application",  "zip" }
 	};
-	const static int suffix_qty = G_N_ELEMENTS (suffixes);
+	static const int suffix_qty = G_N_ELEMENTS (suffixes);
 	const char * suffix;
 
 	/* zero out the return values */
@@ -766,7 +750,6 @@ handle_inline_encoded_data (GMimeObject **part)
 			GMimeStream * substream;
 			const char * type = NULL;
 			const char * subtype = NULL;
-			char *cid;
 			
 			/* create the new subpart's stream */
 
@@ -780,9 +763,6 @@ handle_inline_encoded_data (GMimeObject **part)
 
 				/* set part's attributes */
 				g_mime_part_set_filename (subpart, enc_part->decoded_filename);
-				cid = g_strdup_printf ("<%s>", enc_part->decoded_filename);
-				g_mime_part_set_content_id (subpart, cid);
-				g_free (cid);
 
 				filter_stream = g_mime_stream_filter_new_with_stream (substream);
 				g_mime_stream_filter_add (GMIME_STREAM_FILTER (filter_stream), g_mime_filter_basic_new_type (GMIME_FILTER_BASIC_UU_DEC));
@@ -800,9 +780,6 @@ handle_inline_encoded_data (GMimeObject **part)
 				
 				/* set part's attributes */
 				g_mime_part_set_filename (subpart, enc_part->decoded_filename);
-				cid = g_strdup_printf ("<%s>", enc_part->decoded_filename);
-				g_mime_part_set_content_id (subpart, cid);
-				g_free (cid);
 				
 				g_mime_part_set_content_disposition (subpart, "inline");
 				
@@ -867,7 +844,7 @@ handle_inline_encoded_data (GMimeObject **part)
  *
  * Returns a partial mime part.
  */
-GMimeMessagePartial*
+static GMimeMessagePartial*
 pan_fake_partial (GMimeMessage  * parent,
                   GMimeStream   * content,
                   const char    * id,
@@ -941,7 +918,7 @@ pan_g_mime_parser_construct_message (GMimeStream  ** istreams,
 
 	/* build the GMimeMessages */
 	parser = g_mime_parser_new ();
-	messages = g_new0 (GMimeMessage*, qty);
+	messages = g_newa (GMimeMessage*, qty);
 	for (i=0; i<qty; ++i) {
 		g_mime_parser_init_with_stream (parser, istreams[i]);
 		messages[i] = g_mime_parser_construct_message (parser);
@@ -955,8 +932,8 @@ pan_g_mime_parser_construct_message (GMimeStream  ** istreams,
 	}
 	else
 	{
-		gpointer * unref = g_new (gpointer, qty);
-		GMimeMessagePartial ** partials  = g_new (GMimeMessagePartial*, qty);
+		gpointer * unref = g_newa (gpointer, qty);
+		GMimeMessagePartial ** partials  = g_newa (GMimeMessagePartial*, qty);
 
 		/* make an array of message/partials that to reconstruct a single message */
 		for (i=0; i<qty; ++i)
@@ -997,8 +974,6 @@ pan_g_mime_parser_construct_message (GMimeStream  ** istreams,
 		/* cleanup */
 		for (i=0; i<qty; ++i)
 			g_object_unref (unref[i]);
-		g_free (partials);
-		g_free (unref);
 	}
 
 	/* pick out yenc and uuenc data in text/plain messages */
@@ -1006,7 +981,6 @@ pan_g_mime_parser_construct_message (GMimeStream  ** istreams,
 		handle_inline_encoded_data (&retval->mime_part);
 
 	/* cleanup */
-	g_free (messages);
 	return retval;
 }
 
