@@ -1,13 +1,11 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Author: Charles Kerr <charles@rebelbase.com>
- *
- * Copyright (C) 2000, 2001  Pan Development Team <pan@rebelbase.com>
+ * Pan - A Newsreader for Gtk+
+ * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation; version 2 of the License.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,10 +20,24 @@
 #ifndef __UTIL_WRAP__H__
 #define __UTIL_WRAP__H__
 
-char * rot13                       (const char * body);
+/**
+ * Run the specified text through a rot13 filter.
+ * @param text
+ */
+char * pan_text_rot13_inplace     (char         * text);
 
-char * mute_quoted_text_in_body    (const char * body);
+/**
+ * Strip out quoted text, replacing it with "> [Quoted text muted]".
+ * @param text
+ */
+char * pan_text_mute_quoted       (const char   * text);
 
-char * fill_body                   (const char * body, int wrap_column);
+/**
+ * Wraps/fills the specified text to the specified column number.
+ * @param text
+ * @param wrap_column
+ */
+char * pan_text_fill              (const char   * text,
+                                   int            wrap_column);
 
 #endif /* __UTIL_WRAP__H__ */
