@@ -93,14 +93,21 @@ static char *
 get_credits_translators (void)
 {
 	const char * str =
-"\n\tcs - Michal Bukovjan"
-"\n\tde - Benjamin Greiner"
-"\n\tes - Pablo Gonzalo del Campo"
-"\n\tet - Tivo Leedjrv"
-"\n\tja - Takayuki KUSANO"
-"\n\tnl - Reinout van Schouwen"
-"\n\tsv - Christian Rose"
-"\n\tvi - pclouds";
+		"\n\tam - Ge'ez Frontier Foundation"
+		"\n\tcs - Michal Bukovjan, Miloslav Trmac"
+		"\n\tde - Benjamin Greiner, Christian Meyer, Karsten Weiss"
+		"\n\tes - Pablo del Campo"
+		"\n\tet - Tivo Leedjrv"
+		"\n\tfr - Gildas Guillemot, Christophe Merlet, Laurent Richard"
+		"\n\tno - Kjartan Maraas"
+		"\n\tsk - Marcel Telka"
+		"\n\tsv - Christian Rose"
+		"\n\tlv - Artis Trops"
+		"\n\tpl - GNOME PL Team"
+		"\n\tpt - Duarte Loreto"
+		"\n\tnl - Vincent van Adrighem, Reinout van Schouwen"
+		"\n\tuk - Yuri Syrota"
+		"\n\tja - Takayuki KUSANO";
 	return g_convert (str, strlen(str), "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
 }
 
@@ -108,7 +115,10 @@ static char *
 get_credits_code (void)
 {
 	const char * str =
-"\n\tBrandon Corey";
+		"\n\tRobert Boucher"
+		"\n\tClinton Bunch"
+		"\n\tHarav Shivanan"
+		"\n\tNam SungHyun";
 	return g_convert (str, strlen(str), "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
 }
 
@@ -116,30 +126,25 @@ static char *
 get_credits_users (void)
 {
 	const char * str = 
-"\n\tAlan Bailward (#91365)"
-"\n\tJames Brost (#100904)"
-"\n\tBobby D. Bryant (#100695)"
-"\n\tChill"
-"\n\tSid Cowles (#99218)"
-"\n\tWendell Dingus (#90378)"
-"\n\tDuncan"
-"\n\tTom F."
-"\n\tBo Flynn (#100605)"
-"\n\tGollum (#93713, #93894)"
-"\n\tDon Horsman (#97527)"
-"\n\tKang Jeong-Hee (#87553)"
-"\n\tJohan (#909070)"
-"\n\tCarl Hudkins (#85153)"
-"\n\tChristian Lohmaier (#89281)"
-"\n\tJean-Marc (#91536)"
-"\n\tMaurizio (#101013)"
-"\n\tBas Mevissen (#89435)"
-"\n\tLeonard Nutley (#93169)"
-"\n\tChris Petersen (#94863)"
-"\n\tJens Petersen (#99873)"
-"\n\tWill Robinson (#97710)"
-"\n\tMartin Schrode (#98463)"
-"\n\tJerry Segers (#97778)"
-"\n\tMarcin Wojtczuk (#67554)";
+		"\n\tRobert Boucher"
+		"\n\tMichaela Susan Buesin"
+		"\n\tBobby D. Bryant (#102208)"
+		"\n\tJean-Marc Desperrier (#104479)"
+		"\n\tNicolas Girard (#104155)"
+		"\n\tJakob Breivik Grimstveit (#105879)"
+		"\n\tMike Hearn (#103563)"
+		"\n\tHolger Hoffsttte (#102881)"
+		"\n\tMark Kelly"
+		"\n\tMaurizio (#101013)"
+		"\n\tBas Mevissen (#103908, #103907)"
+		"\n\tMr. Nice (#107025)"
+		"\n\tMatt Pinkham (#103579)"
+		"\n\tMartin Schrode (#88869)"
+		"\n\tJerry Segers (#102586, #102577)"
+		"\n\tHarav Shivanan"
+		"\n\tVille Skytt (#102158)"
+		"\n\tLuigi Trovato"
+		"\n\tAdam Warner (#102469)"
+		"\n\tMichael Waters";
 	return g_convert (str, strlen(str), "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
 }
