@@ -27,13 +27,12 @@
 #include <pan/base/base-prefs.h>
 #include <pan/base/serverlist.h>
 #include <pan/base/pan-i18n.h>
+#include <pan/base/pan-glib-extensions.h>
 
 #include <pan/dialogs/dialogs.h>
 
-#include <pan/globals.h>
 #include <pan/grouplist.h>
 #include <pan/pan-charset-picker.h>
-#include <pan/prefs.h>
 #include <pan/util.h>
 
 
@@ -79,6 +78,7 @@ group_properties_response_cb (GtkDialog * dialog, int response, gpointer user_da
 	if (response!=GTK_RESPONSE_APPLY)
 	{
 		gtk_widget_destroy (GTK_WIDGET(dialog));
+		g_free (gp);
 	}
 }
 
