@@ -1,31 +1,38 @@
-/* Pan "About" Dialog
- * Copyright (C) 2001 Charles Kerr <charles@rebelbase.com>
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/*
+ * Pan - A Newsreader for Gtk+
+ * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Cambridge, MA 02139, USA. 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include <config.h>
 #include <string.h>
-#include <gnome.h>
-#include "pan-about.h"
+
+#include <glib.h>
+#include <gtk/gtk.h>
+
+#include <pan/base/pan-i18n.h>
+#include <pan/dialogs/pan-about.h>
+#include <pan/util.h>
 
 typedef struct
 {
-	gint tabs;
-	GtkWidget * author_text;
-	GtkWidget * credit_text;
+	int tabs;
+	GtkWidget * notebook;
+	GtkTextBuffer * author_text;
+	GtkTextBuffer * credit_text;
 }
 Impl;
 
@@ -35,67 +42,11 @@ Impl;
 ****
 ***/
 
-static GtkObjectClass * parent_class = NULL;
-
-static void
-pan_about_destroy (GtkObject* object)
-{
-        PanAbout * a;
- 
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (PAN_IS_ABOUT (object));
-        g_return_if_fail (GTK_OBJECT_CONSTRUCTED (object));
-
-	a = PAN_ABOUT(object);
-	g_free (a->_private);
- 
-        (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
-}                                                                                               
-
-static void
-pan_about_class_init (PanAboutClass * klass)
-{
-	GtkObjectClass * object_class = (GtkObjectClass*) klass;
-	parent_class = gtk_type_class (GTK_TYPE_OBJECT);
-
-	object_class->destroy = pan_about_destroy;
-}
-
-static void
-pan_about_init (PanAbout *about)
-{
-}
-
-guint
-pan_about_get_type (void)
-{
-	static guint about_type = 0;
-
-	if (!about_type)
-	{
-		GtkTypeInfo about_info =
-		{
-			"PanAbout",
-			sizeof (PanAbout),
-			sizeof (PanAboutClass),
-			(GtkClassInitFunc) pan_about_class_init,
-			(GtkObjectInitFunc) pan_about_init,
-			(GtkArgSetFunc) NULL,
-			(GtkArgGetFunc) NULL,
-		};
-
-		about_type = gtk_type_unique (gnome_dialog_get_type(), &about_info);
-	}
-
-	return about_type;
-}
-
-
 static void
 homepage_clicked_url (GtkWidget * w)
 {
-	const gchar * url = (const gchar*) gtk_object_get_data (GTK_OBJECT(w), "url");
-	gnome_url_show (url);
+	const char * url = (const char*) gtk_object_get_data (GTK_OBJECT(w), "url");
+	pan_url_show (url);
 }
 
 /***
@@ -104,52 +55,56 @@ homepage_clicked_url (GtkWidget * w)
 ****
 ***/
 
-static void
-create_text (GtkWidget ** top, GtkWidget ** text)
+static GtkWidget*
+create_text (GtkTextBuffer * buffer)
 {
 	GtkWidget * w;
 	GtkWidget * scrolled_window;
 
         scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-        gtk_container_set_border_width (GTK_CONTAINER(scrolled_window), GNOME_PAD_SMALL);
+        gtk_container_set_border_width (GTK_CONTAINER(scrolled_window), GUI_PAD_SMALL);
         gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
                                         GTK_POLICY_AUTOMATIC,
-                                        GTK_POLICY_AUTOMATIC);       
- 	w = gtk_text_new (NULL, NULL);
-	gtk_text_set_editable (GTK_TEXT(w), FALSE);
-	gtk_text_set_line_wrap (GTK_TEXT(w), FALSE);
+                                        GTK_POLICY_AUTOMATIC);
+ 	w = gtk_text_view_new_with_buffer (buffer);
 	gtk_container_add (GTK_CONTAINER(scrolled_window), w);
 
 	gtk_widget_show (scrolled_window);
 	gtk_widget_show (w);
 
-	*top = scrolled_window;
-	*text = w;
+	return scrolled_window;
 }
  
-void
-pan_about_construct (PanAbout      * about,
-                     const gchar   * app_title,
-                     const gchar   * app_version,
-                     const gchar   * app_short_description,
-                     const gchar   * app_copyright,
-                     const gchar   * app_license,
-                     const gchar   * app_homepage)
+GtkWidget*
+pan_about_new (GtkWindow     * window,
+               const char    * app_title,
+               const char    * app_version,
+               const char    * app_short_description,
+               const char    * app_copyright,
+               const char    * app_license,
+               const char    * app_homepage)
 {
-	gchar * pch;
+	char * pch;
 	GtkWidget * w;
+	GtkWidget * dialog;
 	GtkWidget * note;
 	Impl * impl;
 
-	/* Init Impl */
+	/* create dialog */
+	pch = g_strdup_printf (_("About %s"), app_title);
+	dialog = gtk_dialog_new_with_buttons (pch,
+	                                      window,
+	                                      GTK_DIALOG_DESTROY_WITH_PARENT,
+	                                      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+	                                      NULL);
+	g_free (pch);
+	                                      
+	/* init impl */
 	impl = g_new0 (Impl, 1);
-	about->_private = impl;
+	g_object_set_data_full (G_OBJECT(dialog), "impl", impl, g_free);
 
 	/* Window properties */
-	gtk_window_set_policy (GTK_WINDOW (about), TRUE, TRUE, TRUE);
-	pch = g_strdup_printf (_("About %s"), app_title);
-	gtk_window_set_title (GTK_WINDOW (about), pch);
-	g_free (pch);
+	gtk_window_set_policy (GTK_WINDOW (dialog), TRUE, TRUE, TRUE);
 
 	/* top -- fixme, needs app's icon */
 	pch = g_strdup_printf ("%s %s", app_title, app_version);
@@ -157,12 +112,12 @@ pan_about_construct (PanAbout      * about,
 	gtk_misc_set_alignment (GTK_MISC(w), 0.0, 0.5);
 	gtk_label_set_justify (GTK_LABEL(w), GTK_JUSTIFY_LEFT);
 	g_free (pch);
-	gtk_box_pack_start (GTK_BOX(GNOME_DIALOG(about)->vbox), w, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX(GTK_DIALOG(dialog)->vbox), w, FALSE, FALSE, GUI_PAD_SMALL);
 	gtk_widget_show (w);
 
 	/* notebook */
-	note = about->notebook = gtk_notebook_new ();
-	gtk_box_pack_start (GTK_BOX(GNOME_DIALOG(about)->vbox), note, TRUE, TRUE, 0);
+	note = impl->notebook = gtk_notebook_new ();
+	gtk_box_pack_start (GTK_BOX(GTK_DIALOG(dialog)->vbox), note, TRUE, TRUE, GUI_PAD_SMALL);
 	gtk_widget_show (note);
 
 	/* populate notebook */
@@ -178,7 +133,7 @@ pan_about_construct (PanAbout      * about,
 		l = gtk_label_new (app_short_description);
 		gtk_misc_set_alignment (GTK_MISC(l), 0.0, 0.5);
 		gtk_label_set_justify (GTK_LABEL(l), GTK_JUSTIFY_LEFT);
-		gtk_box_pack_start (GTK_BOX(w), l, FALSE, FALSE, GNOME_PAD);
+		gtk_box_pack_start (GTK_BOX(w), l, FALSE, FALSE, GUI_PAD);
 		gtk_widget_show (l);
 
 		if (app_homepage != NULL)
@@ -186,11 +141,11 @@ pan_about_construct (PanAbout      * about,
 			GtkWidget * h = gtk_hbox_new (FALSE, FALSE);
 			l = gtk_button_new_with_label (app_homepage);
 			gtk_object_set_data_full (GTK_OBJECT(l), "url", g_strdup(app_homepage), g_free);
-			gtk_signal_connect (GTK_OBJECT(l), "clicked", homepage_clicked_url, NULL);
+			g_signal_connect (GTK_OBJECT(l), "clicked", G_CALLBACK(homepage_clicked_url), NULL);
 			gtk_button_set_relief (GTK_BUTTON(l), GTK_RELIEF_NONE);
 			gtk_misc_set_alignment (GTK_MISC(GTK_BIN(l)->child), 0.0, 0.5);
 			gtk_box_pack_start (GTK_BOX(h), l, FALSE, FALSE, 0);
-			gtk_box_pack_start (GTK_BOX(w), h, FALSE, FALSE, GNOME_PAD);
+			gtk_box_pack_start (GTK_BOX(w), h, FALSE, FALSE, GUI_PAD);
 			gtk_widget_show (l);
 			gtk_widget_show (h);
 		}
@@ -200,11 +155,11 @@ pan_about_construct (PanAbout      * about,
 			l = gtk_label_new (app_copyright);
 			gtk_misc_set_alignment (GTK_MISC(l), 0.0, 0.5);
 			gtk_label_set_justify (GTK_LABEL(l), GTK_JUSTIFY_LEFT);
-			gtk_box_pack_start (GTK_BOX(w), l, FALSE, FALSE, GNOME_PAD);
+			gtk_box_pack_start (GTK_BOX(w), l, FALSE, FALSE, GUI_PAD);
 			gtk_widget_show (l);
 		}
 
-		gtk_container_set_border_width (GTK_CONTAINER(w), GNOME_PAD_BIG);
+		gtk_container_set_border_width (GTK_CONTAINER(w), GUI_PAD_BIG);
 
  		tab = gtk_label_new (_("About"));
 		gtk_notebook_append_page (GTK_NOTEBOOK(note), w, tab);
@@ -215,41 +170,25 @@ pan_about_construct (PanAbout      * about,
 	/* license */
 	if (app_license != NULL)
 	{
-		gint i = 0;
 		GtkWidget * tab;
-		GtkWidget * w = NULL;
-		GtkWidget * top = NULL;
-		create_text (&top, &w);
+		GtkWidget * top;
+		GtkTextIter iter;
+		GtkTextBuffer * buffer;
+
+		buffer = gtk_text_buffer_new (NULL);
+		gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
+		gtk_text_buffer_insert (buffer, &iter, app_license, -1);
+		top = create_text (buffer);
+
  		tab = gtk_label_new (_("License"));
-		gtk_editable_insert_text (GTK_EDITABLE(w), app_license, strlen(app_license), &i);
 		gtk_notebook_append_page (GTK_NOTEBOOK(note), top, tab);
 		gtk_widget_show (tab);
 		++impl->tabs;
 	}
 
-	gtk_widget_set_usize (GTK_WIDGET(about), 450, 400);
-        gnome_dialog_append_button ( GNOME_DIALOG(about),
-                                     GNOME_STOCK_BUTTON_OK);
-        gnome_dialog_set_close(GNOME_DIALOG(about), TRUE);
-}
-
-GtkWidget*
-pan_about_new (const gchar   * app_title,
-               const gchar   * app_version,
-               const gchar   * app_short_description,
-               const gchar   * app_copyright,
-               const gchar   * app_license,
-               const gchar   * app_homepage)
-{
-	PanAbout * about = gtk_type_new (pan_about_get_type ());
-	pan_about_construct (about,
-	                     app_title,
-	                     app_version,
-	                     app_short_description,
-	                     app_copyright,
-	                     app_license,
-	                     app_homepage);
-	return GTK_WIDGET (about);
+	gtk_widget_set_usize (GTK_WIDGET(dialog), 450, 400);
+	g_signal_connect_swapped (GTK_OBJECT (dialog), "response", G_CALLBACK (gtk_widget_destroy), GTK_OBJECT(dialog));
+	return dialog;
 }
 
 
@@ -262,26 +201,27 @@ pan_about_new (const gchar   * app_title,
 
 
 static void
-pan_add_someone (GtkText          ** text,
-                 gint              * tabs,
+pan_add_someone (GtkTextBuffer    ** buffer,
+                 int               * tabs,
                  GtkWidget         * notebook,
-                 const gchar       * tab_name,
-                 const gchar       * person_name,
-                 const gchar       * person_job_title,
-                 const gchar       * person_email)
+                 const char        * tab_name,
+                 const char        * person_name,
+                 const char        * person_job_title,
+                 const char        * person_email)
 {
+	g_return_if_fail (buffer!=NULL);
 	g_return_if_fail (person_name!=NULL);
-	g_return_if_fail (text!=NULL);
 	g_return_if_fail (notebook!=NULL);
 
-	if (*text == NULL)
+	if (*buffer == NULL)
 	{
 		GtkWidget * tab;
-		GtkWidget * txt = NULL;
 		GtkWidget * top = NULL;
-		create_text (&top, &txt);
- 		tab = gtk_label_new (_("Authors"));
- 		*text = GTK_TEXT(txt);
+
+		*buffer = gtk_text_buffer_new (NULL);
+		top = create_text (*buffer);
+
+ 		tab = gtk_label_new (tab_name);
 		gtk_notebook_insert_page (GTK_NOTEBOOK(notebook), top, tab, *tabs-1);
 		(*tabs)++;
 		gtk_widget_show (tab);
@@ -290,21 +230,20 @@ pan_add_someone (GtkText          ** text,
 	/* add the string */
 	if (person_name != NULL)
 	{
-		gint i;
 		GString * str;
-
+		GtkTextIter iter;
 
 		/* build the string */
 		str = g_string_new (person_name);
 		if (person_email!=NULL && *person_email!='\0')
-			g_string_sprintfa (str, "\n\t%s", person_email);
+			g_string_append_printf (str, "\n\t%s", person_email);
 		if (person_job_title!=NULL && *person_job_title!='\0')
-			g_string_sprintfa (str, "\n\t%s", person_job_title);
+			g_string_append_printf (str, "\n\t%s", person_job_title);
 		g_string_append (str, "\n\n");
 
 		/* add it to the text widget */
-		i = gtk_text_get_length (GTK_TEXT(*text));
-		gtk_editable_insert_text (GTK_EDITABLE(*text), str->str, str->len, &i);
+		gtk_text_buffer_get_end_iter (*buffer, &iter);
+		gtk_text_buffer_insert (*buffer, &iter, str->str, str->len);
 
 		/* cleanup */
 		g_string_free (str, TRUE);
@@ -314,56 +253,71 @@ pan_add_someone (GtkText          ** text,
 }
 
 void
-pan_about_add_author   (PanAbout      * about,
-                        const gchar   * name,
-                        const gchar   * job_title,
-                        const gchar   * email)
+pan_about_add_author   (GtkWidget     * about,
+                        const char    * name,
+                        const char    * email,
+                        const char    * job_title)
 {
 	Impl * impl;
 
-	g_return_if_fail (PAN_IS_ABOUT(about));
+	g_return_if_fail (GTK_IS_DIALOG(about));
 	g_return_if_fail (name!=NULL);
+	impl = (Impl*) g_object_get_data (G_OBJECT(about), "impl");
+	g_return_if_fail (impl!=NULL);
 
-	impl = (Impl*) about->_private;
-	pan_add_someone ((GtkText**)(&impl->author_text), &impl->tabs,
-	                 about->notebook,
+	pan_add_someone (&impl->author_text,
+	                 &impl->tabs,
+	                  impl->notebook,
 	                 _("Authors"),
 	                 name, job_title, email);
 }
 
 void
-pan_about_add_credit   (PanAbout      * about,
-                        const gchar   * name,
-                        const gchar   * job_title,
-                        const gchar   * email)
+pan_about_add_credit   (GtkWidget     * about,
+                        const char    * name,
+                        const char    * email,
+                        const char    * job_title)
 {
 	Impl * impl;
 
-	g_return_if_fail (PAN_IS_ABOUT(about));
+	g_return_if_fail (GTK_IS_DIALOG(about));
 	g_return_if_fail (name!=NULL);
+	impl = (Impl*) g_object_get_data (G_OBJECT(about), "impl");
+	g_return_if_fail (impl!=NULL);
 
-	impl = (Impl*) about->_private;
-	pan_add_someone ((GtkText**)(&impl->credit_text), &impl->tabs,
-	                 about->notebook,
+	pan_add_someone (&impl->credit_text,
+	                 &impl->tabs,
+	                  impl->notebook,
 	                 _("Thanks to"),
 	                 name, job_title, email);
 }
 
  
 void
-pan_about_add_text     (PanAbout      * about,
-                        const gchar   * tab_text,
-                        const gchar   * text)
+pan_about_add_text     (GtkWidget     * about,
+                        const char    * tab_text,
+                        const char    * text)
 {
-	Impl * impl = about->_private;
-	gint i = 0;
-	GtkWidget * txt = NULL;
-	GtkWidget * top = NULL;
-	GtkWidget * tab = gtk_label_new (tab_text);
+	GtkTextIter iter;
+	GtkTextBuffer * buffer;
+	GtkWidget * top;
+	GtkWidget * tab;
+	Impl * impl;
+
+	g_return_if_fail (GTK_IS_DIALOG(about));
+	impl = (Impl*) g_object_get_data (G_OBJECT(about), "impl");
+	g_return_if_fail (impl!=NULL);
+
+	top = NULL;
+	tab = gtk_label_new (tab_text);
 	gtk_widget_show (tab);
-	create_text (&top, &txt);
-	gtk_editable_insert_text (GTK_EDITABLE(txt), text, strlen(text), &i);
-	gtk_notebook_insert_page (GTK_NOTEBOOK(about->notebook), top, tab, impl->tabs-1);
+
+       	buffer = gtk_text_buffer_new (NULL);
+	gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
+	gtk_text_buffer_insert (buffer, &iter, text, -1);
+	top = create_text (buffer);
+
+	gtk_notebook_insert_page (GTK_NOTEBOOK(impl->notebook), top, tab, impl->tabs-1);
 	++impl->tabs;
 }
                                                                                                 
@@ -375,7 +329,7 @@ pan_about_add_text     (PanAbout      * about,
 ***/
 
 
-const gchar * PAN_ABOUT_LICENSE_GPL =  "GNU GENERAL PUBLIC LICENSE\n\
+const char * PAN_ABOUT_LICENSE_GPL =  "GNU GENERAL PUBLIC LICENSE\n\
 Version 2, June 1991\n\
 \n\
 Copyright (C) 1989, 1991 Free Software Foundation, Inc.\n\
@@ -655,3 +609,4 @@ PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE\n\
 POSSIBILITY OF SUCH DAMAGES.\n\
 \n\
 END OF TERMS AND CONDITIONS";
+
