@@ -69,9 +69,9 @@ typedef struct
 	GtkWidget * view_clist;
 
 	GtkWidget * phrase_rb;
-	GtkWidget * phrase_menu;
-	GtkWidget * phrase_entry;
-	GtkWidget * phrase_regexp_checkbutton;
+	GtkWidget * phrase_key_menu;
+	GtkWidget * phrase_match_menu;
+	GtkWidget * phrase_key_entry;
 	GtkWidget * lines_rb;
 	GtkWidget * lines_sb;
 	GtkWidget * xpost_rb;
@@ -339,16 +339,32 @@ get_new_filter (FilterEditDialog * d)
 
 	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(d->phrase_rb)))
 	{
-		gboolean is_regex = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(d->phrase_regexp_checkbutton));
-		GtkWidget * active = gtk_menu_get_active (GTK_MENU(d->phrase_menu));
-		FilterPhraseState state = GPOINTER_TO_INT(gtk_object_get_user_data (GTK_OBJECT(active)));
-		char * phrase = gtk_editable_get_chars (GTK_EDITABLE(d->phrase_entry), 0, -1);
-                g_strstrip (phrase);
-		if (is_nonempty_string(phrase)) {
-			f = filter_phrase_new ();
-			filter_phrase_set (FILTER_PHRASE(f), state, phrase, is_regex);
+		GtkWidget * active;
+		PhraseKeyType key_type;
+		int match_type;
+		char * key;
+		gboolean negate = FALSE;
+
+		active = gtk_menu_get_active (GTK_MENU(d->phrase_match_menu));
+		match_type = GPOINTER_TO_INT(gtk_object_get_user_data (GTK_OBJECT(active)));
+		if (match_type < 0) {
+			match_type = -match_type;
+			negate = TRUE;
 		}
-		g_free (phrase);
+
+		active = gtk_menu_get_active (GTK_MENU(d->phrase_key_menu));
+		key_type = GPOINTER_TO_INT(gtk_object_get_user_data (GTK_OBJECT(active)));
+
+		key = gtk_editable_get_chars (GTK_EDITABLE(d->phrase_key_entry), 0, -1);
+                g_strstrip (key);
+		if (is_nonempty_string(key))
+		{
+			f = filter_phrase_new ();
+			filter_phrase_set (FILTER_PHRASE(f), match_type, key_type, key);
+			if (negate)
+				filter_negate (f);
+		}
+		g_free (key);
 	}
 	else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(d->lines_rb)))
 	{
@@ -705,14 +721,14 @@ filter_edit_dialog_new (GtkWindow * window, const FilterTop * top)
 	g_signal_connect (GTK_OBJECT(w), "clicked", G_CALLBACK(down_button_cb), d);
 	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
 	gtk_tooltips_set_tip (tips, w, _("Move the selected line down one line"), NULL);
-	w = gtk_button_new_with_label (_("Negate"));
+	w = gtk_button_new_with_label (_("Invert"));
 	g_signal_connect (GTK_OBJECT(w), "clicked", G_CALLBACK(negate_button_cb), d);
 	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip (tips, w, _("Negate the selected line"), NULL);
-	w = gtk_button_new_with_label (_("AND"));
+	gtk_tooltips_set_tip (tips, w, _("Invert the selected line"), NULL);
+	w = gtk_button_new_with_label (_("All Of"));
 	g_signal_connect (GTK_OBJECT(w), "clicked", G_CALLBACK(and_button_cb), d);
 	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
-	w = gtk_button_new_with_label (_("OR"));
+	w = gtk_button_new_with_label (_("Any Of"));
 	g_signal_connect (GTK_OBJECT(w), "clicked", G_CALLBACK(or_button_cb), d);
 	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
 	w = gtk_button_new_from_stock (GTK_STOCK_DELETE);
@@ -742,34 +758,40 @@ filter_edit_dialog_new (GtkWindow * window, const FilterTop * top)
 	w = d->phrase_rb = gtk_radio_button_new_with_mnemonic (rb_group, _("_Article"));
 	rb_group = gtk_radio_button_group (GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start (GTK_BOX(hbox), w, FALSE, FALSE, 0);
+
+#define add_menu_item(str, callback_int) \
+	tmp = gtk_menu_item_new_with_label (str); \
+	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(callback_int)); \
+	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->phrase_rb)); \
+	gtk_widget_show (tmp); \
+	gtk_menu_append (GTK_MENU(w2), tmp); \
+
 	w = gtk_option_menu_new ();
 	gtk_box_pack_start (GTK_BOX(hbox), w, FALSE, FALSE, 0);
-	w2 = d->phrase_menu = gtk_menu_new ();
-	tmp = gtk_menu_item_new_with_label (_("Subject"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(FILTER_PHRASE_SUBJECT));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->phrase_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
-	tmp = gtk_menu_item_new_with_label (_("Author"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(FILTER_PHRASE_AUTHOR));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->phrase_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
-	tmp = gtk_menu_item_new_with_label (_("Message-ID"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(FILTER_PHRASE_MESSAGE_ID));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->phrase_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
+	w2 = d->phrase_key_menu = gtk_menu_new ();
+	add_menu_item (_("Subject"), PHRASE_KEY_SUBJECT)
+	add_menu_item (_("Author"), PHRASE_KEY_AUTHOR)
+	add_menu_item (_("Message-ID"), PHRASE_KEY_MESSAGE_ID)
 	gtk_option_menu_set_menu (GTK_OPTION_MENU(w), w2);
-	w = gtk_label_new (_("contains the phrase"));
+
+	w = gtk_option_menu_new ();
 	gtk_box_pack_start (GTK_BOX(hbox), w, FALSE, FALSE, 0);
-	w = d->phrase_entry = gtk_entry_new ();
+	w2 = d->phrase_match_menu = gtk_menu_new ();
+	add_menu_item (_("contains"), PHRASE_MATCH_CONTAINS)
+	add_menu_item (_("does not contain"), -PHRASE_MATCH_CONTAINS)
+	add_menu_item (_("is"), PHRASE_MATCH_IS)
+	add_menu_item (_("is not"), -PHRASE_MATCH_IS)
+	add_menu_item (_("starts with"), PHRASE_MATCH_STARTS_WITH)
+	add_menu_item (_("does not start with"), -PHRASE_MATCH_STARTS_WITH)
+	add_menu_item (_("ends with"), PHRASE_MATCH_ENDS_WITH)
+	add_menu_item (_("does not end with"), -PHRASE_MATCH_ENDS_WITH)
+	add_menu_item (_("matches regular expression"), PHRASE_MATCH_REGEX)
+	add_menu_item (_("does not match regular expression"), -PHRASE_MATCH_REGEX)
+	gtk_option_menu_set_menu (GTK_OPTION_MENU(w), w2);
+
+	w = d->phrase_key_entry = gtk_entry_new ();
 	g_signal_connect_swapped (GTK_OBJECT(w), "focus_in_event", G_CALLBACK(tb_activate), GTK_OBJECT(d->phrase_rb));
 	gtk_box_pack_start (GTK_BOX(hbox), w, TRUE, TRUE, 0);
-	w = d->phrase_regexp_checkbutton = gtk_check_button_new_with_label (_("Regular Expression"));
-	gtk_tooltips_set_tip (tips, w,_("See http://pan.rebelbase.com/regexp.txt for a tutorial on how to use regular expressions.  If regular expressions are turned off, a simple case-insensitive wildcard match is used."), NULL);
-	g_signal_connect_swapped (GTK_OBJECT(w), "focus_in_event", G_CALLBACK(tb_activate), GTK_OBJECT(d->phrase_rb));
-	gtk_box_pack_start (GTK_BOX(hbox), w, FALSE, FALSE, 0);
 
 	/* saved */
 	++row;
@@ -779,21 +801,9 @@ filter_edit_dialog_new (GtkWindow * window, const FilterTop * top)
 	w = gtk_option_menu_new ();
 	gtk_table_attach (GTK_TABLE(table), w, col+1, col+2, row, row+1, GTK_FILL, 0, 0, 0);
 	w2 = d->saved_menu = gtk_menu_new ();
-	tmp = gtk_menu_item_new_with_label (_("Saved"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(FILTER_SAVED_SAVED));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->saved_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
-	tmp = gtk_menu_item_new_with_label (_("Queued for Saving"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(FILTER_SAVED_QUEUED));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->saved_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
-	tmp = gtk_menu_item_new_with_label (_("Neither Saved nor Queued"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(FILTER_SAVED_NOT_SAVED));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->saved_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
+	add_menu_item (_("Saved"), FILTER_SAVED_SAVED)
+	add_menu_item (_("Queued for Saving"), FILTER_SAVED_QUEUED)
+	add_menu_item (_("Neither Saved nor Queued"), FILTER_SAVED_NOT_SAVED)
 	gtk_option_menu_set_menu (GTK_OPTION_MENU(w), w2);
 
 	/* thread */
@@ -804,21 +814,9 @@ filter_edit_dialog_new (GtkWindow * window, const FilterTop * top)
 	w = gtk_option_menu_new ();
 	gtk_table_attach (GTK_TABLE(table), w, col+1, col+2, row, row+1, GTK_FILL, 0, 0, 0);
 	w2 = d->thread_menu = gtk_menu_new ();
-	tmp = gtk_menu_item_new_with_label (_("Watched"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(FILTER_THREAD_WATCHED));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->thread_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
-	tmp = gtk_menu_item_new_with_label (_("Ignored"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(FILTER_THREAD_IGNORED));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->thread_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
-	tmp = gtk_menu_item_new_with_label (_("Neither Watched nor Ignored"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(FILTER_THREAD_NOTHING));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->thread_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
+	add_menu_item (_("Watched"), FILTER_THREAD_WATCHED)
+	add_menu_item (_("Ignored"), FILTER_THREAD_IGNORED)
+	add_menu_item (_("Neither Watched nor Ignored"), FILTER_THREAD_NOTHING)
 	gtk_option_menu_set_menu (GTK_OPTION_MENU(w), w2);
 
 	/* attachment */
@@ -829,21 +827,9 @@ filter_edit_dialog_new (GtkWindow * window, const FilterTop * top)
 	w = gtk_option_menu_new ();
 	gtk_table_attach (GTK_TABLE(table), w, col+1, col+2, row, row+1, GTK_FILL, 0, 0, 0);
 	w2 = d->attach_menu = gtk_menu_new ();
-	tmp = gtk_menu_item_new_with_label (_("Attachments"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(FILTER_BINARY_COMPLETE));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->attach_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
-	tmp = gtk_menu_item_new_with_label (_("Incomplete Attachments"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(FILTER_BINARY_INCOMPLETE));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->attach_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
-	tmp = gtk_menu_item_new_with_label (_("No Attachments"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(FILTER_BINARY_NONBINARY));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->attach_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
+	add_menu_item (_("Attachments"), FILTER_BINARY_COMPLETE)
+	add_menu_item (_("Incomplete Attachments"), FILTER_BINARY_INCOMPLETE)
+	add_menu_item (_("No Attachments"), FILTER_BINARY_NONBINARY)
 	gtk_option_menu_set_menu (GTK_OPTION_MENU(w), w2);
 
 	/* read, cached, new, posted-by-me */
@@ -854,31 +840,11 @@ filter_edit_dialog_new (GtkWindow * window, const FilterTop * top)
 	w = gtk_option_menu_new ();
 	gtk_table_attach (GTK_TABLE(table), w, col+1, col+2, row, row+1, GTK_FILL, 0, 0, 0);
 	w2 = d->article_is_menu = gtk_menu_new ();
-	tmp = gtk_menu_item_new_with_label (_("New"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(ARTICLE_IS_NEW));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->article_is_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
-	tmp = gtk_menu_item_new_with_label (_("Unread"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(ARTICLE_IS_UNREAD));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->article_is_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
-	tmp = gtk_menu_item_new_with_label (_("Read"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(ARTICLE_IS_READ));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->article_is_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
-	tmp = gtk_menu_item_new_with_label (_("Cached"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(ARTICLE_IS_CACHED));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->article_is_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
-	tmp = gtk_menu_item_new_with_label (_("Posted by Me"));
-	gtk_object_set_user_data (GTK_OBJECT(tmp), GINT_TO_POINTER(ARTICLE_IS_MINE));
-	g_signal_connect_swapped (GTK_OBJECT(tmp), "activate", G_CALLBACK(tb_activate), GTK_OBJECT(d->article_is_rb));
-	gtk_widget_show (tmp);
-	gtk_menu_append (GTK_MENU(w2), tmp);
+	add_menu_item (_("New"), ARTICLE_IS_NEW)
+	add_menu_item (_("Unread"), ARTICLE_IS_UNREAD)
+	add_menu_item (_("Read"), ARTICLE_IS_READ)
+	add_menu_item (_("Cached"), ARTICLE_IS_CACHED)
+	add_menu_item (_("Posted by Me"), ARTICLE_IS_MINE)
 	gtk_option_menu_set_menu (GTK_OPTION_MENU(w), w2);
 
 	/* lines */
