@@ -43,9 +43,11 @@
 #include <pan/util.h>
 
 
+#define DEFAULT_FILTER_SHOW FILTER_SHOW_MATCHES_AND_REFERENCES
+
 static FilterCurrentMediatorCtor _buttons;
 static gulong _filter_bits = ~STATE_FILTER_IGNORED;
-static FilterShow _filter_show = FILTER_SHOW_MATCHES_AND_REFERENCES;
+static FilterShow _filter_show = DEFAULT_FILTER_SHOW;
 static void fire_user_changed_filter (void);
 
 /**
@@ -147,10 +149,11 @@ refresh (void)
 	if (model != view)
 		gtk_check_menu_item_set_active (ckm, model);
 
-	tb = GTK_TOGGLE_BUTTON(_buttons._match_only_watched_tb);
+	tb = GTK_TOGGLE_BUTTON(_buttons._show_only_watched_threads_tb);
 	model = (_filter_bits & STATE_FILTER_WATCHED)
 		&& !(_filter_bits & STATE_FILTER_IGNORED)
-		&& !(_filter_bits & STATE_FILTER_NORMAL_RANK);
+		&& !(_filter_bits & STATE_FILTER_NORMAL_RANK)
+		&& (_filter_show == FILTER_SHOW_MATCHES_AND_REPLIES);
 	view = gtk_toggle_button_get_active (tb);
 	if (model != view)
 		gtk_toggle_button_set_active (tb, model);
@@ -194,9 +197,10 @@ refresh (void)
 	if (model != view)
 		gtk_check_menu_item_set_active (ckm, model);
 
-	tb = GTK_TOGGLE_BUTTON(_buttons._match_only_mine_tb);
+	tb = GTK_TOGGLE_BUTTON(_buttons._show_only_my_threads_tb);
 	model = (_filter_bits & STATE_FILTER_MINE)
-		&& !(_filter_bits & STATE_FILTER_NOT_MINE);
+		&& !(_filter_bits & STATE_FILTER_NOT_MINE)
+		&& (_filter_show == FILTER_SHOW_MATCHES_AND_REPLIES);
 	view = gtk_toggle_button_get_active (tb);
 	if (model != view)
 		gtk_toggle_button_set_active (tb, model);
@@ -336,17 +340,21 @@ static void
 show_only_watched_cb (GtkToggleButton * tb, gpointer user_data)
 {
 	gulong value = _filter_bits;
+	FilterShow show = _filter_show;
 	const gboolean active = gtk_toggle_button_get_active (tb);
 
-	if (!active)
+	if (!active) {
 		value |= STATE_FILTER_WATCHED | STATE_FILTER_NORMAL_RANK;
+		show = DEFAULT_FILTER_SHOW;
+	}
 	else {
 		value |= STATE_FILTER_WATCHED;
 		value &= ~STATE_FILTER_IGNORED;
 		value &= ~STATE_FILTER_NORMAL_RANK;
+		show = FILTER_SHOW_MATCHES_AND_REPLIES;
 	}
 
-	set_value (value);
+	set (value, show);
 }
 
 static void
@@ -369,16 +377,20 @@ static void
 show_only_mine_cb (GtkToggleButton * tb, gpointer user_data)
 {
 	gulong value = _filter_bits;
+	FilterShow show = _filter_show;
 	const gboolean active = gtk_toggle_button_get_active (tb);
 
-	if (!active)
+	if (!active) {
 		value |= STATE_FILTER_MINE | STATE_FILTER_NOT_MINE;
+		show = DEFAULT_FILTER_SHOW;
+	}
 	else {
 		value |= STATE_FILTER_MINE;
 		value &= ~STATE_FILTER_NOT_MINE;
+		show = FILTER_SHOW_MATCHES_AND_REPLIES;
 	}
 
-	set_value (value);
+	set (value, show);
 }
 
 static void
@@ -543,7 +555,7 @@ filter_mediator_init (FilterCurrentMediatorCtor * ctor)
 	                  G_CALLBACK(menu_button_toggled), GSIZE_TO_POINTER(STATE_FILTER_IGNORED));
 	g_signal_connect (G_OBJECT(_buttons._match_normal_ckm), "toggled",
 	                  G_CALLBACK(menu_button_toggled), GSIZE_TO_POINTER(STATE_FILTER_NORMAL_RANK));
-	g_signal_connect (G_OBJECT(_buttons._match_only_watched_tb), "toggled",
+	g_signal_connect (G_OBJECT(_buttons._show_only_watched_threads_tb), "toggled",
 	                  G_CALLBACK(show_only_watched_cb), NULL);
 
 	/* Cached */
@@ -561,7 +573,7 @@ filter_mediator_init (FilterCurrentMediatorCtor * ctor)
 	                  G_CALLBACK(menu_button_toggled), GSIZE_TO_POINTER(STATE_FILTER_MINE));
 	g_signal_connect (G_OBJECT(_buttons._match_others_ckm), "toggled",
 	                  G_CALLBACK(menu_button_toggled), GSIZE_TO_POINTER(STATE_FILTER_NOT_MINE));
-	g_signal_connect (G_OBJECT(_buttons._match_only_mine_tb), "toggled",
+	g_signal_connect (G_OBJECT(_buttons._show_only_my_threads_tb), "toggled",
 	                  G_CALLBACK(show_only_mine_cb), NULL);
 
 	/* show */
