@@ -62,7 +62,12 @@ filter_cached_test_articles (Filter          * filter,
 	int i;
 
 	for (i=0; i<article_qty; ++i)
-		passfail[i] = acache_has_message (article_get_message_id(articles[i]));
+	{
+		Group * group = articles[i]->group;
+		const char * acache_key = group_get_acache_key (group);
+		const char * message_id = article_get_message_id (articles[i]);
+		passfail[i] = acache_has_message (acache_key, message_id);
+	}
 }
 
 /************
