@@ -59,6 +59,9 @@ filter_new_to_string (const Filter * filter)
 		case FILTER_NEW_READ:
 			pch = negate ? _("Article is new or unread") : _("Article is read");
 			break;
+		default:
+			pch = "ERROR";
+			break;
 	}
 
 	return g_strdup (pch);
