@@ -32,11 +32,23 @@ typedef struct _FilterPhrase FilterPhrase;
 
 typedef enum
 {
-	FILTER_PHRASE_SUBJECT,
-	FILTER_PHRASE_AUTHOR,
-	FILTER_PHRASE_MESSAGE_ID
+	PHRASE_KEY_SUBJECT              = 1,
+	PHRASE_KEY_AUTHOR               = 2,
+	PHRASE_KEY_MESSAGE_ID           = 3,
+	PHRASE_KEY_REFERENCES           = 4,
+	PHRASE_KEY_XREF                 = 5,
 }
-FilterPhraseState;
+PhraseKeyType;
+
+typedef enum
+{
+	PHRASE_MATCH_CONTAINS           = 1,
+	PHRASE_MATCH_IS	                = 2,
+	PHRASE_MATCH_STARTS_WITH        = 3,
+	PHRASE_MATCH_ENDS_WITH          = 4,
+	PHRASE_MATCH_REGEX              = 5 
+}
+PhraseMatchType;
 
 struct _FilterPhrase
 {
@@ -44,10 +56,12 @@ struct _FilterPhrase
 	Filter parent;
 
 	/* Fields */
-	FilterPhraseState state;
-	gboolean is_regex;
-	gchar * phrase;
-	regex_t phrase_regex;
+	PhraseMatchType match_type;
+	PhraseKeyType key_type;
+	char * key;
+	char * key_lower;
+	int key_len;
+	regex_t key_regex;
 };
 
 /***
@@ -57,8 +71,8 @@ struct _FilterPhrase
 Filter*      filter_phrase_new     (void);
 
 void         filter_phrase_set     (FilterPhrase         * f,
-                                    FilterPhraseState      state,
-                                    const gchar          * phrase,
-                                    gboolean               is_regex);
+                                    PhraseMatchType        match_type,
+                                    PhraseKeyType          key_type,
+                                    const char           * key);
 
 #endif
