@@ -93,7 +93,7 @@ filter_saved_test_articles (Filter           * filter,
 		const Article * a = articles[i];
 		gboolean is_saved = article_flag_on (a, STATE_DECODED);
 		gboolean is_queued = FALSE;
-#warning fitlering on queued is broken..
+/* FIXME filtering on queued is broken.. */
 		gboolean b;
 
 		switch (state)
