@@ -77,15 +77,15 @@ filter_thread_to_string (const Filter * filter)
 static void
 filter_thread_test_articles (Filter          * filter,
                              const Article  ** articles,
-                             gint              article_qty,
+                             int               article_qty,
                              gboolean        * passfail)
 {
-	gint i;
+	int i;
 	const FilterThreadState state = FILTER_THREAD(filter)->state;
 
 	for (i=0; i<article_qty; ++i)
 	{
-		const gint a_state = pan_thread_get_state (articles[i]);
+		const int a_state = pan_thread_get_state (articles[i]);
 		gboolean b;
 		switch (state)
 		{
