@@ -197,27 +197,54 @@ add_thread_arguments (GString * appendme, const FilterThread * f)
 	}
 }
 static void
-add_phrase_arguments (GString * appendme, const FilterPhrase * f)
+add_new_arguments (GString * appendme, const FilterNew * f)
 {
 	add_filter_arguments (appendme, FILTER(f));
 
-	if (f->is_regex)
-		g_string_append (appendme, " is_regex=\"t\"");
-
-	switch (f->state) {
-		case FILTER_PHRASE_SUBJECT:
-			g_string_append (appendme, " type=\"subject\"");
+	switch (f->type) {
+		case FILTER_NEW_NEW:
+			g_string_append (appendme, " type=\"new\"");
 			break;
-		case FILTER_PHRASE_AUTHOR:
-			g_string_append (appendme, " type=\"author\"");
+		case FILTER_NEW_UNREAD:
+			g_string_append (appendme, " type=\"unread\"");
 			break;
-		case FILTER_PHRASE_MESSAGE_ID:
-			g_string_append (appendme, " type=\"message-id\"");
+		case FILTER_NEW_READ:
+			g_string_append (appendme, " type=\"read\"");
 			break;
 	}
+}
+static void
+add_phrase_arguments (GString * appendme, const FilterPhrase * f)
+{
+	const char * str;
 
-	g_string_append (appendme, " phrase=\"");
-	pan_g_string_append_escaped (appendme, f->phrase);
+	add_filter_arguments (appendme, FILTER(f));
+
+	/* match type */
+	str = "";
+	switch (f->match_type) {
+		case PHRASE_MATCH_CONTAINS:     str = "contains"; break;
+		case PHRASE_MATCH_IS:           str = "is"; break;
+		case PHRASE_MATCH_STARTS_WITH:  str = "starts_with"; break;
+		case PHRASE_MATCH_ENDS_WITH:    str = "ends_with"; break;
+		case PHRASE_MATCH_REGEX:        str = "regex"; break;
+	}
+	g_string_append_printf (appendme, " match_type=\"%s\"", str);
+
+	/* key type */
+	str = "";
+	switch (f->key_type) {
+		case PHRASE_KEY_SUBJECT:      str = "subject"; break;
+		case PHRASE_KEY_AUTHOR:       str = "author"; break;
+		case PHRASE_KEY_MESSAGE_ID:   str = "message-id"; break;
+		case PHRASE_KEY_REFERENCES:   str = "references"; break;
+		case PHRASE_KEY_XREF:         str = "xref"; break;
+	}
+	g_string_append_printf (appendme, " key_type=\"%s\"", str);
+
+	/* key */
+	g_string_append (appendme, " key=\"");
+	pan_g_string_append_escaped (appendme, f->key);
 	g_string_append (appendme, "\"");
 }
 static void
@@ -342,7 +369,7 @@ write_new (GString * appendme, const FilterNew * f, gint depth)
 {
 	newline_depth (appendme, depth);
 	g_string_append (appendme, "<new");
-	add_filter_arguments (appendme, FILTER(f));
+	add_new_arguments (appendme, f);
 	g_string_append (appendme, "/>");
 }
 static void
@@ -613,7 +640,21 @@ populate_cached (FilterCached * f, xmlNodePtr node)
 static void
 populate_new (FilterNew * f, xmlNodePtr node)
 {
+	xmlChar * val;
+	FilterNewType state = FILTER_NEW_NEW;
+
 	populate_filter (FILTER(f), node);
+
+	if ((val = xmlGetProp (node, "type")) != NULL)
+	{
+		if (!pan_strcmp(val,"new")) state = FILTER_NEW_NEW;
+		else if (!pan_strcmp(val,"unread")) state = FILTER_NEW_UNREAD;
+		else if (!pan_strcmp(val,"read")) state = FILTER_NEW_READ;
+
+		xmlFree (val);
+	}
+
+	filter_new_set_state (f, state);
 }
 
 static void
@@ -685,40 +726,72 @@ static void
 populate_phrase (FilterPhrase * f, xmlNodePtr node)
 {
 	xmlChar * val;
-	char * phrase = NULL;
-	gboolean is_regex = FALSE;
-	FilterPhraseState state = FILTER_PHRASE_SUBJECT;
+	gboolean pre_0_13_3_91 = FALSE;
+	char * key = NULL;
+	PhraseKeyType key_type = PHRASE_KEY_SUBJECT;
+	PhraseMatchType match_type = PHRASE_MATCH_CONTAINS;
 
 	populate_filter (FILTER(f), node);
 
-	/* type */
-	if ((val = xmlGetProp (node, "type")) != NULL) {
-		if (!pan_strcmp (val, "subject"))
-			state = FILTER_PHRASE_SUBJECT;
-		else if (!pan_strcmp (val, "author"))
-			state = FILTER_PHRASE_AUTHOR;
-		else if (!pan_strcmp (val, "message-id"))
-			state = FILTER_PHRASE_MESSAGE_ID;
-		else
-			log_add_va (LOG_ERROR, "Invalid filter phrase: \"%s\"", val);
+	/* match type */
+	val = xmlGetProp (node, "match_type");
+	if (val != NULL) {
+		     if (!pan_strcmp (val, "contains"))    match_type = PHRASE_MATCH_CONTAINS;
+		else if (!pan_strcmp (val, "is"))          match_type = PHRASE_MATCH_IS;
+		else if (!pan_strcmp (val, "starts_with")) match_type = PHRASE_MATCH_STARTS_WITH;
+		else if (!pan_strcmp (val, "ends_with"))   match_type = PHRASE_MATCH_ENDS_WITH;
+		else if (!pan_strcmp (val, "regex"))       match_type = PHRASE_MATCH_REGEX;
+		g_free (val);
+	}
+
+	/* key type */
+	val = xmlGetProp (node, "key_type");
+	if (val == NULL)
+		val = xmlGetProp (node, "type");
+	if (val != NULL) {
+		     if (!pan_strcmp (val, "subject"))    key_type = PHRASE_KEY_SUBJECT;
+		else if (!pan_strcmp (val, "author"))     key_type = PHRASE_KEY_AUTHOR;
+		else if (!pan_strcmp (val, "message-id")) key_type = PHRASE_KEY_MESSAGE_ID;
+		else if (!pan_strcmp (val, "references")) key_type = PHRASE_KEY_REFERENCES;
+		else if (!pan_strcmp (val, "xref"))       key_type = PHRASE_KEY_XREF;
+		else log_add_va (LOG_ERROR, "Invalid filter phrase key type: \"%s\"", val);
 
 		xmlFree (val);
 	}
 
-	/* phrase */
-	if ((val = xmlGetProp (node, "phrase")) != NULL) {
-		phrase = g_strdup (val);
+	/* key */
+	val = xmlGetProp (node, "key");
+	if (val == NULL) {
+		pre_0_13_3_91 = TRUE;
+		val = xmlGetProp (node, "phrase"); /* pre=0.13.4 */
+	}
+	if (val != NULL) {
+		key = g_strdup (val);
 		xmlFree (val);
 	}
 
-	/* regex */
-	if ((val = xmlGetProp (node, "is_regex")) != NULL) {
-		is_regex = *val=='t';
-		xmlFree (val);
+	/* backwards compatability to 0.13.3.90 and earlier:
+	 * (1) it wrapped phrases with splats for some brain-damaged reason
+	 * (2) regular expressions were denoted with their own flag.
+	 */
+	if (pre_0_13_3_91)
+	{
+		/* remove the splats */
+		GString * str = g_string_new (key);
+		if (str->len && str->str[0]=='*') g_string_erase (str, 0, 1);
+		if (str->len && str->str[str->len-1]=='*') g_string_erase (str, str->len-1, 1);
+		replace_gstr (&key, g_string_free (str, FALSE));
+
+		/* check for regex flag */
+		if ((val = xmlGetProp (node, "is_regex")) != NULL) {
+			if (*val == 't')
+				match_type = PHRASE_MATCH_REGEX;
+			xmlFree (val);
+		}
 	}
 
-	filter_phrase_set (f, state, phrase, is_regex);
-	xmlFree (phrase);
+	filter_phrase_set (f, match_type, key_type, key);
+	g_free (key);
 }
 
 static void
