@@ -472,7 +472,7 @@ grouplist_selection_changed_cb (gpointer call_object,
                                 gpointer user_data)
 {
 	GPtrArray * groups = (GPtrArray*)call_arg;
-	const gboolean activate = !_modifiers && _mb==1 && _button_click_count>=(single_click_selects?2:1);
+	const gboolean activate = !_modifiers && _mb==1 && _button_click_count>=(single_click_selects_groups ? 2 : 1);
 	debug_enter ("grouplist_selection_changed_cb");
 
 	/* sanity clause */
@@ -549,13 +549,32 @@ select_row_cb_mainthread (gpointer data)
 	GPtrArray * groups;
 	debug_enter ("select_row_cb_mainthread");
 
+	/* get the selected groups */
        	groups = grouplist_get_selected_groups ();
+
+	/* make the callbacks */
 	pan_callback_call (grouplist_group_selection_changed,
 	                   Pan.group_tree,
 			   groups);
 	select_callback_pending = FALSE;
-	g_ptr_array_free (groups, TRUE);
 
+	/* if the header pane's group is no longer selected, hide it.
+	 * http://bugzilla.gnome.org/show_bug.cgi?id=102244 */
+	if (1) {
+		Group * group = articlelist_get_group ();
+		if (group != NULL) {
+			guint i;
+			gboolean match;
+			for (match=FALSE, i=0; !match && i<groups->len; ++i)
+				if (g_ptr_array_index(groups,i) == group)
+					match = TRUE;
+			if (!match)
+				articlelist_set_group (NULL);
+		}
+	}
+
+	/* cleanup */
+	g_ptr_array_free (groups, TRUE);
 	debug_exit ("select_row_cb_mainthread");
 	return FALSE;
 }
