@@ -68,6 +68,7 @@
 #include <pan/save-ui.h>
 #include <pan/server-menu-ui.h>
 #include <pan/server-ui.h>
+#include <pan/sockets.h>
 #include <pan/status-item-view.h>
 #include <pan/text.h>
 #include <pan/task-bodies.h>
@@ -103,10 +104,10 @@ typedef enum
 	ACTION_SAVE,
 	ACTION_SAVE_AS,
 	ACTION_SHOW_ONLY_NEW,
-	ACTION_SHOW_ONLY_MINE,
+	ACTION_SHOW_ONLY_MY_THREADS,
 	ACTION_SHOW_ONLY_CACHED,
 	ACTION_SHOW_ONLY_ATTACHMENTS,
-	ACTION_SHOW_ONLY_WATCHED,
+	ACTION_SHOW_ONLY_WATCHED_THREADS,
 	ACTION_NET_ONLINE,
 	ACTION_NET_CANCEL_LAST_TASK,
 	ACTION_QTY
@@ -244,35 +245,37 @@ gui_queue_add (GSourceFunc func, gpointer user_data)
 static int
 gui_set_title_idle (gpointer data)
 {
-	Server      * server;
-	const Group * group = GROUP(data);
-	GString     * s = g_string_new (NULL);
-	const char  * servername = NULL;
-	const char  * groupname = NULL;
-	guint         selected_count = 0;
+	const Group * group;
+	GString * s;
 	debug_enter ("gui_set_title_idle");
 
-	/* look for active server & group */
-	server = serverlist_get_active_server ();
-	if (server != NULL)
-		servername = server_get_name (server);
+       	s = g_string_sized_new (128);
+
+	/* add the group */
+       	group = GROUP(data);
 	if (group != NULL) {
-		groupname = group_get_name (group);
-		selected_count = articlelist_get_selected_count_nolock ();
+		const char * groupname = group_get_name (group);
+		const guint selected_count = articlelist_get_selected_count_nolock ();
+		g_string_printf (s, "%s %d/%d",
+		                 groupname,
+		                 group->article_qty-group->article_read_qty,
+		                 group->article_qty);
+		if (selected_count > 1u) {
+			g_string_append_c (s, ' ');
+			g_string_append_printf (s, _("(%u selected)"), selected_count);
+		}
+		g_string_append (s, " - ");
 	}
 
-	/* build the title */
-	g_string_assign (s, "Pan ");
-	if (servername != NULL)
-		g_string_append_printf (s, " - %s", servername);
-	if (groupname != NULL)
-		g_string_append_printf (s, " - %s - %d/%d",
-		                   groupname,
-		                   group->article_qty-group->article_read_qty,
-		                   group->article_qty);
-	if (selected_count > 1u)
-		g_string_append_printf (s, _(" (%u selected)"),
-				   selected_count);
+	/* add the server */
+	if (1) {
+		Server * server = serverlist_get_active_server ();
+		if (server != NULL)
+			g_string_append_printf (s, " %s - ", server_get_name(server));
+	}
+
+	/* add application name */
+	g_string_append (s, "Pan");
 
 	/* set the title in the UI */
 	pan_lock ();
@@ -342,10 +345,13 @@ log_entry_added_cb (gpointer entry_data, gpointer unused1, gpointer unused2)
 
 	if (e != NULL)
 	{
-		if (e->severity & (LOG_URGENT&LOG_ERROR))
-			pan_error_dialog (e->message);
-		if (e->severity & (LOG_URGENT&LOG_INFO))
-			pan_info_dialog (e->message);
+		if (e->severity & LOG_URGENT)
+		{
+		       if (e->severity & LOG_ERROR)
+				pan_error_dialog (e->message);
+			else
+				pan_info_dialog (e->message);
+		}
 		if (e->severity & LOG_ERROR)
 			gui_queue_add (set_log_button_status_idle, GINT_TO_POINTER(STATUS_ERROR));
 	}
@@ -459,7 +465,6 @@ update_menus_cb (gpointer call_object, gpointer call_arg, gpointer user_data)
 }
 
 static GtkWidget * connection_qty_label = NULL;
-static gboolean _is_connecting = FALSE;
 static int connection_size = -1;
 static double KBps = 0.0;
 
@@ -482,11 +487,6 @@ gui_refresh_connection_label_idle (gpointer data)
 		g_snprintf (tip, sizeof(tip), _("%d connections totaling %.1f KB per second"),
 			connection_size, KBps);
 	}
-	else if (_is_connecting) {
-		g_snprintf (str, sizeof(str), _("Connecting"));
-		g_snprintf (tip, sizeof(tip), _("Connecting to news server"));
-
-	}
 	else {
 		g_snprintf (str, sizeof(str), _("No Connections"));
 		g_snprintf (tip, sizeof(tip), "%s", str);
@@ -503,18 +503,6 @@ gui_refresh_connection_label_idle (gpointer data)
 	return 0;
 }
 
-static void
-queue_connecting_state_changed_cb (gpointer call_obj, gpointer call_arg, gpointer user_data)
-{
-	const gboolean is_connecting = call_obj != NULL;
-
-	if (_is_connecting != is_connecting)
-	{
-		_is_connecting = is_connecting;
-		gui_queue_add (gui_refresh_connection_label_idle, NULL);
-	}
-}
-
 static void
 gui_set_connection_size (int size)
 {
@@ -530,8 +518,8 @@ gui_set_connection_size (int size)
 static void
 queue_connection_size_changed_cb (gpointer call_obj, gpointer call_arg, gpointer user_data)
 {
-	const int inc = GPOINTER_TO_INT (call_obj);
-	gui_set_connection_size (connection_size + inc);
+	const int size = GPOINTER_TO_INT (call_obj);
+	gui_set_connection_size (size);
 }
 
 
@@ -1141,7 +1129,6 @@ gui_shutdown (void)
 	pan_callback_remove (log_get_entry_added_callback(), log_entry_added_cb, NULL);
 	pan_callback_remove (queue_get_size_changed_callback(), queue_size_changed_cb, NULL);
 	pan_callback_remove (queue_get_connection_size_changed_callback(), queue_connection_size_changed_cb, NULL);
-	pan_callback_remove (queue_get_connecting_state_changed_callback(), queue_connecting_state_changed_cb, NULL);
 	pan_callback_remove (text_get_fill_body_changed_callback(), text_fill_body_changed_cb, NULL);
 	pan_callback_remove (text_get_mute_quoted_changed_callback(), mute_quoted_text_changed_cb, NULL);
 	pan_callback_remove (text_get_show_all_headers_changed_callback(), show_all_headers_changed_cb, NULL);
@@ -1760,8 +1747,8 @@ create_toolbar (void)
 	_toolbar_buttons[ACTION_SHOW_ONLY_NEW] = gtk_toolbar_append_element (
 		toolbar, GTK_TOOLBAR_CHILD_TOGGLEBUTTON, NULL, _("New"), _("Show Only New Articles"), NULL,
 		create_image (icon_filter_only_new), NULL, NULL);
-	_toolbar_buttons[ACTION_SHOW_ONLY_MINE] = gtk_toolbar_append_element (
-		toolbar, GTK_TOOLBAR_CHILD_TOGGLEBUTTON, NULL, _("Mine"), _("Show Only My Posts"), NULL,
+	_toolbar_buttons[ACTION_SHOW_ONLY_MY_THREADS] = gtk_toolbar_append_element (
+		toolbar, GTK_TOOLBAR_CHILD_TOGGLEBUTTON, NULL, _("Mine"), _("Show Only Replies to My Articles"), NULL,
 		create_image (icon_filter_only_me), NULL, NULL);
 	_toolbar_buttons[ACTION_SHOW_ONLY_CACHED] = gtk_toolbar_append_element (
 		toolbar, GTK_TOOLBAR_CHILD_TOGGLEBUTTON, NULL, _("Cached"), _("Show Only Cached Articles"), NULL,
@@ -1769,8 +1756,8 @@ create_toolbar (void)
 	_toolbar_buttons[ACTION_SHOW_ONLY_ATTACHMENTS] = gtk_toolbar_append_element (
 		toolbar, GTK_TOOLBAR_CHILD_TOGGLEBUTTON, NULL, _("Files"), _("Show Only Complete Attachments"), NULL,
 		create_image (icon_filter_only_attachments), NULL, NULL);
-	_toolbar_buttons[ACTION_SHOW_ONLY_WATCHED] = gtk_toolbar_append_element (
-		toolbar, GTK_TOOLBAR_CHILD_TOGGLEBUTTON, NULL, _("Watched"), _("Show Only Watched Articles"), NULL,
+	_toolbar_buttons[ACTION_SHOW_ONLY_WATCHED_THREADS] = gtk_toolbar_append_element (
+		toolbar, GTK_TOOLBAR_CHILD_TOGGLEBUTTON, NULL, _("Watched"), _("Show Only Watched Threads"), NULL,
 		create_image (icon_filter_only_watched), NULL, NULL);
 	gtk_toolbar_append_space (toolbar);
 
@@ -1897,7 +1884,6 @@ gui_construct (const char * geometry)
 	pan_callback_add (log_get_entry_added_callback(), log_entry_added_cb, NULL);
 	pan_callback_add (queue_get_size_changed_callback(), queue_size_changed_cb, NULL);
 	pan_callback_add (queue_get_connection_size_changed_callback(), queue_connection_size_changed_cb, NULL);
-	pan_callback_add (queue_get_connecting_state_changed_callback(), queue_connecting_state_changed_cb, NULL);
 	pan_callback_add (status_item_get_active_callback(), status_item_active_changed_cb, NULL);
 	pan_callback_add (text_get_fill_body_changed_callback(), text_fill_body_changed_cb, NULL);
 	pan_callback_add (text_get_show_all_headers_changed_callback(), show_all_headers_changed_cb, NULL);
@@ -1938,7 +1924,6 @@ gui_construct (const char * geometry)
 		ctor._match_watched_ckm = gtk_item_factory_get_item (_main_menu_factory, "/Filter/Match Watched Threads");
 		ctor._match_ignored_ckm = gtk_item_factory_get_item (_main_menu_factory, "/Filter/Match Ignored Threads");
 		ctor._match_normal_ckm = gtk_item_factory_get_item (_main_menu_factory, "/Filter/Match Threads Neither Watched nor Ignored");
-		ctor._match_only_watched_tb = _toolbar_buttons[ACTION_SHOW_ONLY_WATCHED];
 
 		ctor._match_cached_ckm = gtk_item_factory_get_item (_main_menu_factory, "/Filter/Match Articles which are Cached");
 		ctor._match_noncached_ckm = gtk_item_factory_get_item (_main_menu_factory, "/Filter/Match Articles which are not Cached");
@@ -1946,13 +1931,15 @@ gui_construct (const char * geometry)
 
 		ctor._match_mine_ckm = gtk_item_factory_get_item (_main_menu_factory, "/Filter/Match Articles Written by Me");
 		ctor._match_others_ckm = gtk_item_factory_get_item (_main_menu_factory, "/Filter/Match Articles Written by Other People");
-		ctor._match_only_mine_tb = _toolbar_buttons[ACTION_SHOW_ONLY_MINE];
 
 		ctor._show_articles_rmi = gtk_item_factory_get_item (_main_menu_factory, "/Filter/Show Matching Articles");
 		ctor._show_articles_and_replies_rmi = gtk_item_factory_get_item (_main_menu_factory, "/Filter/Show Matching Articles and Replies");
 		ctor._show_articles_and_refs_rmi = gtk_item_factory_get_item (_main_menu_factory, "/Filter/Show Matching Articles and References");
 		ctor._show_threads_rmi = gtk_item_factory_get_item (_main_menu_factory, "/Filter/Show Threads with Matching Articles");
 
+		ctor._show_only_watched_threads_tb = _toolbar_buttons[ACTION_SHOW_ONLY_WATCHED_THREADS];
+		ctor._show_only_my_threads_tb = _toolbar_buttons[ACTION_SHOW_ONLY_MY_THREADS];
+
 		filter_mediator_init (&ctor);
 	}
 
@@ -2399,7 +2386,7 @@ static GtkItemFactoryEntry main_menu_entries[MAIN_MENU_ENTRIES_QTY] =
 	/*   */ {N_("/_Tools/---"), NULL, NULL, 0, "<Separator>"},
 	/* t */ {N_("/_Tools/_Task Manager..."), NULL, task_manager_spawn, 0, NULL},
 	/*   */ {N_("/_Tools/---"), NULL, NULL, 0, "<Separator>"},
-	/* l */ {N_("/_Tools/_Log Viewer..."), NULL, log_button_clicked, 0, "<ImageItem>", GTK_STOCK_DIALOG_INFO},
+	/* l */ {N_("/_Tools/_Log Viewer..."), NULL, log_button_clicked, 0, "<ImageItem>", icon_inform},
 
 	/*   */ {N_("/_Help"), NULL, NULL, 0, "<Branch>"},
 	/* h */ {N_("/_Help/Pan _Home Page..."), NULL, pan_homepage_url, 0, "<StockItem>", GTK_STOCK_HOME},
