@@ -135,12 +135,12 @@ create_identity_tab (IdentityEditDialog *d)
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+3);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+3, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+3);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+3, 0, 0, 0, 0);
 
 		l = gtk_label_new_with_mnemonic (_("_Profile name:"));
 		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
@@ -162,7 +162,7 @@ create_identity_tab (IdentityEditDialog *d)
 	/* spacer between "profile information" and "required information" */
 	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 	gtk_widget_set_usize (w, 0u, 6u);
-	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
+	gtk_table_attach (GTK_TABLE(t), w, 0, 4, row, row+1, 0, 0, 0, 0);
 	++row;
 
 		/* title for profile info section */
@@ -176,12 +176,12 @@ create_identity_tab (IdentityEditDialog *d)
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+2);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+2, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+2);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+2, 0, 0, 0, 0);
 
 		l = gtk_label_new_with_mnemonic (_("_Full Name:"));
 		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
@@ -204,7 +204,7 @@ create_identity_tab (IdentityEditDialog *d)
 	/* spacer between "profile information" and "required information" */
 	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 	gtk_widget_set_usize (w, 0u, 6u);
-	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
+	gtk_table_attach (GTK_TABLE(t), w, 0, 4, row, row+1, 0, 0, 0, 0);
 	++row;
 
 		/* title for profile info section */
@@ -218,12 +218,12 @@ create_identity_tab (IdentityEditDialog *d)
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+2);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+2, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+2);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+2, 0, 0, 0, 0);
 
 		l = gtk_label_new_with_mnemonic (_("_Reply-To Header:"));
 		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
