@@ -18,7 +18,7 @@
  */
 
 #include <gtk/gtkwindow.h>
-#include <pan/rules/rule.h>
+#include <pan/identities/identity.h>
 
 /*
 ** Ugly as sin. Need to think of something better
