@@ -149,7 +149,7 @@ static void
 mark_default_or_not (IdentityListDialog   * d,
                      gchar               ** default_id_name,
                      gchar                * id_name,
-                     gchar                  is_default)
+                     gboolean               is_default)
 {
 	/* If there's only one identity, it's always the default */
 
