@@ -17,6 +17,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <config.h>
+
 #include <stdlib.h>
 #include <errno.h>
 #include <string.h>
@@ -428,7 +430,7 @@ identity_xml_read (const gchar  * filename,
 			{
 				xmlChar * val;
 
-				if ((val = xmlGetProp (cur, "default_name")) != NULL) {
+				if ((val = xmlGetProp (cur, "default_news")) != NULL) {
 					replace_gstr (default_news_id, g_strdup (val));
 					xmlFree (val);
 				}
