@@ -1,11 +1,11 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Pan - A Newsreader for X
- * Copyright (C) 2000, 2001  Pan Development Team <pan@rebelbase.com>
+ * Pan - A Newsreader for Gtk+
+ * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation; version 2 of the License.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,14 +15,14 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * 
  */
 
 #include <config.h>
 
 #include <glib.h>
-#include <libgnomeui/libgnomeui.h>
+#include <gtk/gtk.h>
 
+#include <pan/base/argset.h>
 #include <pan/base/pan-i18n.h>
 
 #include <pan/message-check-ui.h>
@@ -35,53 +35,44 @@ typedef struct
 	GtkWidget * window;
 
 	Server * server;
-	Article * article;
+	GMimeMessage * message;
 
 	GoodnessLevel goodness;
 	GPtrArray * errors;
 
-	ArticleCheckedFunc checked_func;
+	MessageCheckedFunc checked_func;
 	gpointer checked_func_user_data;
 }
 CheckedCallbackStruct;
 
 static void
-cleanup (CheckedCallbackStruct * cbs)
+warning_response_cb (GtkDialog * dialog, int response, gpointer user_data)
 {
-	group_unref_articles (cbs->article->group, NULL);
+	CheckedCallbackStruct * cbs = (CheckedCallbackStruct*) user_data;
+
+	/* if user hit `yes, go ahead' then change the goodness from WARN to OKAY */
+	if (response==GTK_RESPONSE_YES)
+		cbs->goodness = OKAY;
+
+	/* let the user know that it's changed */
+	(cbs->checked_func)(cbs->server, cbs->message, cbs->goodness, cbs->checked_func_user_data);
+
+	/* cleanup */
+	gtk_widget_destroy (GTK_WIDGET(dialog));
+	g_object_unref (cbs->message);
 	pan_g_ptr_array_foreach (cbs->errors, (GFunc)g_free, NULL);
 	g_ptr_array_free (cbs->errors, TRUE);
 	g_free (cbs);
 }
 
-static void
-error_response_cb (GnomeDialog * dialog, int button, gpointer user_data)
-{
-	CheckedCallbackStruct * cbs = (CheckedCallbackStruct*) user_data;
-
-	(cbs->checked_func)(cbs->server, cbs->article, cbs->goodness, cbs->checked_func_user_data);
-
-	cleanup (cbs);
-}
-
-static void
-warning_response_cb (GnomeDialog * dialog, int response, gpointer user_data)
-{
-	CheckedCallbackStruct * cbs = (CheckedCallbackStruct*) user_data;
-
-	if (response==0) /* yes, post anyway */
-		cbs->goodness = OKAY;
-
-	(cbs->checked_func)(cbs->server, cbs->article, cbs->goodness, cbs->checked_func_user_data);
-
-	cleanup (cbs);
-}
-
-static gint
-dialog_cb (gpointer user_data)
+static int
+post_warning_cb (gpointer user_data)
 {
 	guint i;
 	GString * str;
+	GtkWidget * w;
+	GtkMessageType message_type;
+	GtkButtonsType buttons_type;
 	CheckedCallbackStruct * cbs = (CheckedCallbackStruct*) user_data;
 
 	/* build the error message */
@@ -91,46 +82,45 @@ dialog_cb (gpointer user_data)
 		g_string_append (str, e);
 		g_string_append_c (str, '\n');
 	}
+	g_warning (str->str);
 
-	/* create the dialog */
 	if (cbs->goodness == WARN)
 	{
-		GtkWidget * w;
-
 		/* make sure the user wants to proceed. */
 		const gchar *ques = cbs->errors->len > 1
 			? _("Post anyway, despite these problems?")
 			: _("Post anyway, despite this problem?");
 		g_string_append (str, "\n");
-		g_string_append (str, ques);
-
-		pan_lock ();
-		w = gnome_question_dialog_parented  (str->str, NULL, cbs, GTK_WINDOW(cbs->window));
-		gtk_signal_connect (GTK_OBJECT(w), "clicked", warning_response_cb, cbs);
-		gtk_widget_show (w);
-		pan_unlock ();
+			g_string_append (str, ques);
+			buttons_type = GTK_BUTTONS_YES_NO;
+			message_type = GTK_MESSAGE_QUESTION;
 	}
 	else
 	{
-		GtkWidget * w;
-
-		pan_lock ();
-		w = gnome_error_dialog_parented (str->str, GTK_WINDOW(cbs->window));
-		gtk_signal_connect (GTK_OBJECT(w), "clicked", error_response_cb, cbs);
-		gtk_widget_show (w);
-		pan_unlock ();
+		/* I'm not asking you, I'm _telling_ you. ;) */
+		buttons_type = GTK_BUTTONS_OK;
+		message_type = GTK_MESSAGE_ERROR;
 	}
 
+	/* create a warning dialog... */
+	w = gtk_message_dialog_new (GTK_WINDOW(cbs->window),
+	                            GTK_DIALOG_DESTROY_WITH_PARENT,
+	                            message_type,
+	                            buttons_type,
+	                            "%s", str->str);
+	g_signal_connect (w, "response", G_CALLBACK(warning_response_cb), cbs);
+	gtk_widget_show_all (w);
+
 	/* cleanup */
 	g_string_free (str, TRUE);
 	return 0;
 }
 
 void
-check_article_and_prompt (GtkWidget           * window,
+message_check_and_prompt (GtkWidget           * window,
                           Server              * server,
-                          Article             * article,
-                          ArticleCheckedFunc    checked_func,
+                          GMimeMessage        * message,
+                          MessageCheckedFunc    checked_func,
                           gpointer              checked_func_user_data)
 {
 	GoodnessLevel goodness;
@@ -139,16 +129,16 @@ check_article_and_prompt (GtkWidget           * window,
 	/* sanity clause */
 	g_return_if_fail (GTK_IS_WINDOW(window));
 	g_return_if_fail (server_is_valid (server));
-	g_return_if_fail (article!=NULL); /* not article_is_valid(); let check_article check for subject */
+	g_return_if_fail (GMIME_IS_MESSAGE(message));
 
-	/* check the article */
+	/* check the message */
 	goodness = OKAY;
        	errors = g_ptr_array_new ();
-	check_article (article, server, errors, &goodness);
+	message_check (message, server, errors, &goodness);
 
 	if (goodness == OKAY)
 	{
-		(*checked_func)(server, article, goodness, checked_func_user_data);
+		(*checked_func)(server, message, goodness, checked_func_user_data);
 		g_ptr_array_free (errors, TRUE);
 	}
 	else
@@ -157,13 +147,12 @@ check_article_and_prompt (GtkWidget           * window,
 		cbs = g_new0 (CheckedCallbackStruct, 1);
 		cbs->window = window;
 		cbs->server = server;
-		cbs->article = article;
+		cbs->message = message;
 		cbs->goodness = goodness;
 		cbs->errors = errors;
 		cbs->checked_func = checked_func;
 		cbs->checked_func_user_data = checked_func_user_data;
-		gui_queue_add (dialog_cb, cbs);
-
-		group_ref_articles (article->group, NULL);
+		g_object_ref (message);
+		gui_queue_add (post_warning_cb, cbs);
 	}
 }
