@@ -309,7 +309,7 @@ static GtkItemFactoryEntry post_menu_entries [] =
 static char*
 menu_translate (const char* path, gpointer data)
 {
-	return gettext (path);
+	return (char*) gettext (path);
 }
 
 static GtkWidget*
@@ -455,8 +455,6 @@ create_reply_body (GMimeMessage * message)
 	/* build each quoted line */
 	march = reply_portion;
 	while (get_next_token_run (march, '\n', &march, &line, &line_len)) {
-		if (!marked && line_len>=3 && (!strncmp(line,"-- ",3) || !strncmp(line,"-- \r",4)))
-			break;
 		g_string_append (out, *line=='>' ? ">" : "> ");
 		g_string_append_len (out, line, line_len);
 		g_string_append_c (out, '\n');
@@ -1255,7 +1253,19 @@ message_gen_attribution_string (GMimeMessage    * message,
 	/* substitutions: author */
 	if (strstr (attribution_line, "%a")) {
 		const char * cpch = g_mime_message_get_header (message, HEADER_FROM);
-		pan_g_string_replace (gstr, "%a", cpch);
+		char * author_utf8 = NULL;
+		const Group * group = articlelist_get_group ();
+		const char * charset = group ? group_get_default_charset (group) : get_charset_from_locale ();
+
+		author_utf8 = pan_header_to_utf8 (cpch, -1, charset);
+		if (author_utf8 != NULL) {
+			pan_g_string_replace (gstr, "%a", author_utf8);
+			g_free (author_utf8);
+		}
+		else {
+			pan_g_string_replace (gstr, "%a", cpch);
+			log_add_va (LOG_ERROR, _("Could not convert \"%s\" to UTF-8. Article may not display correctly."), cpch);
+		}
 	}
 
 	/* attribution */
@@ -1359,70 +1369,27 @@ prepend_attribution_line (Compose      * compose,
 **** SIGNATURE
 ***/
 
-static void
-remove_signature (GtkTextBuffer * body_buffer)
+static char *
+load_signature (const char * sig_file)
 {
-	GtkTextIter start;
-	GtkTextIter end;
-	char * text;
-	char * index;
-
-	/* sanity clause */
-	g_return_if_fail (body_buffer!=NULL);
-	g_return_if_fail (GTK_IS_TEXT_BUFFER(body_buffer));
-
-	/* get the text buffer */
-	gtk_text_buffer_get_bounds (body_buffer, &start, &end);
-	text = gtk_text_buffer_get_text (body_buffer, &start, &end, FALSE);
-
-	if (!strncmp (text, "-- \r\n", 5) ||
-	    !strncmp (text, "-- \n", 4))
-		index = text;
-	else
-	{
-		index = pan_strstr (text, "\n-- \n");
-		if (index == NULL)
-			index = pan_strstr (text, "\n-- \r"); 
-	}	
-
-	if (index)
-	{
-		*index = 0;
-		update_body_pane (body_buffer, text, FALSE);
-	}
-
-	g_free (text);
-}
-
-static void
-append_signature (GtkTextBuffer * body_buffer, const char *sig_file)
-{
-	char * sig = NULL;
 	char * pch;
+	char * sig = NULL;
+	GError * err = NULL;
+	int argc = 0;
+	char ** argv = NULL;
 
-	/* sanity clause */
-	g_return_if_fail (body_buffer!=NULL);
-	g_return_if_fail (GTK_IS_TEXT_BUFFER(body_buffer));
-	g_return_if_fail (sig_file!=NULL);
-
-	/* since we're applying a signature, remove any signature anyway */
-	remove_signature (body_buffer);
-
-        /* load the signature */	
+	/* process file name */
 	pch = g_strdup (sig_file);
 	g_strstrip (pch);
 	if (is_nonempty_string (pch))
 	{
-		GError * err = NULL;
-		int argc = 0;
-		char ** argv = NULL;
-
 		/* expand the home directory character */
-		if (*pch=='~')
-			replace_gstr (&pch, g_strconcat (g_get_home_dir(), pch+1, NULL));
+		if (*pch=='~') 
+			replace_gstr (&pch, g_build_filename (g_get_home_dir(), pch+1, NULL));
+
 		/* if not an absolute path, assume in home directory */
-		if (*pch!=G_DIR_SEPARATOR)
-			replace_gstr (&pch, g_strdup_printf ("%s%c%s", g_get_home_dir(), G_DIR_SEPARATOR, pch));
+		if (!g_path_is_absolute (pch))
+			replace_gstr (&pch, g_build_filename (g_get_home_dir(), pch, NULL));
 
 		if (!g_shell_parse_argv (pch, &argc, &argv, &err))
 		{
@@ -1435,56 +1402,110 @@ append_signature (GtkTextBuffer * body_buffer, const char *sig_file)
 		{
 			log_add_va (LOG_ERROR, _("Couldn't parse signature command \"%s\""), pch);
 		}
-		else
+	}
+
+	/* get signature */
+	if (argv && is_nonempty_string(argv[0]))
+	{
+		if (g_file_test (argv[0], G_FILE_TEST_IS_EXECUTABLE))
 		{
-			if (g_file_test (argv[0], G_FILE_TEST_IS_EXECUTABLE))
-			{
-				int exit_status = 0;
-				char * standard_output = NULL;
-				char * standard_error = NULL;
+			int exit_status = 0;
+			char * standard_output = NULL;
+			char * standard_error = NULL;
 
-				if (!g_spawn_sync (NULL, argv, NULL, 0, NULL, NULL, &standard_output, &standard_error, &exit_status, &err))
-				{
-					log_add_va (LOG_ERROR, _("Couldn't run signature program \"%s\": %s"), pch, err->message);
-					g_error_free (err);
-					err = NULL;
-				}
-				else
-				{
-					sig = strdup (is_nonempty_string (standard_output) ? standard_output : standard_error);
-					replace_gstr (&standard_output, NULL);
-					replace_gstr (&standard_error, NULL);
-				}
+			if (!g_spawn_sync (NULL, argv, NULL, 0, NULL, NULL, &standard_output, &standard_error, &exit_status, &err))
+			{
+				log_add_va (LOG_ERROR, _("Couldn't run signature program \"%s\": %s"), pch, err->message);
+				g_error_free (err);
+				err = NULL;
 			}
-
-			if (!sig)
+			else
 			{
-				GError * err = NULL;
-				if (!g_file_get_contents (argv[0], &sig, NULL, &err))
-				{
-					log_add_va (LOG_ERROR, _("Couldn't read signature file \"%s\": %s"), pch, err->message);
-					g_error_free (err);
-				}
-
+				sig = g_strdup (is_nonempty_string (standard_output) ? standard_output : standard_error);
+				replace_gstr (&standard_output, NULL);
+				replace_gstr (&standard_error, NULL);
 			}
 		}
 
-		/* cleanup */
-		g_strfreev (argv);
-	}
+		if (!sig)
+		{
+			GError * err = NULL;
+			if (!g_file_get_contents (argv[0], &sig, NULL, &err))
+			{
+				log_add_va (LOG_ERROR, _("Couldn't read signature file \"%s\": %s"), pch, err->message);
+				g_error_free (err);
+			}
 
-	g_free (pch);
+		}
+	}
 
 	/* Convert signature to UTF-8. Since the signature is a local file, */
 	/* we assume the contents is in the user's locale's charset.        */
+	/* If we can't convert, clear the signature. Otherwise, we'd add an */
+	/* charset-encoded sig (say 'iso-8859-1') to the body (in UTF-8),   */
+	/* which could result in a blank message in the composer window.    */
 	if (sig!=NULL)
 	{
+		const char * sig_utf8 = NULL;
 		char * freeme = NULL;
-		pan_utf8ize (sig, -1, &freeme);
-		if (freeme != NULL)
-			replace_gstr (&sig, freeme);
+		sig_utf8 = pan_utf8ize (sig, -1, &freeme);
+		if (sig_utf8 != NULL) {
+			replace_gstr (&sig, g_strdup (sig_utf8));
+			g_free (freeme);
+		}
+		else {
+			log_add_va (LOG_ERROR, _("Could not convert signature file '%s' to UTF-8. Signature must be in '%s'"), pch, g_mime_charset_locale_name ());
+			g_free (sig);
+			sig = NULL;
+		}
 	}
-	 
+
+	/* Cleanup */
+	g_strfreev (argv);
+	g_free (pch);
+
+	return sig;
+}
+
+static void
+remove_signature (GtkTextBuffer * body_buffer)
+{
+	GtkTextIter start;
+	GtkTextIter end;
+	char * text;
+
+	/* sanity clause */
+	g_return_if_fail (body_buffer!=NULL);
+	g_return_if_fail (GTK_IS_TEXT_BUFFER(body_buffer));
+
+	/* get the text buffer */
+	gtk_text_buffer_get_bounds (body_buffer, &start, &end);
+	text = gtk_text_buffer_get_text (body_buffer, &start, &end, FALSE);
+
+	if (pan_remove_signature (text))
+	{
+		update_body_pane (body_buffer, text, FALSE);
+	}
+
+	g_free (text);
+}
+
+static void
+append_signature (GtkTextBuffer * body_buffer, const char *sig_file)
+{
+	char * sig = NULL;
+
+	/* sanity clause */
+	g_return_if_fail (body_buffer!=NULL);
+	g_return_if_fail (GTK_IS_TEXT_BUFFER(body_buffer));
+	g_return_if_fail (sig_file!=NULL);
+
+	/* since we're applying a signature, remove any signature anyway */
+	remove_signature (body_buffer);
+
+        /* load the signature */	
+	sig = load_signature (sig_file);
+
 	/* append the signature */
 	if (sig!=NULL)
 	{
@@ -2110,6 +2131,7 @@ create_body_pane_nolock (Compose * mw)
 	gtk_text_buffer_create_tag (buf, "quote_1", "foreground_gdk", NULL, NULL);
 	gtk_text_buffer_create_tag (buf, "quote_2", "foreground_gdk", NULL, NULL);
 	gtk_text_buffer_create_tag (buf, "quote_3", "foreground_gdk", NULL, NULL);
+	gtk_text_buffer_create_tag (buf, "signature", "foreground_gdk", NULL, NULL);
 
 	pan_widget_set_font (mw->body_view, message_body_font_fixed);
 	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW(mw->body_view), GTK_WRAP_NONE);
@@ -2599,12 +2621,11 @@ static gboolean
 check_charset_for_body (Compose * mw)
 {
 	GtkTextIter start, end;
-	const char * utf8_body = NULL;
 	const char * charset = NULL;
+	char       * utf8_body = NULL;
 	char       * body = NULL;
 	gboolean     ok = TRUE;
 
-
 	/* get settings */
 	gtk_text_buffer_get_bounds (mw->body_buffer, &start, &end);
 	utf8_body = gtk_text_buffer_get_text (mw->body_buffer, &start, &end, FALSE);
@@ -2630,6 +2651,7 @@ check_charset_for_body (Compose * mw)
 
 	/* cleanup */
 	g_free (body);
+	g_free (utf8_body);
 
 	return ok;
 }
@@ -2805,12 +2827,20 @@ message_window_save_ok_clicked (GtkWidget * widget, GtkWidget * file_entry)
 	mw = (const Compose*) gtk_object_get_data (GTK_OBJECT(file_entry), "mw");
 	filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_entry));
 
+	/* create output file */
+	fp = fopen (filename, "w");
+	if (fp == NULL)
+	{
+		if (errno != EISDIR)
+			pan_error_dialog (_("Can't create file \"%s\" %s"), filename, g_strerror(errno));
+		return;
+	}
+
 	/* build the message ... */
 	message = g_mime_message_new (FALSE);
 	populate_message_from_mw (message, mw);
 
 	/* save the message ... */
-	fp = fopen (filename, "w");
 	stream = g_mime_stream_file_new (fp);
 	g_mime_message_write_to_stream (message, stream);
 
