@@ -173,23 +173,19 @@ nntp_command_va (StatusItem           * status,
 ***
 **/
 
-gint
+void
 nntp_disconnect (StatusItem   * status,
                  PanSocket    * socket)
 {
-	const gchar * reply;
-	gint val;
 	debug_enter ("nntp_disconnect");
 
 	/* entry assertions */
-	g_return_val_if_fail (socket!=NULL, TASK_FAIL_HOPELESS);
+	g_return_if_fail (socket!=NULL);
 
-	/* try to disconnect */
-	val = nntp_command (status, socket, &reply, "QUIT");
-	if (val != 205) {
-		status_item_emit_error_va (status, _("QUIT failed: %s"), reply);
-		return val==-1 ? TASK_FAIL : TASK_FAIL_HOPELESS;
-	}
+	/* try to disconnect.  We don't look for the response, since we don't
+	 * know what's in this socket.  It could be dead, or it could still have
+	 * crap in the read buffer, mangling the response number. */
+	pan_socket_putline (socket, "QUIT\r\n");
 
 	/* Flush the socket. This ensures any remaining data (like TCP closing 
 	 * packets) are read between sending the NNTP command (which makes the 
@@ -201,7 +197,6 @@ nntp_disconnect (StatusItem   * status,
 
 	/* disconnected successfully */
 	debug_exit ("nntp_disconnect");
-	return TASK_SUCCESS;
 }
 
 /**
@@ -238,7 +233,7 @@ nntp_handshake (StatusItem  * status,
 
 	/* yes, we also support authentication on demand, but it appears
 	   many servers are happier if we ask for authentication up-front. */
-	if (socket->need_auth)
+	if (pan_socket_needs_auth (socket))
 		val = nntp_authenticate (status, socket);
 
 	/* Achim Settelmeir reports that his local INN doesn't accept GROUP
@@ -278,7 +273,7 @@ nntp_spa_authenticate (StatusItem     * status,
 		return TASK_FAIL;
 	}
 	
-	spa_build_auth_request (&spa_request, sock->nntp_username, NULL);
+	spa_build_auth_request (&spa_request, pan_socket_get_username(sock), NULL);
 	spa_bits_to_base64 (msgbuf, (unsigned char*)&spa_request, 
 		spa_request_length (&spa_request));
 
@@ -291,7 +286,7 @@ nntp_spa_authenticate (StatusItem     * status,
 		return TASK_FAIL;
 	}
 
-	if (!is_nonempty_string(sock->nntp_password)) {
+	if (!is_nonempty_string(pan_socket_get_password(sock))) {
 		if (status != NULL)
 			status_item_emit_error_va (status, _(
 				"Authentication failed: need a password"));
@@ -305,7 +300,8 @@ nntp_spa_authenticate (StatusItem     * status,
 	spa_base64_to_bits ((unsigned char*)&spa_challenge, response_trim);
 
 	spa_build_auth_response (&spa_challenge, &spa_response, 
-		sock->nntp_username, sock->nntp_password);
+		pan_socket_get_username(sock),
+		pan_socket_get_password(sock));
 
 	spa_bits_to_base64 (msgbuf, (unsigned char*)&spa_response, 
 		spa_request_length (&spa_response));
@@ -337,7 +333,7 @@ nntp_authenticate_types (StatusItem     * status,
 	/* entry assertions */
 	g_return_val_if_fail (status!=NULL, TASK_FAIL);
 	g_return_val_if_fail (sock!=NULL, TASK_FAIL);
-	g_return_val_if_fail (sock->nntp_username!=NULL, TASK_FAIL_HOPELESS);
+	g_return_val_if_fail (pan_socket_get_username(sock)!=NULL, TASK_FAIL_HOPELESS);
 
 	/* check for authentication schemes */
 	/* see: http://www.mibsoftware.com/userkt/nntpext/0035.htm */
@@ -375,7 +371,7 @@ nntp_authenticate_types (StatusItem     * status,
 	}
 
 	/* set the username */
-	val = nntp_command_va (status, sock, &response, "AUTHINFO USER %s", sock->nntp_username);
+	val = nntp_command_va (status, sock, &response, "AUTHINFO USER %s", pan_socket_get_username(sock));
 
 	/* On servers that require SPA authentication, sending			*/
 	/* "AUTHINFO USER ..." seems to result in a 502 error. If we	*/
@@ -395,12 +391,13 @@ nntp_authenticate_types (StatusItem     * status,
 
 	/* set the password, if required */
 	if (val==NEED_AUTHDATA) {
-		if (!is_nonempty_string(sock->nntp_password)) {
+		const char * password = pan_socket_get_password (sock);
+		if (!is_nonempty_string(password)) {
 			if (status != NULL)
 				status_item_emit_error_va (status, _("Authentication failed: need a password"));
 			return TASK_FAIL;
 		}
-		val = nntp_command_va (status, sock, &response, "AUTHINFO PASS %s", sock->nntp_password);
+		val = nntp_command_va (status, sock, &response, "AUTHINFO PASS %s", password);
 	}
 
 	/* if we failed, emit an error */	
@@ -477,7 +474,7 @@ nntp_set_group (StatusItem   * status,
 	g_return_val_if_fail (is_nonempty_string(group_name), TASK_FAIL_HOPELESS);
 
 	/* we're already there */
-	if (!pan_strcmp (sock->nntp_group_name, group_name))
+	if (!pan_strcmp (pan_socket_get_current_group(sock), group_name))
 		return TASK_SUCCESS;
 
 	/* change to that group */
@@ -488,7 +485,7 @@ nntp_set_group (StatusItem   * status,
 	}
 
 	/* update this socket's current group */
-	replace_gstr (&sock->nntp_group_name, g_strdup(group_name));
+	pan_socket_set_current_group (sock, group_name);
 	return TASK_SUCCESS;
 }
 
@@ -555,7 +552,7 @@ nntp_noop (StatusItem    * status,
 	g_return_val_if_fail (socket!=NULL, TASK_FAIL);
 
 	/* do work */
-	status_item_emit_status_va (status, _("\"stay connected\" sent to %s"), socket->host_name); 
+	status_item_emit_status_va (status, _("\"stay connected\" sent to %s"), pan_socket_get_server_name(socket));
 	return nntp_can_post (status, socket, &can_post);
 }
 
@@ -591,7 +588,7 @@ nntp_article_download (StatusItem         * status,
 		status_item_emit_status (status, mid->message_id);
 
 	/* change to the group we want */
-	source = message_identifier_get_source_for_server (mid, sock->host_name);
+	source = message_identifier_get_source_for_server (mid, pan_socket_get_server_name(sock));
 	if (*abort || !source)
 		return TASK_FAIL;
 	result = nntp_set_group (status, sock, source->group_name);
@@ -724,7 +721,7 @@ nntp_get_group_info (StatusItem       * status,
 
 	/* success; parse the results */
 	sscanf (response, "%*d %lu %lu %lu", article_qty, low_num, high_num);
-	replace_gstr (&sock->nntp_group_name, g_strdup(group_name));
+	pan_socket_set_current_group (sock, group_name);
 	return TASK_SUCCESS;
 }
 
@@ -866,18 +863,16 @@ nntp_download_headers (StatusItem       * status,
 
 		/* get references */
 		if (get_next_token_run (march, '\t', &march, &tok, &tok_len)) {
+			((char*)tok)[tok_len] = '\0';
 			g_strstrip ((char*)tok);
-			if (tok_len>0 ) {
-				((gchar*)tok)[tok_len] = '\0';
-				if (is_nonempty_string(tok) && *tok=='<')
-					article_init_header (a, HEADER_REFERENCES, tok, DO_CHUNK_SHARE);
-			}
+			if (is_nonempty_string(tok) && *tok=='<')
+				article_init_header (a, HEADER_REFERENCES, tok, DO_CHUNK_SHARE);
 		}
 
-		/* get unused field: size */
-		skip_next_token (march, '\t', &march);
+		/* get byte qty */
+		a->byte_qty = get_next_token_ulong (march, '\t', &march);
 
-		/* get linecount */
+		/* get line qty */
 		a->linecount = get_next_token_int (march, '\t', &march);
 
 		/* get crossref */
