@@ -60,7 +60,7 @@ int    nntp_authenticate_types   (StatusItem           * status,
                                   PanSocket            * socket,
                                   gboolean              check_auth_types);
 
-int    nntp_disconnect           (StatusItem           * status,
+void   nntp_disconnect           (StatusItem           * status,
                                   PanSocket            * socket);
 
 int    nntp_noop                 (StatusItem           * status,
