@@ -248,8 +248,6 @@ main (int argc, char *argv[])
 		           "stdout instead of smtp/nntp server");
 
 	queue_init (pan_config_get_bool ("/Pan/General/Online=TRUE"),
-	            pan_config_get_int  ("/Pan/General/Max_Connections_Total=4"),
-	            pan_config_get_int  ("/Pan/General/Max_Task_Tries_Total=4"),
 	            pan_config_get_bool ("/Pan/General/remove_failed_tasks=TRUE"));
 
 	/* if it's a new user, pop up the newuser dialog.
@@ -278,7 +276,9 @@ main (int argc, char *argv[])
 			g_free (tasks_filename);
 	}
 
+	gdk_threads_enter();
 	gtk_main ();
+	gdk_threads_leave();
 
 	return 0;
 }
