@@ -71,7 +71,8 @@ typedef struct
 
 	/* general */
 	GtkWidget * online_on_startup_cbutton;
-	GtkWidget * single_click_selects_cbutton;
+	GtkWidget * single_click_selects_groups_cbutton;
+	GtkWidget * single_click_selects_headers_cbutton;
 	GtkWidget * remove_failed_tasks_cbutton;
 	GtkWidget * fetch_new_on_group_load_cbutton;
 	GtkWidget * fetch_new_on_startup_cbutton;
@@ -96,12 +97,15 @@ typedef struct
 	GtkWidget * message_lb;
 	GtkWidget * message_gfp;
 	GtkWidget * message_fixed_gfp;
+	GtkWidget * read_pcp;
+	GtkWidget * unread_pcp;
 	GtkWidget * ignored_pcp;
 	GtkWidget * watched_pcp;
 	GtkWidget * text_fg_pcp;
 	GtkWidget * text_bg_pcp;
 	GtkWidget * text_url_pcp;
 	GtkWidget * text_quoted_pcp[3];
+	GtkWidget * signature_pcp;
 	GtkWidget * text_quoted_chars_entry;
 	GtkWidget * thread_date_entry;
 	GtkWidget * smooth_scrolling_check;
@@ -110,10 +114,6 @@ typedef struct
 	/* layout */
 	GtkWidget * layout_page;
 	GtkWidget * display_page;
-
-	/* connections */
-	GtkWidget  * max_connections;
-	GtkWidget  * max_tries;
 }
 PrefsWindow;
 
@@ -144,7 +144,8 @@ gboolean fetch_new_on_group_load              = TRUE;
 gboolean fetch_new_on_startup                 = FALSE;
 gboolean fetch_new_and_bodies_on_startup      = FALSE;
 gboolean header_pane_is_threaded              = TRUE;
-gboolean single_click_selects                 = FALSE;
+gboolean single_click_selects_groups          = FALSE;
+gboolean single_click_selects_headers         = FALSE;
 gboolean show_group_pane                      = TRUE;
 gboolean show_header_pane                     = TRUE;
 gboolean show_body_pane                       = TRUE;
@@ -387,6 +388,8 @@ prefs_apply (void)
 	**/
 
 	/* update the articlelist colors */
+	articlelist_changed |= handle_color_picker ("read_color", &read_color, win->read_pcp);
+	articlelist_changed |= handle_color_picker ("unread_color", &unread_color, win->unread_pcp);
 	articlelist_changed |= handle_color_picker ("killfile_color", &killfile_color, win->ignored_pcp);
 	articlelist_changed |= handle_color_picker ("watched_color", &watched_color, win->watched_pcp);
 
@@ -396,6 +399,7 @@ prefs_apply (void)
 	b |= handle_color_picker ("text_quoted_color_1", &text_quoted_color[0], win->text_quoted_pcp[0]);
 	b |= handle_color_picker ("text_quoted_color_2", &text_quoted_color[1], win->text_quoted_pcp[1]);
 	b |= handle_color_picker ("text_quoted_color_3", &text_quoted_color[2], win->text_quoted_pcp[2]);
+	b |= handle_color_picker ("signature_color", &signature_color, win->signature_pcp);
 	color_changed = b;
 
 	/* quote prefix characters */
@@ -413,6 +417,7 @@ prefs_apply (void)
 	if (color_changed)
 	{
 		GtkStyle * style;
+		GtkTextBuffer *text_buffer;
 
 		style = gtk_rc_get_style (Pan.text);
 
@@ -422,6 +427,11 @@ prefs_apply (void)
 		gtk_widget_set_style (Pan.text, style);
 
 		text_set_font ();
+		if (Pan.text)
+		{
+			text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(Pan.text));
+			text_set_text_buffer_tags (text_buffer);
+		}
 	}
 
 	update_entry_and_bool_from_toggle_button (
@@ -435,9 +445,14 @@ prefs_apply (void)
 		win->fetch_new_on_startup_cbutton);
 
 	update_entry_and_bool_from_toggle_button (
-		&single_click_selects,
-		"/Pan/General/single_click_selects",
-		win->single_click_selects_cbutton);
+		&single_click_selects_groups,
+		"/Pan/General/single_click_selects_groups",
+		win->single_click_selects_groups_cbutton);
+
+	update_entry_and_bool_from_toggle_button (
+		&single_click_selects_headers,
+		"/Pan/General/single_click_selects_headers",
+		win->single_click_selects_headers_cbutton);
 
 	pan_config_set_bool ("/Pan/General/Online",
 	                     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(win->online_on_startup_cbutton)));
@@ -564,28 +579,6 @@ prefs_apply (void)
 			queue_set_remove_failed_tasks (new_val);
 	}
 
-	/* maximum number of connections */
-	if (1) {
-		GtkSpinButton * sb = GTK_SPIN_BUTTON (win->max_connections);
-		const int i = gtk_spin_button_get_value_as_int (sb);
-		if (i != queue_get_max_sockets()) {
-			queue_set_max_sockets (i);
-			server_connections_changed = TRUE;
-			pan_config_set_int ("/Pan/General/Max_Connections_Total", i);
-		}
-	}
-
-	/* maximum number of tries */
-	if (1) {
-		GtkSpinButton * sb = GTK_SPIN_BUTTON (win->max_tries);
-		const int i = gtk_spin_button_get_value_as_int (sb);
-		if (i != queue_get_max_tries()) {
-			queue_set_max_tries (i);
-			server_connections_changed = TRUE;
-			pan_config_set_int ("/Pan/General/Max_Task_Tries_Total", i);
-		}
-	}
-
 	/* layout */
 	if (1) {
 		char * str = layout_get_new_string (win->layout_page);
@@ -642,7 +635,7 @@ prefs_init (void)
 	if (is_nonempty_string (download_dir))
 		ensure_trailing_slash (&download_dir);
 	else
-		download_dir = g_strdup_printf ("%s/News/Pan/", g_get_home_dir());
+		download_dir = g_build_filename (g_get_home_dir(), "News", "Pan", NULL);
 
 
 	acache_max_megs = pan_config_get_int ("/Pan/Cache/MaxMegs=10");
@@ -671,7 +664,8 @@ prefs_init (void)
 
 	/* general preferences */
 	pan_config_push_prefix ("/Pan/General/");
-	single_click_selects = pan_config_get_bool ("single_click_selects=FALSE");
+	single_click_selects_groups = pan_config_get_bool ("single_click_selects_groups=FALSE");
+	single_click_selects_headers = pan_config_get_bool ("single_click_selects_headers=FALSE");
 	wrap_column = pan_config_get_int ("wrap_column=74");
 	fetch_new_on_group_load = pan_config_get_bool ("fetch_new_on_group_load=TRUE");
 	fetch_new_on_startup = pan_config_get_bool ("fetch_new_from_subscribed_on_startup=FALSE");
@@ -736,12 +730,15 @@ prefs_init (void)
 	***  Colors
 	**/
 
+	set_color (&read_color,            "read_color",            40960, 40960, 40960);
+	set_color (&unread_color,          "unread_color",              0,     0,     0);
 	set_color (&killfile_color,        "killfile_color",        35723, 17733,  4883);
 	set_color (&watched_color,         "watched_color",             0, 52428,     0);
 	set_color (&text_url_color,        "text_url_color",            0,     0, 40000);
 	set_color (&text_quoted_color[0],  "text_quoted_color_1",   40000, 10000, 40000);
 	set_color (&text_quoted_color[1],  "text_quoted_color_2",   50000,     0,  2000);
 	set_color (&text_quoted_color[2],  "text_quoted_color_3",   45000, 28000,     0);
+	set_color (&signature_color, 	   "signature_color",	    45000, 28000,     0);
 
 	base_prefs_init (download_dir,
 	                 text_quote_chars,
@@ -782,7 +779,6 @@ tasks_page (void)
 	GtkWidget * w;
 	GtkWidget * h;
 	GtkWidget * l;
-	GtkAdjustment * adj;
 	char buf[512];
 	char * p;
 
@@ -790,6 +786,120 @@ tasks_page (void)
 	t = gtk_table_new (4, 16, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE(t), 6);
 
+	/* title for profile info section */
+	g_snprintf (buf, sizeof(buf), "<b>%s</b>", _("Mouse Behavior"));
+	w = gtk_label_new (buf);
+	gtk_misc_set_alignment (GTK_MISC(w), 0.0f, 0.5f);
+	gtk_label_set_use_markup (GTK_LABEL(w), TRUE);
+	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
+	++row;
+
+		items_in_section = 2;
+	
+		/* spacer to move the fields a little to the right of the name header */
+		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
+		gtk_widget_set_usize (w, 18u, 0u);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
+
+		/* mouse behavior - group pane */
+		w = gtk_check_button_new_with_mnemonic (_("single-clic_k selects, rather than loads, groups"));
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), single_click_selects_groups);
+		connect_signal_to_prefs_changed (w, "toggled");
+		win->single_click_selects_groups_cbutton = w;
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
+		++row;
+
+		/* mouse behavior - header pane */
+		w = gtk_check_button_new_with_mnemonic (_("_single-click selects, rather than loads, headers"));
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), single_click_selects_headers);
+		connect_signal_to_prefs_changed (w, "toggled");
+		win->single_click_selects_headers_cbutton = w;
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
+		++row;
+
+	/* section spacer */
+	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
+	gtk_widget_set_usize (w, 0u, 6u);
+	gtk_table_attach (GTK_TABLE(t), w, 0, 4, row, row+1, 0, 0, 0, 0);
+	++row;
+
+	/* title for profile info section */
+	g_snprintf (buf, sizeof(buf), "<b>%s</b>", _("Automatic Downloads"));
+	w = gtk_label_new (buf);
+	gtk_misc_set_alignment (GTK_MISC(w), 0.0f, 0.5f);
+	gtk_label_set_use_markup (GTK_LABEL(w), TRUE);
+	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
+	++row;
+
+		items_in_section = 3;
+	
+		/* spacer to move the fields a little to the right of the name header */
+		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
+		gtk_widget_set_usize (w, 18u, 0u);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
+
+		/* download new headers */
+		w = gtk_check_button_new_with_mnemonic (
+			_("Download new headers when loading a _group"));
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), fetch_new_on_group_load);
+		connect_signal_to_prefs_changed (w, "toggled");
+		win->fetch_new_on_group_load_cbutton = w;
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
+		++row;
+
+		/* download new headers on startup */
+		w = gtk_check_button_new_with_mnemonic (
+			_("Download new headers from _subscribed groups when starting Pan"));
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), fetch_new_on_startup);
+		connect_signal_to_prefs_changed (w, "toggled");
+		win->fetch_new_on_startup_cbutton = w;
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
+		++row;
+
+		/* download new headers and bodies on startup */
+		w = gtk_check_button_new_with_mnemonic (
+			_("Download new headers and bod_ies from subscribed groups when starting Pan"));
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), fetch_new_and_bodies_on_startup);
+		connect_signal_to_prefs_changed (w, "toggled");
+		win->fetch_new_and_bodies_on_startup_cbutton = w;
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
+		++row;
+
+	/* section spacer */
+	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
+	gtk_widget_set_usize (w, 0u, 6u);
+	gtk_table_attach (GTK_TABLE(t), w, 0, 4, row, row+1, 0, 0, 0, 0);
+	++row;
+
+	/* title for profile info section */
+	g_snprintf (buf, sizeof(buf), "<b>%s</b>", _("Online"));
+	w = gtk_label_new (buf);
+	gtk_misc_set_alignment (GTK_MISC(w), 0.0f, 0.5f);
+	gtk_label_set_use_markup (GTK_LABEL(w), TRUE);
+	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
+	++row;
+
+		items_in_section = 1;
+	
+		/* spacer to move the fields a little to the right of the name header */
+		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
+		gtk_widget_set_usize (w, 18u, 0u);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
+
+		/* download new headers */
+		w = gtk_check_button_new_with_mnemonic (_("Start Pan in _online mode"));
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), pan_config_get_bool ("/Pan/General/Online=TRUE"));
+		connect_signal_to_prefs_changed (w, "toggled");
+		win->online_on_startup_cbutton = w;
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
+		++row;
+
+	/* section spacer */
+	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
+	gtk_widget_set_usize (w, 0u, 6u);
+	gtk_table_attach (GTK_TABLE(t), w, 0, 4, row, row+1, 0, 0, 0, 0);
+	++row;
+
 	/* title for profile info section */
 	g_snprintf (buf, sizeof(buf), "<b>%s</b>", _("Tasks"));
 	l = gtk_label_new (buf);
@@ -798,53 +908,27 @@ tasks_page (void)
 	gtk_table_attach_defaults (GTK_TABLE(t), l, 0, 4, row, row+1);
 	++row;
 
-		items_in_section = 4;
+		items_in_section = 3;
 	
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+items_in_section);
-
-		/* max connections total */
-		l = gtk_label_new_with_mnemonic (_("Ma_ximum connections:"));
-		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
-		gtk_table_attach_defaults (GTK_TABLE(t), l, 1, 2, row, row+1);
-
-		adj = (GtkAdjustment *) gtk_adjustment_new (128.0, 1.0, 128.0, 1.0, 1.0, 0.0);
-		win->max_connections = w = gtk_spin_button_new (adj, 0, 0);
-		gtk_label_set_mnemonic_widget (GTK_LABEL(l), w);
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (win->max_connections), queue_get_max_sockets());
-		connect_signal_to_prefs_changed (w, "changed");
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 3, 4, row, row+1);
-		++row;
-
-		/* task retries */
-		l = gtk_label_new_with_mnemonic (_("Maximum task retr_ies:"));
-		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
-		gtk_table_attach_defaults (GTK_TABLE(t), l, 1, 2, row, row+1);
-
-		adj = (GtkAdjustment *) gtk_adjustment_new (4.0, 1.0, 999.0, 1.0, 1.0, 0.0);
-		win->max_tries = w = gtk_spin_button_new (adj, 0, 0);
-		gtk_label_set_mnemonic_widget (GTK_LABEL(l), w);
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (win->max_tries), queue_get_max_tries());
-		connect_signal_to_prefs_changed (w, "changed");
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 3, 4, row, row+1);
-		++row;
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* download directory */
-		l = gtk_label_new_with_mnemonic (_("Do_wnload directory:"));
+		l = gtk_label_new_with_mnemonic (_("Save attachments in _directory:"));
 		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
 		gtk_table_attach_defaults (GTK_TABLE(t), l, 1, 2, row, row+1);
 
 		h = gtk_hbox_new (FALSE, GUI_PAD_SMALL);
 		w = win->dir_download = pan_file_entry_new (_("Download Directory"));
 		if ((p = pan_config_get_string ("/Pan/Paths/download_dir")) == NULL)
-			p = g_strdup_printf ("%s/News/Pan/", g_get_home_dir());
+			p = g_build_filename (g_get_home_dir(), "News", "Pan", NULL);
 		pan_file_entry_set (win->dir_download, p);
 		g_free (p);
 		gtk_label_set_mnemonic_widget (GTK_LABEL(l), pan_file_entry_gtk_entry(w));
@@ -865,92 +949,6 @@ tasks_page (void)
 		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
 		++row;
 
-	/* section spacer */
-	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
-	gtk_widget_set_usize (w, 0u, 6u);
-	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
-	++row;
-
-	/* title for profile info section */
-	g_snprintf (buf, sizeof(buf), "<b>%s</b>", _("Headers"));
-	w = gtk_label_new (buf);
-	gtk_misc_set_alignment (GTK_MISC(w), 0.0f, 0.5f);
-	gtk_label_set_use_markup (GTK_LABEL(w), TRUE);
-	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
-	++row;
-
-		items_in_section = 4;
-	
-		/* spacer to move the fields a little to the right of the name header */
-		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
-		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+items_in_section);
-
-		/* download new headers */
-		w = gtk_check_button_new_with_mnemonic (
-			_("Download _new headers from subscribed groups when starting Pan"));
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), fetch_new_on_startup);
-		connect_signal_to_prefs_changed (w, "toggled");
-		win->fetch_new_on_startup_cbutton = w;
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
-		++row;
-
-		/* download new headers and bodies */
-		w = gtk_check_button_new_with_mnemonic (
-			_("Download new headers and bo_dies from subscribed groups when starting Pan"));
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), fetch_new_and_bodies_on_startup);
-		connect_signal_to_prefs_changed (w, "toggled");
-		win->fetch_new_and_bodies_on_startup_cbutton = w;
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
-		++row;
-
-		/* download new headers */
-		w = gtk_check_button_new_with_mnemonic (
-			_("Download new headers when loading a _group"));
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), fetch_new_on_group_load);
-		connect_signal_to_prefs_changed (w, "toggled");
-		win->fetch_new_on_group_load_cbutton = w;
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
-		++row;
-
-		/* mouse behavior */
-		w = gtk_check_button_new_with_mnemonic (
-			_("Mouse single clic_k selects, rather than activates, groups and articles"));
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), single_click_selects);
-		connect_signal_to_prefs_changed (w, "toggled");
-		win->single_click_selects_cbutton = w;
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
-		++row;
-
-	/* section spacer */
-	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
-	gtk_widget_set_usize (w, 0u, 6u);
-	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
-	++row;
-
-	/* title for profile info section */
-	g_snprintf (buf, sizeof(buf), "<b>%s</b>", _("Online"));
-	w = gtk_label_new (buf);
-	gtk_misc_set_alignment (GTK_MISC(w), 0.0f, 0.5f);
-	gtk_label_set_use_markup (GTK_LABEL(w), TRUE);
-	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
-	++row;
-
-		items_in_section = 1;
-	
-		/* spacer to move the fields a little to the right of the name header */
-		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
-		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+items_in_section);
-
-		/* download new headers */
-		w = gtk_check_button_new_with_mnemonic (_("_Start Pan in online mode"));
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), pan_config_get_bool ("/Pan/General/Online=TRUE"));
-		connect_signal_to_prefs_changed (w, "toggled");
-		win->online_on_startup_cbutton = w;
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
-		++row;
-
 	return t;
 }
 
@@ -1019,12 +1017,12 @@ display_page (void)
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* break threads when subject changes? */
 		w = gtk_check_button_new_with_mnemonic (_("When a _Followup subject header changes, show as new thread"));
@@ -1077,7 +1075,7 @@ display_page (void)
 	/* section spacer */
 	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 	gtk_widget_set_usize (w, 0u, 6u);
-	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
+	gtk_table_attach (GTK_TABLE(t), w, 0, 4, row, row+1, 0, 0, 0, 0);
 	++row;
 
 	/* title for profile info section */
@@ -1093,12 +1091,12 @@ display_page (void)
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* quoted text label */
 		l = gtk_label_new_with_mnemonic (_("Characters denoting _quoted text:"));
@@ -1199,12 +1197,12 @@ appearance_page (void)
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* use custom fonts */
 		w = gtk_check_button_new_with_mnemonic (_("Use custom _fonts"));
@@ -1272,7 +1270,7 @@ appearance_page (void)
 	/* section spacer */
 	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 	gtk_widget_set_usize (w, 0u, 6u);
-	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
+	gtk_table_attach (GTK_TABLE(t), w, 0, 4, row, row+1, 0, 0, 0, 0);
 	++row;
 
 	/* title for profile info section */
@@ -1288,12 +1286,12 @@ appearance_page (void)
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* quoted text 1 */
 		l = gtk_label_new_with_mnemonic (_("Quoted Text _1:"));
@@ -1331,6 +1329,18 @@ appearance_page (void)
 		gtk_table_attach_defaults (GTK_TABLE(t), w, 3, 4, row, row+1);
 		++row;
 
+		/* signature */
+		l = gtk_label_new_with_mnemonic (_("Signature"));
+		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
+		gtk_table_attach_defaults (GTK_TABLE(t), l, 1, 2, row, row+1);
+
+		w = win->signature_pcp = pan_color_picker_new ();
+		pan_color_picker_set_color (w, &signature_color);
+		connect_signal_to_prefs_changed (w, "clicked");
+		gtk_label_set_mnemonic_widget (GTK_LABEL(l), w);
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 3, 4, row, row+1);
+		++row;
+		
 		/* URLs */
 		l = gtk_label_new_with_mnemonic (_("_URLs:"));
 		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
@@ -1343,6 +1353,30 @@ appearance_page (void)
 		gtk_table_attach_defaults (GTK_TABLE(t), w, 3, 4, row, row+1);
 		++row;
 
+		/* read threads */
+		l = gtk_label_new_with_mnemonic (_("_Read Threads:"));
+		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
+		gtk_table_attach_defaults (GTK_TABLE(t), l, 1, 2, row, row+1);
+
+		w = win->read_pcp = pan_color_picker_new ();
+		pan_color_picker_set_color (w, &read_color);
+		connect_signal_to_prefs_changed (w, "clicked");
+		gtk_label_set_mnemonic_widget (GTK_LABEL(l), w);
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 3, 4, row, row+1);
+		++row;
+
+		/* unread threads */
+		l = gtk_label_new_with_mnemonic (_("Unread _Threads:"));
+		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
+		gtk_table_attach_defaults (GTK_TABLE(t), l, 1, 2, row, row+1);
+
+		w = win->unread_pcp = pan_color_picker_new ();
+		pan_color_picker_set_color (w, &unread_color);
+		connect_signal_to_prefs_changed (w, "clicked");
+		gtk_label_set_mnemonic_widget (GTK_LABEL(l), w);
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 3, 4, row, row+1);
+		++row;
+
 		/* ignored threads */
 		l = gtk_label_new_with_mnemonic (_("_Ignored Threads:"));
 		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
@@ -1356,7 +1390,7 @@ appearance_page (void)
 		++row;
 
 		/* watched threads */
-		l = gtk_label_new_with_mnemonic (_("_Watched Threads:"));
+		l = gtk_label_new_with_mnemonic (_("Watc_hed Threads:"));
 		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
 		gtk_table_attach_defaults (GTK_TABLE(t), l, 1, 2, row, row+1);
 
@@ -1400,12 +1434,12 @@ apps_page (void)
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* group pane font */
 		l = gtk_label_new_with_mnemonic (_("E_ditor (%t is filename):"));
@@ -1433,7 +1467,7 @@ apps_page (void)
 		++row;
 
 		/* group pane font */
-		l = gtk_label_new_with_mnemonic (_("_Web Browser (%s is URL):"));
+		l = gtk_label_new_with_mnemonic (_("Web _Browser (%s is URL):"));
 		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
 		gtk_table_attach_defaults (GTK_TABLE(t), l, 1, 2, row, row+1);
 		w = win->external_browser_combo = gtk_combo_new ();
@@ -1443,7 +1477,7 @@ apps_page (void)
 		s = g_list_append (s, "galeon --new-tab '%s'");
 		s = g_list_append (s, "netscape '%s'");
 		s = g_list_append (s, "netscape -remote 'openURL(%s,raise)'");
-		s = g_list_append (s, "mozilla -remote 'openURL(%s,raise)'");
+		s = g_list_append (s, "mozilla -remote 'openURL(%s)'");
 		s = g_list_append (s, "konqueror '%s'");
 		s = g_list_append (s, "xterm -e w3m \"%s\"");
 		s = g_list_append (s, "xterm -e lynx \"%s\"");
@@ -1555,20 +1589,20 @@ layout_page (void)
 	gtk_table_attach_defaults (GTK_TABLE(t), l, 0, 4, row, row+1);
 	++row;
 
-		items_in_section = 5;
+		items_in_section = 1;
 	
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
 
-		/* spacer between the controls and their labels */
+		/* spacer between the controls and their labels 
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+items_in_section, 0, 0, 0, 0); */
 
 		/* pane layout */
-		h = gtk_hbox_new (TRUE, 0);
+		h = gtk_hbox_new (FALSE, 6);
 		gtk_container_set_border_width (GTK_CONTAINER (h), 0);
 		for (i=0; i<5; ++i)
 		{
@@ -1592,16 +1626,16 @@ layout_page (void)
 			g_signal_connect (w, "toggled", G_CALLBACK(layout_changed_cb), layout_buttons);
 			connect_signal_to_prefs_changed (w, "toggled");
 			layout_buttons[i] = w;
-			gtk_box_pack_start (GTK_BOX(h), w, TRUE, FALSE, 0);
+			gtk_box_pack_start (GTK_BOX(h), w, FALSE, FALSE, 0);
 
 		}
-		gtk_table_attach_defaults (GTK_TABLE(t), h, 1, 4, row, row+1);
+		gtk_table_attach_defaults (GTK_TABLE(t), h, 1, 2, row, row+1);
 		++row;
 
 	/* section spacer */
 	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 	gtk_widget_set_usize (w, 0u, 6u);
-	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
+	gtk_table_attach (GTK_TABLE(t), w, 0, 4, row, row+1, 0, 0, 0, 0);
 	++row;
 
 	/* title for profile info section */
@@ -1617,7 +1651,7 @@ layout_page (void)
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* pane order */
 		pch_group = _("Group");
@@ -1628,42 +1662,42 @@ layout_page (void)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), !strcmp(layout_str+1,"gta"));
 		g_object_set_data (G_OBJECT(w), "layout", "gta");
 		connect_signal_to_prefs_changed (w, "toggled");
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 2, row, row+1);
 		++row;
 		g_snprintf (buf, sizeof(buf), "1=%s, 2=%s, 3=%s", pch_group, pch_body, pch_header);
 		w = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON(w), buf);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), !strcmp(layout_str+1,"gat"));
 		g_object_set_data (G_OBJECT(w), "layout", "gat");
 		connect_signal_to_prefs_changed (w, "toggled");
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 2, row, row+1);
 		++row;
 		g_snprintf (buf, sizeof(buf), "1=%s, 2=%s, 3=%s", pch_header, pch_group, pch_body);
 		w = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON(w), buf);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), !strcmp(layout_str+1,"tga"));
 		g_object_set_data (G_OBJECT(w), "layout", "tga");
 		connect_signal_to_prefs_changed (w, "toggled");
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 2, row, row+1);
 		++row;
 		g_snprintf (buf, sizeof(buf), "1=%s, 2=%s, 3=%s", pch_header, pch_body, pch_group);
 		w = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON(w), buf);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), !strcmp(layout_str+1,"tag"));
 		g_object_set_data (G_OBJECT(w), "layout", "tag");
 		connect_signal_to_prefs_changed (w, "toggled");
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 2, row, row+1);
 		++row;
 		g_snprintf (buf, sizeof(buf), "1=%s, 2=%s, 3=%s", pch_body, pch_group, pch_header);
 		w = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON(w), buf);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), !strcmp(layout_str+1,"agt"));
 		g_object_set_data (G_OBJECT(w), "layout", "agt");
 		connect_signal_to_prefs_changed (w, "toggled");
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 2, row, row+1);
 		++row;
 		g_snprintf (buf, sizeof(buf), "1=%s, 2=%s, 3=%s", pch_body, pch_header, pch_body);
 		w = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON(w), buf);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), !strcmp(layout_str+1,"atg"));
 		g_object_set_data (G_OBJECT(w), "layout", "atg");
 		connect_signal_to_prefs_changed (w, "toggled");
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
+		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 2, row, row+1);
 		++row;
 
 	g_object_set_data_full (G_OBJECT(t), "layout_buttons", layout_buttons, g_free);
@@ -1706,12 +1740,12 @@ cache_page (void)
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* max cache size */
 		l = gtk_label_new_with_mnemonic (_("Ma_ximum Cache Size (Megs):"));
@@ -1763,12 +1797,12 @@ mail_page (void)
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u);
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+items_in_section);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+items_in_section, 0, 0, 0, 0);
 
 		/* address label */
 		l = gtk_label_new_with_mnemonic (_("Mail Server A_ddress:"));
@@ -1837,7 +1871,7 @@ prefs_spawn (void)
 
 	win = g_new0 (PrefsWindow, 1);
 
-	win->dialog = w = gtk_dialog_new_with_buttons (_("Pan: Preferences"),
+	win->dialog = w = gtk_dialog_new_with_buttons (_("Pan Preferences"),
 	                                               GTK_WINDOW(Pan.window),
 	                                               GTK_DIALOG_DESTROY_WITH_PARENT,
 	                                               GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -1862,7 +1896,7 @@ prefs_spawn (void)
 	add_tab (_("Appea_rance"), appearance_page)
 	add_tab (_("_Layout"), win->layout_page=layout_page)
 	add_tab (_("Displa_y"), win->display_page=display_page)
-	add_tab (_("_Tasks"), tasks_page)
+	add_tab (_("_Downloads"), tasks_page)
 	add_tab (_("Cach_e"), cache_page)
 	add_tab (_("_Mail"), mail_page)
 	add_tab (_("A_pplications"), apps_page)
