@@ -24,7 +24,8 @@
 *** Global Variables
 **/
 
-extern gboolean                single_click_selects;
+extern gboolean                single_click_selects_groups;
+extern gboolean                single_click_selects_headers;
 extern gboolean                header_pane_is_threaded;
 extern gboolean                show_group_pane;
 extern gboolean                show_header_pane;
