@@ -46,6 +46,7 @@
 
 #include <pan/nntp.h>
 #include <pan/queue.h>
+#include <pan/socket-pool.h>
 #include <pan/task-xml.h>
 
 /*********************
@@ -58,9 +59,7 @@ typedef enum
 	TODO_REMOVE,
 	TODO_MOVE,
 	TODO_REQUEUE,
-	TODO_TASK_ABORT,
-	TODO_SET_MAX_SOCKET_QTY,
-	TODO_SET_MAX_TRIES,
+	TODO_STOP,
 	TODO_SHUTDOWN,
 	TODO_ONLINE
 }
@@ -82,20 +81,11 @@ typedef struct
 }
 QueueTodo;
 
-typedef struct
-{
-	PanSocket *socket;
-	Server *server;
-	Task *task;	/* NULL if idle */
-}
-SocketInfo;
-
 /*********************
 **********************  Private Function Prototypes
 *********************/
 
 static void fire_queue_size_changed (int running_qty, int total_qty);
-static void fire_connecting_state_changed (gboolean connecting);
 static void fire_connection_size_changed (int increment);
 static void fire_online_status_changed (gboolean online);
 static void fire_message_id_status_changed (const char ** message_ids, int message_id_qty);
@@ -109,8 +99,6 @@ static void queue_run_what_we_can (void);
 static void queue_set_task_status (Task* task,
                                    QueueTaskStatus status);
 
-static void socket_cleanup (Task* task);
-
 static void queue_new_todo (QueueTodoAction     action,
                             GSList            * tasks,
                             int                 i);
@@ -151,20 +139,16 @@ PanCallback * queue_tasks_added           = NULL;
 PanCallback * queue_tasks_removed         = NULL;
 PanCallback * queue_tasks_moved           = NULL;
 PanCallback * queue_task_status_changed   = NULL;
-PanCallback * queue_max_tries_changed     = NULL;
 
 /***********
 ************  Private
 ***********/
 
-
-/* FIXME glib 2.0: for efficiency of adding to end, use a GQueue instead of GSList */
 static GQueue * todo_queue = NULL;
 static GSList* task_list = NULL;
 
 static GThreadPool * _tpool = NULL;
 
-static GMutex * sock_lock = NULL;
 static GMutex * task_lock = NULL;
 static GMutex * cond_mutex = NULL;
 static GMutex * todo_mutex = NULL;
@@ -172,15 +156,10 @@ static GMutex * todo_mutex = NULL;
 static GCond * qcond = NULL;
 static gboolean work_to_do = FALSE;
 
+static GHashTable * server_to_pool = NULL;
 static GHashTable * task_to_status = NULL;
 static GHashTable * message_id_hash = NULL;
 
-static GSList * sockets = NULL;
-
-static int max_socket_qty = 4;
-
-static int max_tries = 5;
-
 static guint running_tasks = 0;
 
 static gboolean _online = TRUE;
@@ -198,29 +177,22 @@ static gboolean _dirty = FALSE;
 void
 queue_wakeup (void)
 {
-	/*gboolean do_wakeup;*/
 	debug_enter ("queue_wakeup");
 
-	/*g_mutex_lock (todo_mutex);
-	do_wakeup = !g_queue_is_empty (todo_queue);
-	g_mutex_unlock (todo_mutex);*/
-
-	if (TRUE /*do_wakeup*/)
-	{
-		g_mutex_lock (cond_mutex);
-		work_to_do = TRUE;
-		g_cond_signal (qcond);
-		g_mutex_unlock (cond_mutex);
-	}
+	g_mutex_lock (cond_mutex);
+	work_to_do = TRUE;
+	g_cond_signal (qcond);
+	g_mutex_unlock (cond_mutex);
 
 	debug_exit ("queue_wakeup");
 }
 
 void
-queue_init (gboolean online, int socket_qty, int tries, gboolean remove_failed_tasks)
+queue_init (gboolean online, gboolean remove_failed_tasks)
 {
 	debug_enter ("queue_init");
 
+	server_to_pool = g_hash_table_new (g_direct_hash, g_direct_equal);
 	task_to_status = g_hash_table_new (g_direct_hash, g_direct_equal);
 	message_id_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
@@ -230,9 +202,7 @@ queue_init (gboolean online, int socket_qty, int tries, gboolean remove_failed_t
 	queue_tasks_removed = pan_callback_new ();
 	queue_tasks_moved = pan_callback_new ();
 	queue_task_status_changed = pan_callback_new ();
-	queue_max_tries_changed = pan_callback_new ();
 
-	sock_lock = g_mutex_new ();
 	task_lock = g_mutex_new ();
 	cond_mutex = g_mutex_new ();
 	todo_mutex = g_mutex_new ();
@@ -242,9 +212,7 @@ queue_init (gboolean online, int socket_qty, int tries, gboolean remove_failed_t
 	_online = online;
 
 	_remove_failed_tasks = remove_failed_tasks;
-	max_tries = tries;
-	max_socket_qty = socket_qty;
-	_tpool = g_thread_pool_new (queue_run_thread, NULL, max_socket_qty, TRUE, NULL);
+	_tpool = g_thread_pool_new (queue_run_thread, NULL, 8, TRUE, NULL);
 
 	/* fire up the queue thread */
 	g_thread_create (queue_mainloop, NULL, FALSE, NULL);
@@ -252,6 +220,43 @@ queue_init (gboolean online, int socket_qty, int tries, gboolean remove_failed_t
 	debug_exit ("queue_init");
 }
 
+/***
+**** SOCKET POOL
+***/
+
+static void
+pool_count_ghfunc (gpointer key, gpointer value, gpointer user_data)
+{
+	int * pi = (int *) user_data;
+	const SocketPool * pool = (const SocketPool*) value;
+	(*pi) += socket_pool_get_connection_qty (pool);
+}
+
+static void
+pool_socket_avail_cb (gpointer call_object, gpointer call_arg, gpointer user_data)
+{
+	/* update the connection count */
+	int qty = 0;
+	g_hash_table_foreach (server_to_pool, pool_count_ghfunc, &qty);
+	fire_connection_size_changed (qty);
+
+	/* wakeup the queue */
+	queue_wakeup ();
+}
+
+static SocketPool*
+get_socket_pool_from_server (Server * server)
+{
+	SocketPool * pool = (SocketPool*) g_hash_table_lookup (server_to_pool, server);
+	if (pool == NULL) {
+		pool = socket_pool_new (server);
+		socket_pool_set_online (pool, _online);
+		pan_callback_add (socket_pool_get_available_callback(pool), pool_socket_avail_cb, NULL);
+		g_hash_table_insert (server_to_pool, server, pool);
+	}
+	return pool;
+}
+
 /***
 ****
 ***/
@@ -312,7 +317,7 @@ queue_remove_message_id_state (const char **   message_ids,
 }
 
 static int
-task_get_state (const Task * task)
+task_get_type_state (const Task * task)
 {
 	int state = 0;
 
@@ -340,7 +345,7 @@ task_get_state (const Task * task)
 static void
 queue_add_message_ids (Task * task)
 {
-	const int state = task_get_state (task);
+	const int state = task_get_type_state (task);
 
 	if (state)
 	{
@@ -360,13 +365,14 @@ queue_add_message_ids (Task * task)
 static void
 queue_remove_message_ids (Task * task)
 {
-	const int state = task_get_state (task);
+	const int state = task_get_type_state (task);
 
 	if (state)
 	{
 		int i;
 		GPtrArray * message_ids = g_ptr_array_new ();
-		for (i=0; i<task->identifiers->len; ++i) {
+		for (i=0; i<task->identifiers->len; ++i)
+		{
 			MessageIdentifier * mid = MESSAGE_IDENTIFIER (g_ptr_array_index (task->identifiers, i));
 			g_ptr_array_add (message_ids, mid->message_id);
 		}
@@ -391,6 +397,13 @@ queue_set_online (gboolean online)
 {
 	queue_new_todo (TODO_ONLINE, NULL, online);
 }
+
+static void
+real_queue_set_online_ghfunc (gpointer key, gpointer value, gpointer user_data)
+{
+	socket_pool_set_online ((SocketPool*)value, _online);
+}
+
 static void
 real_queue_set_online (gint p, gboolean * do_wakeup)
 {
@@ -401,26 +414,24 @@ real_queue_set_online (gint p, gboolean * do_wakeup)
 	}
 	else
 	{
+		GSList * l;
+
 		_online = p;
 
-		fire_online_status_changed (_online);
+		/* set/clear the abort flag on all the tasks */
+		g_mutex_lock (task_lock);
+		for (l=task_list; l!=NULL; l=l->next)
+			TASK(l->data)->hint_abort = !_online;
+		g_mutex_unlock (task_lock);
+
+		/* set the socket pools offline */
+		g_hash_table_foreach (server_to_pool, real_queue_set_online_ghfunc, NULL);
 
 		if (_online)
 			*do_wakeup = TRUE;
-		else
-		{
-			GSList * l;
 
-			g_mutex_lock (sock_lock);
-			for (l=sockets; l!=NULL; l=l->next)
-			{
-				SocketInfo * i = (SocketInfo*)l->data;
-				if (i->task != NULL)
-					task_hint_abort (i->task);
-				queue_set_task_status (i->task, QUEUE_TASK_STATUS_ABORTING);
-			}
-			g_mutex_unlock (sock_lock);
-		}
+		/* let listeners know */
+		fire_online_status_changed (_online);
 	}
 }
 
@@ -433,33 +444,16 @@ queue_shutdown (void)
 static void
 real_queue_shutdown (void)
 {
-	gint len;
-	GSList * l;
-	GSList * sockets_tmp;
-
 	/* clear the status hashtable */
 	g_hash_table_destroy (task_to_status);
 	task_to_status = NULL;
 
-
-
 	/* optionally save the tasks */
 
 	/* unref the tasks */
 
-	/* get the socket array */
-	g_mutex_lock (sock_lock);
-	sockets_tmp = sockets;
-	sockets = NULL;
-	g_mutex_unlock (sock_lock);
-
 	/* close the sockets */
-	len = g_slist_length (sockets_tmp);
-	for (l=sockets_tmp; l!=NULL; l=l->next)
-		pan_object_unref (PAN_OBJECT(((SocketInfo*)l->data)->socket));
-	fire_connection_size_changed (-len);
-	g_slist_foreach (sockets_tmp, (GFunc)g_free, NULL);
-	g_slist_free (sockets_tmp);
+	/* FIXME: need to clear the socket pools */
 }
 
 
@@ -505,7 +499,7 @@ queue_is_empty (void)
 char*
 queue_get_tasks_filename (void)
 {
-	return g_strdup_printf ("%s%ctasks.xml", get_data_dir(), G_DIR_SEPARATOR);
+	return g_build_filename (get_data_dir(), "tasks.xml", NULL);
 }
 
 static void
@@ -530,30 +524,6 @@ queue_save_tasks (void)
 ***
 **/
 
-int
-queue_get_max_sockets (void)
-{
-	return max_socket_qty;
-}
-void
-queue_set_max_sockets (int i)
-{
-	queue_new_todo (TODO_SET_MAX_SOCKET_QTY, NULL, i);
-	queue_wakeup ();
-}
-static void
-real_queue_set_max_sockets (int i, gboolean * do_wakeup)
-{
-	if (max_socket_qty != i)
-	{
-		if (i > max_socket_qty)
-			*do_wakeup = TRUE;
-
-		max_socket_qty = i;
-		g_thread_pool_set_max_threads (_tpool, max_socket_qty, NULL);
-	}
-}
-
 guint
 queue_get_running_task_count (void)
 {
@@ -566,8 +536,7 @@ queue_get_running_task_count (void)
 		QueueTaskStatus status = queue_get_task_status (l->data);
 
 		if (status == QUEUE_TASK_STATUS_RUNNING ||
-		    status == QUEUE_TASK_STATUS_QUEUED ||
-		    status == QUEUE_TASK_STATUS_CONNECTING)
+		    status == QUEUE_TASK_STATUS_QUEUED)
 			++running_count;
 	}
 	g_mutex_unlock (task_lock);
@@ -580,38 +549,34 @@ queue_get_running_task_count (void)
 **/
 
 void
-queue_abort_tasks (GSList * tasks)
+queue_stop_tasks (GSList * tasks)
 {
-	queue_new_todo (TODO_TASK_ABORT, tasks, -1);
+	queue_new_todo (TODO_STOP, tasks, -1);
 }
 static void
-real_queue_abort_tasks (GSList * tasks)
+real_queue_stop_tasks (GSList * tasks)
 {
 	GSList * l;
 	for (l=tasks; l!=NULL; l=l->next)
 	{
 		Task * task = TASK(l->data);
-		QueueTaskStatus status = queue_get_task_status (task);
+		const QueueTaskStatus status = queue_get_task_status (task);
 
-		if (status==QUEUE_TASK_STATUS_RUNNING)
+		if (status == QUEUE_TASK_STATUS_RUNNING)
 		{
-			/* ask a running task to abort */
-			task_hint_abort (TASK(task));
-			queue_set_task_status (task, QUEUE_TASK_STATUS_ABORTING);
-		}
-		else if (task->hint_abort && !queue_is_online())
-		{
-			/* the task's been stopped because the queue is offline */
-			task->tries = 0;
-			task->hint_abort = FALSE;
-			queue_set_task_status (task, QUEUE_TASK_STATUS_QUEUED);
+			/* ask a running task to stop */
+			task->hint_abort = TRUE;
+			queue_set_task_status (task, QUEUE_TASK_STATUS_STOPPING);
 		}
 		else
 		{
-			/* the task has failed */
-			task->tries = 0;
+			/* if the task was stopped because we went offline, set it to queued instead of stopped. */
+			queue_set_task_status (task, task->hint_abort && !queue_is_online()
+					? QUEUE_TASK_STATUS_QUEUED
+					: QUEUE_TASK_STATUS_STOPPED);
+
+			/* clear the abort flag */
 			task->hint_abort = FALSE;
-			queue_set_task_status (task, QUEUE_TASK_STATUS_FAILED);
 		}
 	}
 }
@@ -634,6 +599,7 @@ real_queue_insert_tasks (GSList * new_tasks, int index, gboolean * do_wakeup)
 	GSList * insertme;
 	guint task_len;
 	debug_enter ("real_queue_insert_tasks");
+	debug1 (DEBUG_QUEUE, "real_queue_insert_tasks: inserting at position %d", index);
 
 	/* sanity clause */
 	g_return_if_fail (new_tasks!=NULL);
@@ -650,7 +616,11 @@ real_queue_insert_tasks (GSList * new_tasks, int index, gboolean * do_wakeup)
 		**/
 		if (task_list == NULL) /* no previous list */
 			task_list = insertme;
-		else { /* insert into the list */
+		else if (index == 0)
+			task_list = g_slist_concat (insertme, task_list);
+		else if (index == -1)
+			task_list = g_slist_concat (task_list, insertme);
+		else {
 			GSList * nth = g_slist_nth (task_list, index);
 			if (nth == NULL) { /* index out of range, append to end */
 				index = g_slist_length (task_list);
@@ -689,6 +659,7 @@ real_queue_insert_tasks (GSList * new_tasks, int index, gboolean * do_wakeup)
 void
 queue_remove_tasks (GSList * tasks)
 {
+	g_slist_foreach (tasks, (GFunc)pan_object_ref, NULL); /* balanced at end of real_queue_remove_tasks */
 	queue_new_todo (TODO_REMOVE, tasks, -1);
 }
 static void
@@ -696,29 +667,26 @@ real_queue_remove_tasks (GSList * tasks, gboolean * do_wakeup)
 {
 	GSList * l;
 	GSList * removed = NULL;
+	debug_enter ("real_queue_remove_tasks");
 
 	for (l=tasks; l!=NULL; l=l->next)
 	{
 		Task * task = TASK(l->data);
 
-		if (task->is_running)
+		if (task->thread_qty > 0)
 		{
-			/* abort the task; after it's done running
-			 * queue_run_thread() will send the task back here
-			 * for part two  */
-			task_hint_abort (task);
 			queue_set_task_status (task, QUEUE_TASK_STATUS_REMOVING);
+			task->hint_abort = TRUE;
 		}
-		else /* not running */
+		else /* not running -- this task can be removed */
 		{
-			/* not running */
-			socket_cleanup (task);
-
-			/* remove the task */
 			g_mutex_lock (task_lock);
-			task_list = g_slist_remove (task_list, task);
-			removed = g_slist_prepend (removed, task);
-			_dirty = TRUE;
+			if (g_slist_find (task_list, task) != NULL)
+			{
+				task_list = g_slist_remove (task_list, task);
+				removed = g_slist_prepend (removed, task);
+				_dirty = TRUE;
+			}
 			g_mutex_unlock (task_lock);
 		}
 	}
@@ -731,7 +699,8 @@ real_queue_remove_tasks (GSList * tasks, gboolean * do_wakeup)
 		*do_wakeup = TRUE;
 		pan_callback_call (queue_tasks_removed, removed, NULL);
 
-		for (l=removed; l!=NULL; l=l->next) {
+		for (l=removed; l!=NULL; l=l->next)
+		{
 			Task * task = TASK(l->data);
 			g_hash_table_remove (task_to_status, task);
 			queue_remove_message_ids (task);
@@ -740,6 +709,9 @@ real_queue_remove_tasks (GSList * tasks, gboolean * do_wakeup)
 
 		g_slist_free (removed);
 	}
+
+	g_slist_foreach (tasks, (GFunc)pan_object_unref, NULL); /* balanced at begin of queue_remove_tasks */
+	debug_exit ("real_queue_remove_tasks");
 }
 
 /**
@@ -820,7 +792,7 @@ queue_requeue_failed_tasks (GSList * tasks)
 	g_return_if_fail (tasks != NULL);
 	for (l=tasks; l!=NULL; l=l->next) {
 		Task * task = (Task*) l->data;
-		g_return_if_fail (queue_get_task_status(task) == QUEUE_TASK_STATUS_FAILED);
+		g_return_if_fail (queue_get_task_status(task) == QUEUE_TASK_STATUS_STOPPED);
 	}
 
 	queue_new_todo (TODO_REQUEUE, tasks, -1);
@@ -834,7 +806,6 @@ real_requeue_failed_tasks (GSList * tasks, gboolean * do_wakeup)
 
 		for (l=tasks; l!=NULL; l=l->next) {
 			Task * task = TASK(l->data);
-			task->tries = 0;
 			task->hint_abort = FALSE;
 			queue_set_task_status (task, QUEUE_TASK_STATUS_QUEUED);
 		}
@@ -863,28 +834,6 @@ queue_set_remove_failed_tasks (gboolean b)
 ***
 **/
 
-int
-queue_get_max_tries (void)
-{
-	return max_tries;
-}
-
-void
-queue_set_max_tries (int i)
-{
-	queue_new_todo (TODO_SET_MAX_TRIES, NULL, i);
-}
-static void
-real_queue_set_max_tries (int i)
-{
-	max_tries = i;
-	pan_callback_call (queue_max_tries_changed, NULL, GINT_TO_POINTER(i));
-}
-
-/**
-***
-**/
-
 QueueTaskStatus
 queue_get_task_status (const Task* task)
 {
@@ -942,499 +891,187 @@ queue_get_length (void)
 	return size;
 }
 
-static void
-queue_run_thread (gpointer data, gpointer user_data)
+typedef struct
 {
-	int status;
-	int result;
-	gboolean aborting;
-	Task* task = TASK(data);
-	gchar* desc = status_item_describe (STATUS_ITEM(task));
-	debug2 (DEBUG_QUEUE, "queue_run_thread: task %p [%s]", task, desc);
+	Server * server;
+	TaskFunc func;
+	Task * task;
+	PanSocket * sock;
+}
+QueueRunStruct;
 
-	/* run */
-	status_item_set_active (STATUS_ITEM(task), TRUE);
-	if (task->sock)
-		pan_socket_reset_statistics (task->sock);
-	fire_queue_size_changed (++running_tasks, queue_get_length());
-	result = task_run (task);
-	fire_queue_size_changed (--running_tasks, queue_get_length());
-	debug3 (DEBUG_QUEUE, "queue task[%p] (%s) returned: %d", task, desc, result);
-	g_free(desc);
-
-	/* clean up gui */
-	status_item_set_active (STATUS_ITEM(task), FALSE);
-
-	/* clean up socket.
-	   We throw away any socket of a failed or aborting task,
-	   just in case the read buffer has junk in there. */
-	status = queue_get_task_status (task);
-	aborting = status==QUEUE_TASK_STATUS_ABORTING || status==QUEUE_TASK_STATUS_REMOVING;
-	if (task->sock!=NULL && (aborting || result!=TASK_SUCCESS))
-		task->sock->error = TRUE;
-	socket_cleanup (task);
-
-	/* clean up the task */
-	task->is_running = FALSE;
-
-	if (result==TASK_SUCCESS)
-	{
-		/* success, remove the task */
-		queue_remove_tasks (g_slist_append(NULL,task));
-	}
-	else if (result==TASK_FAIL_HOPELESS && _remove_failed_tasks)
-	{
-		/* failed, and requeueing won't help, so remove it now */
-		queue_remove_tasks (g_slist_append(NULL,task));
-	}
-	else if (status == QUEUE_TASK_STATUS_REMOVING)
-	{
-		/* someone is waiting until run() finishes to remove the task */
-		queue_remove_tasks (g_slist_append(NULL,task));
-	}
-	else if (status == QUEUE_TASK_STATUS_ABORTING)
-	{
-		/* someone is waiting until run() finishes to abort the task */
-		task->tries = 0;
-		queue_abort_tasks (g_slist_append(NULL,task));
-	}
-	else if (task->tries<max_tries && result != TASK_FAIL_HOPELESS)
-	{
-		/* failed, but still has tries left to requeue */
-		++task->tries;
-		queue_set_task_status (task, QUEUE_TASK_STATUS_QUEUED);
-		queue_wakeup ();
-	}
-	else
-	{
-		/* failed, let the user requeue later */
-		task->tries = 0;
-		task->hint_abort = FALSE;
-		queue_set_task_status (task, QUEUE_TASK_STATUS_FAILED);
-		queue_wakeup ();
-	}
-
-	debug1 (DEBUG_QUEUE, "queue_run_thread: task %p done", data);
+static void
+increment_running_task_qty (int inc)
+{
+	running_tasks += inc;
+	fire_queue_size_changed (running_tasks, g_slist_length(task_list));
 }
 
+static void
+queue_run_thread (gpointer gp_data, gpointer user_data)
+{
+	QueueRunStruct * data = (QueueRunStruct*) gp_data;
+	Task * task = data->task;
+	PanSocket * sock = data->sock;
+
+	/* get ready to run */
+	if (++task->thread_qty == 1)
+	{
+		/* let the GUI know what's going on */
+		status_item_set_active (STATUS_ITEM(task), TRUE);
+		increment_running_task_qty (1);
+	}
+	if (sock != NULL)
+		task->sockets = g_slist_prepend (task->sockets, sock);
+
+	/* run the task's workproc */
+	(data->func)(task, sock);
+
+	/* workproc done */
+	if (sock != NULL)
+		task->sockets = g_slist_remove (task->sockets, sock);
+	if (!--task->thread_qty)
+	{
+		const QueueTaskStatus qts = queue_get_task_status (task);
+
+		/* let the GUI know what's going on */
+		status_item_set_active (STATUS_ITEM(task), FALSE);
+		increment_running_task_qty (-1);
+
+		/* if the task is slated for removal or stopping,
+		 * then the queue is waiting for the task's threads to finish.
+		 * Since this is the last thread, remind the queue to do its work. */
+		switch (qts) {
+			case QUEUE_TASK_STATUS_REMOVING:
+				queue_remove_tasks (g_slist_append (NULL, task));
+				break;
+			case QUEUE_TASK_STATUS_STOPPING:
+				queue_stop_tasks (g_slist_append (NULL, task));
+				break;
+			default:
+				queue_set_task_status (task, QUEUE_TASK_STATUS_QUEUED);
+				break;
+		}
+	}
+
+	/* clean up the socket */
+	if (sock != NULL)
+	{
+		/* if the task aborted, the read buffer may still have contents,
+		 * so throw away the socket */
+		if (task->hint_abort)
+			pan_socket_set_error_flag (sock, TRUE);
+
+		socket_pool_checkin (get_socket_pool_from_server (data->server), sock);
+	}
+	else /* since we didn't checkin a socket to wake the queue, let's do it explicitly */
+	{
+		queue_wakeup ();
+	}
+
+	/* cleanup */
+	g_free (data);
+}
 
 static void
-queue_run (Task* task)
+queue_run (Task * task, TaskFunc func, PanSocket * sock, Server * server)
 {
-	g_return_if_fail (task!=NULL);
-	debug2 (DEBUG_QUEUE, "starting a thread to run task %p, sock %p", task, task->sock);
+	QueueRunStruct * data;
 
+	g_return_if_fail (task!=NULL);
+
+	/* set the task to TASK_WORKING here in the queue's thread so that
+	 * queue_run_what_we_can() doesn't kick off two workprocs at exactly
+	 * the same time, causing threading issues.  All workprocs can safely
+	 * assume that the state is TASK_WORKING when they begin, and it's up
+	 * to them to tell the queue if another concurrent workproc would be good.
+	 * (See task-save.c's task_save_run_download()). */
+	task_state_set (&task->state, TASK_WORKING);
+
+	/* This is mostly for the benefit of the GUI */
 	queue_set_task_status (task, QUEUE_TASK_STATUS_RUNNING);
 
-	task->is_running = TRUE;
-	g_thread_pool_push (_tpool, task, NULL);
-}
+	data = g_new0 (QueueRunStruct, 1);
+	data->server = server;
+	data->func = func;
+	data->task = task;
+	data->sock = sock;
 
-
-/**
- * Allocates a socket for a task.  First it looks for an idle socket in the
- * socket pool; otherwise, if we're not maxed out, it tries to create a new
- * socket.
- *
- * Return -1 if we can't connect because all lines are busy
- * Return -2 if we can't connect because of a connection failure
- */
-static int
-queue_get_socket_for_task (Task *task)
-{
-	GSList* sl = NULL;
-	int retval = -1;
-	const gboolean gets_bodies = TASK(task)->gets_bodies;
-	gboolean skip_first_idle = task->server->reserve_connection_for_bodies && !gets_bodies;
-	gboolean reader_socket_exists = FALSE;
-	Server * server = task->server;
-	int socket_qty;
-	debug_enter ("queue_get_socket_for_task");
-
-	g_mutex_lock (sock_lock);
-
-	/* if an idle socket for that server, use it. */
-	socket_qty = 0;
-	for (sl=sockets; sl!=NULL && retval!=0; sl=sl->next)
-	{
-		SocketInfo * si = (SocketInfo*) sl->data;
-
-		if (si->server != server) /* ignore other servers */
-			continue;
-
-		++socket_qty;
-
-		if (!queue_is_online()) /* offline */
-			continue;
-		if (si->task != NULL) /* socket already in use */
-			continue;
-
-		if (skip_first_idle) { /* save one article reader socket */
-			reader_socket_exists = TRUE;
-			skip_first_idle = FALSE;
-			continue;
-		}
-
-		si->task = task;
-		task->sock = si->socket;
-
-		debug3 (DEBUG_QUEUE,
-			"queue_get_socket_for_task %p "
-			"reusing socket #%d (%p)",
-			task, g_slist_index(sockets, si), si->socket);
-
-		retval = 0;
-	}
-
-	/* if no idle sockets for that server... */
-	if (retval && queue_is_online() && socket_qty<max_socket_qty)
-	{
-		const int current_connections = socket_qty;
-		int slots_open = server->max_connections - current_connections;
-		debug1 (DEBUG_QUEUE, "queue_get_socket_for_task %p no idle sockets", task);
-
-		/* leave an article reader socket free */
-		if (!reader_socket_exists
-			&& server->reserve_connection_for_bodies
-			&& !gets_bodies
-			&& max_socket_qty>1
-			&& server->max_connections>1)
-				--slots_open;
-
-		if (slots_open <= 0)
-		{
-			debug2 (DEBUG_QUEUE,
-				"we've already got %d connections "
-				"and %d reader connections",
-				current_connections,
-				(reader_socket_exists?1:0) );
-
-			retval = -1;
-		}
-		else	
-		{
-			char * errmsg = NULL;
-
-			/* open a new socket.. */
-			PanSocket *sock = NULL;
-			debug1 (DEBUG_QUEUE, "making a new socket to %s", server->address);
-
-			fire_connecting_state_changed (TRUE);
-			sock = pan_socket_new (server->name, server->address, server->port);
-			pan_socket_set_nntp_auth (sock, server->need_auth, server->username, server->password); 
-
-			debug1 (DEBUG_QUEUE, "new socket %p", sock);
-			if (sock == NULL || sock->sockfd < 0)
-			{
-				if (is_nonempty_string (server->address))
-					errmsg = g_strdup_printf (_("Unable to connect to server %s:%d"), server->address, server->port);
-				else
-					errmsg = g_strdup (_("No server address specified in the Preferences"));
-			}
-			else /* handshake */
-			{
-				StatusItem * status = STATUS_ITEM(task);
-				gboolean posting_ok = FALSE;
-				gint val = nntp_handshake (status, sock, &posting_ok);
-				if (val != TASK_SUCCESS)
-					errmsg = g_strdup(g_slist_last(status->errors)->data);
-			}
-			if (errmsg!=NULL)
-			{
-				log_add (LOG_ERROR, errmsg);
-				g_free (errmsg);
-				if (sock)
-					pan_object_unref (PAN_OBJECT(sock));
-				sock = NULL;
-
-				debug1 (DEBUG_QUEUE, "%p can't log in!", sock);
-
-				retval = -2;
-			}
-			else
-			{
-				SocketInfo * si = NULL;
-
-				debug1 (DEBUG_QUEUE, "%p logged in", sock);
-
-				/* looks like we got a new socket okay... */
-				si = g_new (SocketInfo, 1);
-				si->socket = sock;
-				si->server = server;
-				si->task = task;
-				task->sock = sock;
-				sockets = g_slist_prepend (sockets, si);
-				retval = 0;
-				fire_connection_size_changed (1);
-			}
-
-			fire_connecting_state_changed (FALSE);
-		}
-	}
-
-	g_mutex_unlock (sock_lock);
-
-	debug_exit ("queue_get_socket_for_item");
-	return retval;
+	g_thread_pool_push (_tpool, data, NULL);
 }
 
 /**
- * Run any tasks in the task_list which can be run (ie, can get a socket,
- * if necessary) right now.
+ * Run any tasks in the task_list which can be run
+ * (ie, can get a socket, if necessary) right now.
  */
 static void
 queue_run_what_we_can (void)
 {
+	int n = 0;
 	GSList * l = NULL;
 	debug_enter ("queue_run_what_we_can");
 
 	/* walk through the queue and see if any tasks are waiting to be run. */
 	l = task_list;
-	while (l!=NULL)
+	while (l != NULL)
 	{
-		Task *task = TASK(l->data);
+		SocketPool * pool;
+		PanSocket * sock;
+		Task * task = TASK(l->data);
+		const TaskState state = task->state;
+		const QueueTaskStatus qts = queue_get_task_status (task); 
+		const gboolean runnable = qts==QUEUE_TASK_STATUS_QUEUED || qts==QUEUE_TASK_STATUS_RUNNING;
 
-		/* if it's not waiting to be run, leave it alone */
-		if (queue_get_task_status(task) != QUEUE_TASK_STATUS_QUEUED)
+		debug5 (DEBUG_QUEUE,
+			"queue_run_what_we_can: #%d task %p (%s) task-state %d queue-task-state %d",
+			n++, task, status_item_describe(STATUS_ITEM(task)), (int)state.state, (int)qts);
+
+		switch (state.state)
 		{
-			debug0 (DEBUG_QUEUE, "task isn't waiting to be run");
-
-		}
-
-		/* if it doesn't need a socket, no problemo! */
-		else if (!task->needs_socket)
-		{
-			debug1 (DEBUG_QUEUE,
-				"task %d needs no socket; running it now",
-				task);
-
-			queue_run (task);
-		}
-
-		/* try to get a socket... */
-		else if (queue_is_online() && max_socket_qty>0)
-		{
-			int i;
-			queue_set_task_status (task, QUEUE_TASK_STATUS_CONNECTING);
-			i = queue_get_socket_for_task (task);
-			if (i==0)
-			{
-				debug1 (DEBUG_QUEUE,
-					"task %d got a socket!",
-					task);
-
-				queue_run (task);
-			}
-			else
-			{
-				if (i==-2) /* connection failure */
-				{
-					status_item_emit_error (STATUS_ITEM(task), _("Connect Failure"));
-
-					++task->tries;
-					if (task->tries > max_tries)
-						queue_abort_tasks (g_slist_append(NULL,task));
+			case TASK_NEED_SOCKET:
+				if (runnable) {
+					pool = get_socket_pool_from_server (state.server);
+					socket_pool_request_connections (pool, 1);
+					sock = socket_pool_checkout (pool);
+					if (sock != NULL)
+						queue_run (task, state.func, sock, state.server);
 				}
+				break;
 
-				queue_set_task_status (task, QUEUE_TASK_STATUS_QUEUED);
-			}
+			case TASK_NEED_WORK:
+				if (runnable)
+					queue_run (task, state.func, NULL, state.server);
+				break;
+
+			case TASK_WORKING:
+				/* don't do anything -- the task is busy */
+				break;
+
+			case TASK_SUCCESS:
+			case TASK_FAIL_HOPELESS:
+				queue_remove_tasks (g_slist_append (NULL, task));
+				pan_callback_call (task->task_ran_callback, task, GINT_TO_POINTER(state.state));
+				break;
+
+			default:
+				g_warning ("unhandled state");
+				break;
 		}
 
-		if (!g_queue_is_empty (todo_queue))
-		{
-				queue_do_todo ();
-				l = task_list;
-		}
-		else
-		{
-				l = l->next;
+
+		/* do we need to do some actions & rebuild the task list? */
+		if (g_queue_is_empty (todo_queue))
+			l = l->next;
+		else {
+			queue_do_todo ();
+			l = task_list;
+			n = 0;
 		}
 	}
 
 	debug_exit ("queue_run_what_we_can done");
 }
 
-/**
- * Destroy or recycle a socket when a task is done with it.
- * @param task the finished task.
- */
-static void
-socket_cleanup (Task* task)
-{
-	debug_enter ("socket_cleanup");
-
-	if (task && task->sock)
-	{
-		PanSocket* socket = task->sock;
-		GSList* l = NULL;
-		SocketInfo * info = NULL;
-		int server_socket_qty;
-		int socket_qty;
-
-		g_mutex_lock (sock_lock);
-
-		/* count the number of sockets this server has */
-		socket_qty = 0;
-		server_socket_qty = 0;
-		for (l=sockets; l!=NULL; l=l->next) {
-			SocketInfo * sockinfo = (SocketInfo*) l->data;
-			if (sockinfo->socket == socket)
-				info = sockinfo;
-			if (sockinfo->server == task->server)
-				++server_socket_qty;
-			++socket_qty;
-		}
-
-		/* find this SocketInfo in our tables */
-		g_assert (info!=NULL);
-
-		/**
-                 *  Recycle the socket if all are true
-		 *  + there was no error
-		 *  + the server is still online
-		 *  + we don't have too many sockets for that server
-		 *  + we don't have too many sockets overall
-		 */
-		if (!socket->error
-		    && queue_is_online()
-		    && socket_qty<=max_socket_qty
-		    && server_socket_qty<=task->server->max_connections)
-		{
-		       	/* if socket's okay, reuse it */
-			info->task = NULL;
-
-			debug1 (DEBUG_QUEUE, "socket_cleanup: recycling socket %p", socket);
-		}
-		else
-		{
-			/* otherwise throw it away */
-			nntp_disconnect (NULL, socket);
-			pan_object_unref (PAN_OBJECT(socket));
-			fire_connection_size_changed (-1);
-			sockets = g_slist_remove (sockets, info);
-			g_free (info);
-
-			debug1 (DEBUG_QUEUE,
-				"socket_cleanup: throwing away socket %p",
-				socket);
-		}
-		task->sock = NULL;
-		g_mutex_unlock (sock_lock);
-	}
-	debug_exit ("socket_cleanup");
-}
-
-static gchar*
-noop_describe (const StatusItem * item)
-{
-	return g_strdup (_("Sending 'stay connected' request"));
-}
-
-static gchar*
-disconnect_describe (const StatusItem * item)
-{
-	return g_strdup (_("Disconnecting"));
-}
-
-/**
- * socket upkeep:  Cull out idle sockets that have been connected too long,
- * and send keepalive commands the rest of the idle sockets so that the
- * server doesn't drop us.
- */
-static void
-sockets_upkeep (void)
-{
-	GSList* l = NULL;
-	GSList* cull = NULL;
-	int socket_qty;
-	debug_enter ("socket_upkeep");
-
-	g_mutex_lock (sock_lock);
-
-	socket_qty = g_slist_length (sockets);
-
-	for (l=sockets; l!=NULL; l=l->next)
-	{
-		gint age;
-		gboolean destroy, idle, old, too_many, offline;
-		SocketInfo * info;
-		PanSocket * sock;
-		const time_t current_time = time(0);
-
-		info = (SocketInfo*) l->data;
-		g_assert (info != NULL);
-		sock = info->socket;
-		g_assert (sock != NULL);
-
-		/* calculate some information about the socket
-		   to decide whether or not we want to keep it */
-		age = current_time - sock->last_action_time;
-		idle = info->task == NULL;
-		old = age > info->server->idle_secs_before_timeout;
-		too_many = socket_qty > max_socket_qty;
-		offline = !queue_is_online ();
-		destroy = idle && (old||too_many||offline);
-
-		/* if it's idle and we're keeping it, send a keepalive msg.
-		   Note that we don't let this affect the socket's
-		   age, otherwise they would never grow old and close... */
-		if (info->task==NULL && !destroy)
-		{
-			const time_t last_action_time = sock->last_action_time;
-			StatusItem * status = status_item_new (noop_describe);
-			status_item_set_active (status, TRUE);
-
-			destroy = nntp_noop (STATUS_ITEM(status), sock) != TASK_SUCCESS;
-			sock->last_action_time = last_action_time;
-
-			status_item_set_active (status, FALSE);
-			pan_object_unref (PAN_OBJECT(status));
-		}
-
-		/* either keep the socket or cull it from the herd */
-		if (destroy) {
-			--socket_qty;
-			cull = g_slist_prepend (cull, info);
-		}
-	}
-
-	debug1 (DEBUG_QUEUE, "sockets_upkeep: culling %u sockets",
-		g_slist_length(cull));
-
-	for (l=cull; l!=NULL; l=l->next)
-	{
-		const time_t current_time = time(0);
-		SocketInfo * info = (SocketInfo*) l->data;
-		PanSocket * sock = info->socket;
-		StatusItem * status = STATUS_ITEM(status_item_new (disconnect_describe));
-		const int age = current_time - sock->last_action_time;
-
-		/* politely disconnect */
-		status_item_set_active (status, TRUE);
-		if (!sock->error)
-			nntp_disconnect (status, sock);
-		status_item_set_active (status, FALSE);
-		log_add_va (LOG_INFO, _("Closing connection %p after %d seconds idle"), sock, age);
-
-		/* destroy the socket */
-		pan_object_unref (PAN_OBJECT(sock));
-		fire_connection_size_changed (-1);
-		sockets = g_slist_remove (sockets, info);
-
-		/* cleanup local */
-		pan_object_unref (PAN_OBJECT(status));
-		g_free (info);
-	}
-
-	pan_warn_if_fail (g_slist_length(sockets) == socket_qty);
-
-	g_mutex_unlock (sock_lock);
-
-	g_slist_free (cull);
-
-	debug_exit ("socket_upkeep");
-}
-
 /**
  * Process the tasks that are waiting in the todo list
  */
@@ -1469,14 +1106,8 @@ queue_do_todo (void)
 			case TODO_REQUEUE:
 				real_requeue_failed_tasks (a->tasks, &do_wakeup);
 				break;
-			case TODO_TASK_ABORT:
-				real_queue_abort_tasks (a->tasks);
-				break;
-			case TODO_SET_MAX_SOCKET_QTY:
-				real_queue_set_max_sockets (a->index_1, &do_wakeup);
-				break;
-			case TODO_SET_MAX_TRIES:
-				real_queue_set_max_tries (a->index_1);
+			case TODO_STOP:
+				real_queue_stop_tasks (a->tasks);
 				break;
 			case TODO_SHUTDOWN:
 				do_shutdown = TRUE;
@@ -1503,6 +1134,12 @@ queue_do_todo (void)
 	debug_exit ("queue_do_todo");
 }
 
+static void
+sockets_upkeep_ghfunc (gpointer key, gpointer value, gpointer user_data)
+{
+	socket_pool_refresh ((SocketPool*)value);
+}
+
 static void*
 queue_mainloop (void* unused)
 {
@@ -1526,7 +1163,7 @@ queue_mainloop (void* unused)
 
 		/* do work */
 		if (was_timeout)
-			sockets_upkeep ();
+			g_hash_table_foreach (server_to_pool, sockets_upkeep_ghfunc, NULL);
 		else {
 			queue_do_todo ();
                 	queue_run_what_we_can ();
@@ -1586,22 +1223,6 @@ fire_connection_size_changed (int increment)
 	                   NULL);
 }
 
-PanCallback*
-queue_get_connecting_state_changed_callback (void)
-{
-	static PanCallback * cb = NULL;
-	if (cb==NULL) cb = pan_callback_new ();
-	return cb;
-}
-
-static void
-fire_connecting_state_changed (gboolean connecting)
-{
-	pan_callback_call (queue_get_connecting_state_changed_callback(),
-	                   GINT_TO_POINTER(connecting),
-	                   NULL);
-}
-
 PanCallback*
 queue_get_size_changed_callback (void)
 {
