@@ -25,7 +25,7 @@
 #include <pan/task.h>
 
 
-extern void queue_init (gboolean online, int max_sockets, int max_tries, gboolean remove_failed_tasks);
+extern void queue_init (gboolean online, gboolean remove_failed_tasks);
 
 extern void queue_add (Task*);
 
@@ -65,12 +65,6 @@ PanCallback*  queue_get_size_changed_callback (void);
  */
 PanCallback*  queue_get_connection_size_changed_callback (void);
 
-/**
- * @call_obj: GINT_TO_POINTER(is_connecting_boolean)
- * @call_arg: NULL
- */
-PanCallback*  queue_get_connecting_state_changed_callback (void);
-
 /**
  * @call_obj: const char ** message_ids
  * @call_arg: GINT_TO_POINTER(message_id_qty)
@@ -103,8 +97,6 @@ extern PanCallback *queue_tasks_moved;
 
 extern PanCallback *queue_task_status_changed;
 
-extern PanCallback *queue_max_tries_changed;
-
 /**
 ***  QUEUE MANIPULATION
 **/
@@ -128,9 +120,9 @@ extern void queue_insert_tasks (GSList * tasks, int index);
 
 /**
  * Aborts a running task, has no effect on non-running tasks.
- * @param list of tasks to abort.  queue assumes ownership of the list.
+ * @param list of tasks to stop.  queue assumes ownership of the list.
  */
-extern void queue_abort_tasks (GSList * tasks);
+extern void queue_stop_tasks (GSList * tasks);
 
 /**
  * Remove an item from the queue.  This decreases each task's refcount by 1.
@@ -156,14 +148,6 @@ extern void queue_requeue_failed_tasks (GSList * tasks);
 ***  CONNECTION
 **/
 
-extern int queue_get_max_sockets (void);
-
-extern void queue_set_max_sockets (int);
-
-extern int queue_get_max_tries (void);
-
-extern void queue_set_max_tries (int);
-
 extern gboolean queue_get_remove_failed_tasks (void);
 
 extern void queue_set_remove_failed_tasks (gboolean);
@@ -183,10 +167,9 @@ typedef enum
 	QUEUE_TASK_STATUS_NOT_QUEUED	= 0,
 	QUEUE_TASK_STATUS_QUEUED	= 1,
 	QUEUE_TASK_STATUS_RUNNING	= 2,
-	QUEUE_TASK_STATUS_FAILED	= 4,
-	QUEUE_TASK_STATUS_ABORTING	= 5,
-	QUEUE_TASK_STATUS_REMOVING	= 6,
-	QUEUE_TASK_STATUS_CONNECTING	= 7
+	QUEUE_TASK_STATUS_STOPPING	= 3,
+	QUEUE_TASK_STATUS_STOPPED	= 4,
+	QUEUE_TASK_STATUS_REMOVING	= 5
 }
 QueueTaskStatus;
 
