@@ -260,7 +260,7 @@ rule_action_apply (const RuleAction * action,
 
 			/* create a decode task */
 			task_save_weed_duplicates (tmp);
-			task = task_save_new_from_articles (article_get_subject(a), (const Article **)tmp->pdata, tmp->len);
+			task = task_save_new_from_articles ((const Article **)tmp->pdata, tmp->len);
 			task_save_set_attachments (TASK_SAVE(task), action->decode_path, NULL);
 			queue_add (TASK(task));
 			g_ptr_array_free (tmp, TRUE);
