@@ -1,14 +1,11 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Author: Charles Kerr <charles@rebelbase.com>
- *
- * Pan - A Newsreader for X
- * Copyright (C) 2001  Pan Development Team <pan@rebelbase.com>
+ * Pan - A Newsreader for Gtk+
+ * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation; version 2 of the License.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,7 +25,8 @@
 
 #include <string.h>
 
-#include <libgnomeui/libgnomeui.h>
+#include <glib.h>
+#include <gtk/gtk.h>
 
 #include <pan/base/debug.h>
 #include <pan/base/pan-glib-extensions.h>
@@ -74,16 +72,13 @@ typedef struct
 	GtkWidget * filter_om;
 	GtkWidget * filter_edit_filters_button;
 
-	GtkWidget * action_sound_tb;
-	GtkWidget * action_sound_fe;
-	GtkWidget * action_sound_test_sound_button;
 	GtkWidget * action_alert_msg_tb;
 	GtkWidget * action_alert_msg_entry;
 	GtkWidget * action_mark_tb;
 	GtkWidget * action_mark_read_rb;
 	GtkWidget * action_mark_unread_rb;
 	GtkWidget * action_decode_tb;
-	GtkWidget * action_decode_path_fe;
+	GtkWidget * action_decode_path_file_entry;
 	GtkWidget * action_flag_tb;
 	GtkWidget * action_download_body_tb;
 	GtkWidget * action_delete_tb;
@@ -132,34 +127,18 @@ static GtkWidget*
 create_action_tab (RuleEditDialog * d)
 {
 	gint row;
-	guint accel;
 	GtkWidget *w, *h, *t;
-	GtkAccelGroup *accel_group;
        
 	row = -1;
-        accel_group = gtk_accel_group_new ();
 
 	t = gtk_table_new (10, 3, FALSE);
-	gtk_table_set_row_spacings (GTK_TABLE(t), GNOME_PAD_SMALL);
-	gtk_table_set_col_spacings (GTK_TABLE(t), GNOME_PAD_SMALL);
-	gtk_container_set_border_width (GTK_CONTAINER(t), GNOME_PAD);
-
-	/* play a sound */
-	++row;
-	w = d->action_sound_tb = gtk_check_button_new_with_label ("");
-	accel = gtk_label_parse_uline (GTK_LABEL(GTK_BIN(w)->child), _("_Play a Sound:"));
-	gtk_widget_add_accelerator (w, "clicked", accel_group, accel, GDK_MOD1_MASK, 0);
-	gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-	w = d->action_sound_fe = gnome_file_entry_new (NULL, NULL);
-	gtk_table_attach (GTK_TABLE(t), w, 1, 2, row, row+1, GTK_EXPAND|GTK_FILL, 0, 0, 0);
-	w = d->action_sound_test_sound_button = gtk_button_new_with_label (_("Test Sound"));
-	gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+	gtk_table_set_row_spacings (GTK_TABLE(t), GUI_PAD_SMALL);
+	gtk_table_set_col_spacings (GTK_TABLE(t), GUI_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER(t), GUI_PAD);
 
 	/* show alert */
 	++row;
-	w = d->action_alert_msg_tb = gtk_check_button_new_with_label ("");
-	accel = gtk_label_parse_uline (GTK_LABEL(GTK_BIN(w)->child), _("Show a_lert:"));
-	gtk_widget_add_accelerator (w, "clicked", accel_group, accel, GDK_MOD1_MASK, 0);
+	w = d->action_alert_msg_tb = gtk_check_button_new_with_mnemonic (_("Show a_lert:"));
 	gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
 	w = d->action_alert_msg_entry = gtk_entry_new ();
 	gtk_table_attach (GTK_TABLE(t), w, 1, 3, row, row+1, GTK_EXPAND|GTK_FILL, 0, 0, 0);
@@ -179,46 +158,34 @@ create_action_tab (RuleEditDialog * d)
 
 	/* decode to */
 	++row;
-	w = d->action_decode_tb = gtk_check_button_new_with_label ("");
-	accel = gtk_label_parse_uline (GTK_LABEL(GTK_BIN(w)->child), _("Save attchments in:"));
-	gtk_widget_add_accelerator (w, "clicked", accel_group, accel, GDK_MOD1_MASK, 0);
+	w = d->action_decode_tb = gtk_check_button_new_with_mnemonic (_("Save attachments in:"));
 	gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-	w = d->action_decode_path_fe = gnome_file_entry_new (NULL, NULL);
+	w = d->action_decode_path_file_entry = gtk_entry_new ();
 	gtk_table_attach (GTK_TABLE(t), w, 1, 2, row, row+1, GTK_EXPAND|GTK_FILL, 0, 0, 0);
 
 	/* flag for retrieval */
 	++row;
-	w = d->action_flag_tb = gtk_check_button_new_with_label ("");
-	accel = gtk_label_parse_uline (GTK_LABEL(GTK_BIN(w)->child), _("_Flag body for download"));
-	gtk_widget_add_accelerator (w, "clicked", accel_group, accel, GDK_MOD1_MASK, 0);
+	w = d->action_flag_tb = gtk_check_button_new_with_mnemonic (_("_Flag body for download"));
 	gtk_table_attach (GTK_TABLE(t), w, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
 
 	/* download body */
 	++row;
-	w = d->action_download_body_tb = gtk_check_button_new_with_label ("");
-	accel = gtk_label_parse_uline (GTK_LABEL(GTK_BIN(w)->child), _("_Retrieve body"));
-	gtk_widget_add_accelerator (w, "clicked", accel_group, accel, GDK_MOD1_MASK, 0);
+	w = d->action_download_body_tb = gtk_check_button_new_with_mnemonic (_("_Retrieve Body"));
 	gtk_table_attach (GTK_TABLE(t), w, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
 
 	/* watch */
 	++row;
-	w = d->action_watch_thread_tb = gtk_check_button_new_with_label ("");
-	accel = gtk_label_parse_uline (GTK_LABEL(GTK_BIN(w)->child), _("_Watch thread (highlights the thread)"));
-	gtk_widget_add_accelerator (w, "clicked", accel_group, accel, GDK_MOD1_MASK, 0);
+	w = d->action_watch_thread_tb = gtk_check_button_new_with_mnemonic (_("_Watch thread (highlights the thread)"));
 	gtk_table_attach (GTK_TABLE(t), w, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
 
 	/* ignore */
 	++row;
-	w = d->action_ignore_thread_tb = gtk_check_button_new_with_label ("");
-	accel = gtk_label_parse_uline (GTK_LABEL(GTK_BIN(w)->child), _("_Ignore thread (hides the thread by default)"));
-	gtk_widget_add_accelerator (w, "clicked", accel_group, accel, GDK_MOD1_MASK, 0);
+	w = d->action_ignore_thread_tb = gtk_check_button_new_with_mnemonic (_("_Ignore thread (hides the thread by default)"));
 	gtk_table_attach (GTK_TABLE(t), w, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
 
 	/* delete */
 	++row;
-	w = d->action_delete_tb = gtk_check_button_new_with_label ("");
-	accel = gtk_label_parse_uline (GTK_LABEL(GTK_BIN(w)->child), _("_Delete article"));
-	gtk_widget_add_accelerator (w, "clicked", accel_group, accel, GDK_MOD1_MASK, 0);
+	w = d->action_delete_tb = gtk_check_button_new_with_mnemonic (_("_Delete article"));
 	gtk_table_attach (GTK_TABLE(t), w, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
 
 	return t;
@@ -231,20 +198,12 @@ populate_actions_tab (RuleEditDialog * d, const Rule * r)
 	gboolean b2;
 	GtkWidget * w;
 
-	/* sound */
-	w = d->action_sound_tb;
-	b = r!=NULL && (r->action->flags & RULE_ACTION_PLAY_SOUND) != 0;
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), b);
-	w = d->action_sound_fe;
-	w = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY(w));
-	gtk_entry_set_text (GTK_ENTRY(w), b ? r->action->sound_file : "");
-
 	/* alert message */
 	w = d->action_alert_msg_tb;
 	b = r!=NULL && (r->action->flags & RULE_ACTION_SHOW_ALERT) != 0;
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), b);
 	w = d->action_alert_msg_entry;
-	gtk_entry_set_text (GTK_ENTRY(w), b ? r->action->alert_message : "");
+	pan_gtk_entry_set_text (w, b ? r->action->alert_message : "");
 
 	/* mark read/unread */
 	b  = r!=NULL && (r->action->flags & RULE_ACTION_MARK_READ) != 0;
@@ -260,9 +219,8 @@ populate_actions_tab (RuleEditDialog * d, const Rule * r)
 	b = r!=NULL && (r->action->flags & RULE_ACTION_DECODE) != 0;
 	w = d->action_decode_tb;
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), b);
-	w = d->action_decode_path_fe;
-	w = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY(w));
-	gtk_entry_set_text (GTK_ENTRY(w), b ? r->action->decode_path : "");
+	w = d->action_decode_path_file_entry;
+	pan_gtk_entry_set_text (w, b ? r->action->decode_path : "");
 
 	/* tag for retrieval */
 	b = r!=NULL && (r->action->flags & RULE_ACTION_TAG_FOR_RETRIEVAL) != 0;
@@ -298,16 +256,6 @@ rule_from_action_tab (RuleEditDialog * d, Rule * r)
 
 	r->action->flags = 0;
 
-	/* sound */
-	w = d->action_sound_tb;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(w))) {
-		r->action->flags |= RULE_ACTION_PLAY_SOUND;
-		w = d->action_sound_fe;
-		w = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY(w));
-		pch = gtk_editable_get_chars (GTK_EDITABLE(w), 0, -1);
-		replace_gstr (&r->action->sound_file, pch);
-	}
-
 	/* alert */
 	w = d->action_alert_msg_tb;
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(w))) {
@@ -331,8 +279,7 @@ rule_from_action_tab (RuleEditDialog * d, Rule * r)
 	w = d->action_decode_tb;
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(w))) {
 		r->action->flags |= RULE_ACTION_DECODE;
-		w = d->action_decode_path_fe;
-		w = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY(w));
+		w = d->action_decode_path_file_entry;
 		pch = gtk_editable_get_chars (GTK_EDITABLE(w), 0, -1);
 		replace_gstr (&r->action->decode_path, pch);
 	}
@@ -369,73 +316,21 @@ rule_from_action_tab (RuleEditDialog * d, Rule * r)
 ******
 *****/
 
-
-static void
-filter_to_string_recursive (GString * gstr,
-                            const Filter * filter,
-                            gint depth)
-{
-	/* sanity clause */
-	g_return_if_fail (gstr!=NULL);
-	g_return_if_fail (filter!=NULL);
-	g_return_if_fail (depth>=0);
-
-	/* add this filter */
-	if (1)
-	{
-		gint i;
-		gchar * s = filter_to_string (filter);
-
-		for (i=0; i<depth; ++i)
-			g_string_append (gstr, "          ");
-		g_string_append (gstr,  s);
-		g_string_append_c (gstr, '\n');
-
-		g_free (s);
-	}
-
-	/* maybe add children */
-	if (filter_isa (filter, FILTER_AGGREGATE_CLASS_ID))
-	{
-		const FilterAggregate * fa = FILTER_AGGREGATE (filter);
-		const gint children = filter_aggregate_child_size (fa);
-
-		if (children == 0)
-		{
-			if (filter->negate)
-				g_string_append (gstr, _("  (No conditions -- no articles will match"));
-			else
-				g_string_append (gstr, _("  (No conditions -- all articles will match)"));
-		}
-		else
-		{
-			guint i;
-			for (i=0; i<fa->children->len; ++i)
-			{
-				const Filter * child = FILTER(g_ptr_array_index(fa->children,i));
-				filter_to_string_recursive (gstr, child, depth+1);
-			}
-		}
-	}
-}
-
 static void
 populate_filter_text (RuleEditDialog * d, const gchar * filter_name)
 {
 	Filter * f = filter_manager_get_named_filter (filter_name);
-	GString * gstr = g_string_new (NULL);
-	gint i = 0;
+	char * pch = filter_to_string_deep (f);
 
 	/* update the text */
-	filter_to_string_recursive (gstr, f, 0);
+
 	pan_lock ();
-	gtk_editable_delete_text (GTK_EDITABLE(d->filter_text), 0, -1);
-	gtk_editable_insert_text (GTK_EDITABLE(d->filter_text), gstr->str, gstr->len, &i);
+	gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW(d->filter_text)), pch, -1);
 	pan_unlock ();
 
 	/* cleanup */
 	pan_object_unref (PAN_OBJECT(f));
-	g_string_free (gstr, TRUE);
+	g_free (pch);
 }
 
 static void
@@ -495,8 +390,7 @@ static void
 edit_filters_cb (GtkButton * button, gpointer data)
 {
 	RuleEditDialog * d = (RuleEditDialog*) data;
-        GtkWidget * w = filter_dialog_new ();
-	gnome_dialog_set_parent (GNOME_DIALOG(w), GTK_WINDOW(d->dialog));
+        GtkWidget * w = filter_dialog_new (GTK_WINDOW(d->dialog));
 	gtk_widget_show_all (w);
 }
 
@@ -516,24 +410,24 @@ create_filter_tab (RuleEditDialog * d)
 	GtkWidget     * text_parent;
 	GtkPolicyType   policy = GTK_POLICY_AUTOMATIC;
 
-	top = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
-	gtk_container_set_border_width (GTK_CONTAINER(top), GNOME_PAD);
+	top = gtk_vbox_new (FALSE, GUI_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER(top), GUI_PAD);
 
 	/* filter optionmenu */
 	d->filter_om = gtk_option_menu_new ();
 
 	/* filter view */
-	d->filter_text = gtk_text_new (NULL, NULL);
+	d->filter_text = gtk_text_view_new ();
 
 	text_parent = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(text_parent), 
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(text_parent),
 		policy, policy);
 	gtk_container_add (GTK_CONTAINER(text_parent), d->filter_text);
-
+	
 	/* "edit filters" button */
-	h = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
-	gtk_container_set_border_width (GTK_CONTAINER(h), GNOME_PAD_SMALL);
-	w = gnome_stock_pixmap_widget_new (d->dialog, GNOME_STOCK_PIXMAP_PROPERTIES);
+	h = gtk_hbox_new (FALSE, GUI_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER(h), GUI_PAD_SMALL);
+	w = gtk_image_new_from_stock (GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_BUTTON);
 	gtk_box_pack_start (GTK_BOX(h), w, 0, 0, 0);
 	w = gtk_label_new (_("Edit Filters"));
 	gtk_box_pack_start (GTK_BOX(h), w, 0, 0, 0);
@@ -542,7 +436,7 @@ create_filter_tab (RuleEditDialog * d)
 	gtk_container_add (GTK_CONTAINER(w), h);
 
 	/* lay it all out */
-	h = gtk_hbox_new (FALSE, GNOME_PAD);
+	h = gtk_hbox_new (FALSE, GUI_PAD);
 	gtk_box_pack_start (GTK_BOX(h), gtk_label_new(_("Select Filter:")), FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX(h), d->filter_om, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX(h), gtk_label_new("      "), FALSE, FALSE, 0);
@@ -560,7 +454,7 @@ create_filter_tab (RuleEditDialog * d)
 static void
 rule_from_filter_tab (RuleEditDialog * d, Rule * r)
 {
-odebug1 ("filter name [%s]", d->filter_name);
+	/*odebug1 ("filter name [%s]", d->filter_name);*/
 	replace_gstr (&r->filter_name, g_strdup(d->filter_name));
 }
 
@@ -610,7 +504,7 @@ move_selected_newsgroups (GtkCList * from, GtkCList * to)
 
 	pan_unlock ();
 
-	g_ptr_array_free (selected, FALSE);
+	g_ptr_array_free (selected, TRUE);
 }
 
 
@@ -641,7 +535,7 @@ create_newsgroup_tab (RuleEditDialog * d)
 {
 	GtkWidget *w, *h, *t, *s, *v, *v2, *top, *v_rb;
 
-	top = gtk_vbox_new (FALSE, GNOME_PAD);
+	top = gtk_vbox_new (FALSE, GUI_PAD);
 	gtk_container_set_border_width (GTK_CONTAINER(top), 5);
 
 	/* rule applies to... */
@@ -653,7 +547,7 @@ create_newsgroup_tab (RuleEditDialog * d)
 	gtk_box_pack_start (GTK_BOX(v_rb), w, FALSE, FALSE, 0);
 
 	/* rule applies to phrase */
-	h = gtk_hbox_new (FALSE, GNOME_PAD);
+	h = gtk_hbox_new (FALSE, GUI_PAD);
 	d->groups_phrase_rb = w = gtk_radio_button_new_with_label_from_widget (
 		GTK_RADIO_BUTTON(w), _("Wildcard group specification:"));
 	gtk_box_pack_start (GTK_BOX(h), w, FALSE, FALSE, 0);
@@ -672,6 +566,7 @@ create_newsgroup_tab (RuleEditDialog * d)
 
 	/* sub list */
 	s = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(s), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_table_attach (GTK_TABLE(t), s, 0, 1, 0, 1,
 	                  GTK_EXPAND|GTK_FILL,
 	                  GTK_EXPAND|GTK_FILL, 0, 0);
@@ -686,6 +581,7 @@ create_newsgroup_tab (RuleEditDialog * d)
 
 	/* apply list */
 	s = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(s), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_table_attach (GTK_TABLE(t), s, 2, 3, 0, 1,
 	                  GTK_EXPAND|GTK_FILL,
 	                  GTK_EXPAND|GTK_FILL, 0, 0);
@@ -699,7 +595,7 @@ create_newsgroup_tab (RuleEditDialog * d)
 	gtk_clist_column_titles_show (GTK_CLIST(w));
 
 	/* add group buttons */
-	v = gtk_vbox_new (FALSE, GNOME_PAD_BIG);
+	v = gtk_vbox_new (FALSE, GUI_PAD_BIG);
 	gtk_table_attach (GTK_TABLE (t), v, 1, 2, 0, 1,
 	                  GTK_FILL, GTK_EXPAND|GTK_FILL, 5, 0);
 	v2 = gtk_vbox_new (FALSE, 0);
@@ -748,7 +644,7 @@ populate_newsgroup_tab (RuleEditDialog * d, const Rule * r)
 
 	/* phrase */
 	b = r!=NULL && r->group_type==RULE_GROUP_WILDCARD;
-	gtk_entry_set_text (GTK_ENTRY(d->groups_phrase_entry), b ? r->group_wildcard :"");
+	pan_gtk_entry_set_text (d->groups_phrase_entry, b ? r->group_wildcard :"");
 
 	/* populate the two group clists */
 	server = serverlist_get_active_server ();
@@ -761,7 +657,7 @@ populate_newsgroup_tab (RuleEditDialog * d, const Rule * r)
 	gtk_clist_clear (app);
 	for (i=0; i!=groups->len; ++i) {
 		Group * g = GROUP(g_ptr_array_index(groups,i));
-		gchar * name = (gchar*) group_get_readable_name (g);
+		char * name = (char*) group_get_name (g);
 		GtkCList * c = r!=NULL && r->group_type==RULE_GROUP_LIST && rule_test_group(r,g->name) ? app : sub;
 		gint row = gtk_clist_insert (c, -1, &name);
 		gtk_clist_set_row_data (c, row, g);
@@ -798,9 +694,10 @@ rule_from_newsgroup_tab (RuleEditDialog * d, Rule * r)
 		r->group_type = RULE_GROUP_LIST;
 		r->group_list = g_ptr_array_new ();
 		for (i=0; i!=apply->rows; ++i) {
-			gchar * text = NULL;
-			gtk_clist_get_text (apply, i, 0, &text);
-			g_ptr_array_add (r->group_list, g_strdup(text));
+			Group * g = GROUP(gtk_clist_get_row_data (apply, i));
+			if (g) {
+				g_ptr_array_add (r->group_list, g_strdup(g->name));
+			}
 		}
 	}
 }
@@ -812,7 +709,7 @@ rule_from_newsgroup_tab (RuleEditDialog * d, Rule * r)
 *****/
 
 static gint
-dialog_close_cb (GnomeDialog * dialog, gpointer data)
+dialog_close_cb (GtkDialog * dialog, gpointer data)
 {
 	RuleEditDialog * d = (RuleEditDialog*) data;
 	pan_callback_remove (filter_manager_get_filters_changed_callback(),
@@ -823,7 +720,7 @@ dialog_close_cb (GnomeDialog * dialog, gpointer data)
 }
 
 GtkWidget*
-rule_edit_dialog_create (const Rule * rule)
+rule_edit_dialog_create (GtkWindow * parent, const Rule * rule)
 {
 	GtkWidget *n, *w, *h, *d_v;
 	RuleEditDialog * d;
@@ -832,17 +729,20 @@ rule_edit_dialog_create (const Rule * rule)
 	d = g_new0 (RuleEditDialog, 1);
 
 	/* dialog */
-	w = d->dialog = gnome_dialog_new (_("Pan: Edit Rule"),
-		GNOME_STOCK_BUTTON_OK,
-		GNOME_STOCK_BUTTON_APPLY,
-		GNOME_STOCK_BUTTON_CANCEL, NULL);
-	d_v = GNOME_DIALOG(w)->vbox;
+	w = d->dialog = gtk_dialog_new_with_buttons (_("Pan: Edit Rule"),
+		parent,
+		GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
+		GTK_STOCK_OK, GTK_RESPONSE_OK,
+	        NULL);
+	d_v = GTK_DIALOG(w)->vbox;
 	gtk_window_set_policy (GTK_WINDOW(w), TRUE, TRUE, TRUE);
-	gtk_signal_connect (GTK_OBJECT(w), "close", GTK_SIGNAL_FUNC(dialog_close_cb), d);
+	gtk_signal_connect (GTK_OBJECT(w), "destroy", GTK_SIGNAL_FUNC(dialog_close_cb), d);
 	gtk_object_set_user_data (GTK_OBJECT(w), d);
 
 	/* name */
-	h = gtk_hbox_new (FALSE, GNOME_PAD);
+	h = gtk_hbox_new (FALSE, GUI_PAD);
 	w = gtk_label_new (_("Rule Name:"));
 	gtk_box_pack_start (GTK_BOX(h), w, FALSE, FALSE, 0);
 	w = d->name_entry = gtk_entry_new ();
@@ -850,7 +750,7 @@ rule_edit_dialog_create (const Rule * rule)
 	gtk_box_pack_start (GTK_BOX(d_v), h, FALSE, FALSE, 0);
 	w = gtk_label_new ("       ");
 	gtk_box_pack_start (GTK_BOX(h), w, FALSE, FALSE, 0);
-	w = gtk_check_button_new_with_label ("Apply to Incoming");
+	w = gtk_check_button_new_with_label (_("Apply to Incoming"));
 	gtk_box_pack_start (GTK_BOX(h), w, FALSE, FALSE, 0);
 	gtk_tooltips_set_tip (tips, w, _("If enabled, this rule will be applied to headers when they are downloaded."), NULL);
 	d->apply_to_incoming_tb = w;
@@ -869,10 +769,10 @@ rule_edit_dialog_create (const Rule * rule)
 	w = create_action_tab (d);
 	gtk_container_add (GTK_CONTAINER(n), w);
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK(n), w, gtk_label_new(_("Actions")));
-	gtk_box_pack_start (GTK_BOX(d_v), n, TRUE, TRUE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX(d_v), n, TRUE, TRUE, GUI_PAD_SMALL);
 
 	/* populate */
-	gtk_entry_set_text (GTK_ENTRY(d->name_entry), rule==NULL || rule->name==NULL ? _("New Rule") : rule->name);
+	pan_gtk_entry_set_text (d->name_entry, rule==NULL || rule->name==NULL ? _("New Rule") : rule->name);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(d->apply_to_incoming_tb), rule==NULL ? FALSE : rule->apply_to_incoming);
 	populate_newsgroup_tab (d, rule);
 	populate_filter_tab (d, rule==NULL ? NULL : rule->filter_name);
@@ -891,6 +791,6 @@ rule_edit_dialog_get_rule (GtkWidget * w)
 	rule_from_action_tab (d, r);
 	rule_from_filter_tab (d, r);
 	rule_from_newsgroup_tab (d, r);
-odebug2 ("returning rule [%s][%lu]", r->name, r->action->flags);
+	/*odebug2 ("returning rule [%s][%lu]", r->name, r->action->flags);*/
 	return r;
 }
