@@ -54,7 +54,7 @@ static gchar * delete_spam_rule_name;
 static gchar*
 get_rule_filename (void)
 {
-	return g_strdup_printf ("%s%crules.xml", get_data_dir(), G_DIR_SEPARATOR);
+	return g_build_filename (get_data_dir(), "rules.xml", NULL);
 }
 
 static gboolean
