@@ -64,7 +64,6 @@ typedef struct
 	GtkWidget * address_entry;
 	GtkWidget * port_spin;
 	GtkWidget * connection_limit_spin;
-	GtkWidget * reserve_reading_socket_checkbox;
 
 	GtkWidget * auth_checkbox;
 	GtkWidget * auth_username_label;
@@ -178,7 +177,6 @@ edit_dialog_populate (ServerEditDialog * d, Server * s)
 	gtk_adjustment_set_value (a, s->port);
 	a = gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON(d->connection_limit_spin));
 	gtk_adjustment_set_value (a, s->max_connections);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(d->reserve_reading_socket_checkbox), s->reserve_connection_for_bodies);
 
 	/* authorization */
 	cpch = s->username;
@@ -214,8 +212,6 @@ edit_dialog_populate_server (ServerEditDialog * d, Server * s)
 	g_strstrip (s->address);
 	s->port = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(d->port_spin));
 	s->max_connections = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(d->connection_limit_spin));
-	b = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(d->reserve_reading_socket_checkbox));
-	s->reserve_connection_for_bodies = b;
 
 	/* authorization */
 	b = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(d->auth_checkbox));
@@ -304,12 +300,12 @@ server_edit_dialog (GtkWidget * window, Server * server)
 		/* spacer to move the fields a little to the right of the name header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u); 
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+5);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+5, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u); 
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+5);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+5, 0, 0, 0, 0);
 
 		l = gtk_label_new_with_mnemonic (_("_Name:"));
 		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
@@ -342,7 +338,7 @@ server_edit_dialog (GtkWidget * window, Server * server)
 	/* spacer between "name" and "connections" */
 	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 	gtk_widget_set_usize (w, 0u, 6u); 
-	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
+	gtk_table_attach (GTK_TABLE(t), w, 0, 4, row, row+1, 0, 0, 0, 0);
 	++row;
 
 		/* title for name section */
@@ -356,17 +352,12 @@ server_edit_dialog (GtkWidget * window, Server * server)
 		/* spacer to move the fields a little to the right of the section header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u); 
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+3);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+3, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u); 
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+3);
-
-		w = gtk_check_button_new_with_mnemonic (_("_Reserve a connection for reading articles"));
-		d->reserve_reading_socket_checkbox = w;
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
-		++row;
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+3, 0, 0, 0, 0);
 
 		l = gtk_label_new_with_mnemonic (_("Connection _Limit:"));
 		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
@@ -382,11 +373,11 @@ server_edit_dialog (GtkWidget * window, Server * server)
 	/* spacer between "connections" and "authorization" */
 	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 	gtk_widget_set_usize (w, 0u, 6u); 
-	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
+	gtk_table_attach (GTK_TABLE(t), w, 0, 4, row, row+1, 0, 0, 0, 0);
 	++row;
 
 		/* title for name section */
-		g_snprintf (buf, sizeof(buf), "<b>%s</b>", _("Authorization"));
+		g_snprintf (buf, sizeof(buf), "<b>%s</b>", _("Login"));
 		l = gtk_label_new (buf);
 		gtk_misc_set_alignment (GTK_MISC(l), 0.0f, 0.5f);
 		gtk_label_set_use_markup (GTK_LABEL(l), TRUE);
@@ -396,12 +387,12 @@ server_edit_dialog (GtkWidget * window, Server * server)
 		/* spacer to move the fields a little to the right of the section header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u); 
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+3);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+3, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u); 
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+3);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+3, 0, 0, 0, 0);
 
 		w = d->auth_checkbox = gtk_check_button_new_with_mnemonic (_("Server requires authori_zation"));
 		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
@@ -430,7 +421,7 @@ server_edit_dialog (GtkWidget * window, Server * server)
 	/* spacer between "authorization" and "newsrc" */
 	w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 	gtk_widget_set_usize (w, 0u, 6u); 
-	gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 4, row, row+1);
+	gtk_table_attach (GTK_TABLE(t), w, 0, 4, row, row+1, 0, 0, 0, 0);
 	++row;
 
 		/* title for name section */
@@ -444,12 +435,12 @@ server_edit_dialog (GtkWidget * window, Server * server)
 		/* spacer to move the fields a little to the right of the section header */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 18u, 0u); 
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 0, 1, row, row+2);
+		gtk_table_attach (GTK_TABLE(t), w, 0, 1, row, row+2, 0, 0, 0, 0);
 
 		/* spacer between the controls and their labels */
 		w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
 		gtk_widget_set_usize (w, 12u, 0u); 
-		gtk_table_attach_defaults (GTK_TABLE(t), w, 2, 3, row, row+2);
+		gtk_table_attach (GTK_TABLE(t), w, 2, 3, row, row+2, 0, 0, 0, 0);
 
 		w = d->newsrc_checkbox = gtk_check_button_new_with_mnemonic (_("Us_e .newsrc file"));
 		gtk_table_attach_defaults (GTK_TABLE(t), w, 1, 4, row, row+1);
