@@ -21,43 +21,13 @@
 #define __PAN_SOCKET_H__
 
 #include <time.h>
-#include <glib.h>
+#include <glib/gtypes.h>
 #include <pan/base/pan-object.h>
 
 #define PAN_SOCKET(a) ((PanSocket *)a)
 
 typedef struct _PanSocket           PanSocket;
 
-struct _PanSocket
-{
-	/* parent class */
-	PanObject parent;
-
-	/* public fields */
-	time_t last_action_time;
-
-	/* public fields */
-	gboolean error;
-
-	/* private fields */  
-	gboolean need_auth;
-	gint sockfd;
-	gchar * inbuf;
-	gchar * endbuf;
-	gchar * inptr;
-	gchar * nntp_group_name;
-	gchar * nntp_username;
-	gchar * nntp_password;
-	GArray * line_buffer;
-
-	/* statistics */
-	char * host_address;
-	char * host_name;
-	unsigned int bytes_read;
-	unsigned int bytes_written;
-	time_t byte_count_start_time;
-};
-
 /**
 ***  PROTECTED
 **/
@@ -83,14 +53,6 @@ void         pan_socket_set_nntp_auth        (PanSocket            * socket,
                                               const char           * username,
                                               const char           * password);
 /**
-***  PUBLIC - UTIL
-**/
-
-int         fd_write                        (int                   fd,
-                                             const char          * buf,
-                                             int                   len);
-
-/**
 ***  PUBLIC - I/O
 **/
 
@@ -110,11 +72,40 @@ void         pan_socket_flush                (PanSocket            * sock);
 ***  STATISTICS
 **/
 
+time_t       pan_socket_get_statistics_start_time (const PanSocket  * sock);
+
 double       pan_socket_get_xfer_rate_KBps  (const PanSocket      * sock);
 
 void         pan_socket_reset_statistics    (PanSocket            * sock);
 
 gulong       pan_socket_get_total_xfer_K    (void);
 
+/**
+***
+**/
+
+gboolean     pan_socket_needs_auth          (const PanSocket      * sock);
+
+const char*  pan_socket_get_username        (const PanSocket      * sock);
+
+const char*  pan_socket_get_password        (const PanSocket      * sock);
+
+const char*  pan_socket_get_server_name     (const PanSocket      * sock);
+
+const char*  pan_socket_get_current_group   (const PanSocket      * sock);
+
+void         pan_socket_set_current_group   (PanSocket            * sock,
+                                             const char           * groupname);
+
+void         pan_socket_set_error_flag      (PanSocket            * sock,
+                                             gboolean               err_state);
+
+gboolean     pan_socket_get_error_flag      (const PanSocket      * sock);
+
+time_t       pan_socket_get_last_action_time  (const PanSocket    * sock);
+
+void         pan_socket_set_last_action_time  (PanSocket          * sock,
+                                               time_t               action_time);
+
 
 #endif /* __PAN_SOCKET_H__ */
