@@ -320,7 +320,7 @@ status_item_view_set_item_nolock (GtkWidget * w, StatusItem* item)
 		gui_queue_add (set_percentage_mainthread, argset_new2 (impl->progress, NULL));
 		prog = GTK_PROGRESS(impl->progress);
 		g_mutex_lock (impl->last_status_mutex);
-		g_string_assign (impl->last_status, "");
+		g_string_truncate (impl->last_status, 0);
 		g_mutex_unlock (impl->last_status_mutex);
 		replace_gstr (&prog->format, g_strdup(""));
 		GTK_PROGRESS_GET_CLASS (GTK_OBJECT(prog))->update (prog);
