@@ -31,7 +31,8 @@ typedef struct
 	Task           task;
 
 	/* private */
-	int            working_index;
+	GQueue       * download_mids;
+	int            download_mids_qty;
 	char *         acache_key;
 }
 TaskBodies;
