@@ -51,7 +51,7 @@
 **********************  Private Function Prototypes
 *********************/
 
-static int task_group_count_run (Task*);
+static void task_group_count_run (Task*, PanSocket*);
 static char* task_group_count_describe (const StatusItem*);
 
 /*********************
@@ -103,15 +103,12 @@ task_group_count_new   (Group      ** groups,
         debug1 (DEBUG_PAN_OBJECT, "task_group_count: %p", t);
 
 	/* initialize the parent class */
-	task_constructor (TASK(t),
-	                  task_group_count_destructor,
-	                  task_group_count_describe,
-	                  task_group_count_run,
-	                  groups[0]->server, TRUE, TRUE);
+	task_constructor (TASK(t), task_group_count_destructor, task_group_count_describe, groups[0]->server, TRUE);
 
 	/* initialize the task-bodies */
 	t->groups = g_ptr_array_new ();
 	pan_g_ptr_array_assign (t->groups, (gpointer*)groups, qty);
+	task_state_set_need_socket (&TASK(t)->state, groups[0]->server, task_group_count_run);
 
 	return PAN_OBJECT(t);
 }
@@ -135,20 +132,19 @@ task_group_count_describe (const StatusItem * status)
 ******
 *****/
 
-static int
-task_group_count_run (Task * task)
+static void
+task_group_count_run (Task * task, PanSocket * sock)
 {
 	TaskGroupCount * t = TASK_GROUP_COUNT(task);
 	GPtrArray * groups = t->groups;
 	StatusItem * status = STATUS_ITEM(task);
-	gint result;
-	gint retval = TASK_SUCCESS;
 	guint i;
 
 	/* for each group, get the numbers... */
 	status_item_emit_init_steps (status, groups->len);
 	for (i=0; i!=groups->len; ++i)
 	{
+		int result;
 		gulong qty=0, low=0, high=0;
 		Group * g = GROUP(g_ptr_array_index(groups,i));
 
@@ -159,11 +155,7 @@ task_group_count_run (Task * task)
 			i, groups->len);
 
 		/* get the numbers for this group */
-		result = nntp_get_group_info (STATUS_ITEM(task),
-		                              TASK(task)->sock,
-		                              g->name,
-		                              &qty, &low, &high,
-		                              &TASK(task)->hint_abort);
+		result = nntp_get_group_info (STATUS_ITEM(task), sock, g->name, &qty, &low, &high, &TASK(task)->hint_abort);
 		if (result == TASK_SUCCESS)
 		{
 			/* update the group object */
@@ -178,5 +170,5 @@ task_group_count_run (Task * task)
 		}
 	}
 
-	return retval;
+	task_state_set (&task->state, TASK_SUCCESS);
 }
