@@ -55,11 +55,11 @@
 **********************  Private Function Prototypes
 *********************/
 
-static gint task_grouplist_run (Task*);
+static void task_grouplist_run (Task*, PanSocket*);
 
-static int nntp_grouplist_download_all (TaskGroupList*);
+static int nntp_grouplist_download_all (TaskGroupList*, PanSocket*);
 
-static int nntp_grouplist_download_new (TaskGroupList*);
+static int nntp_grouplist_download_new (TaskGroupList*, PanSocket*);
 
 static gchar* task_grouplist_describe (const StatusItem*);
 
@@ -98,10 +98,8 @@ task_grouplist_new (Server *server,
 	debug1 (DEBUG_PAN_OBJECT, "task_grouplist_new: %p", item);
 	
 	/* construct superclass... */
-	task_constructor (TASK(item),
-		task_grouplist_destructor,
-		task_grouplist_describe,
-		task_grouplist_run, server, FALSE, TRUE);
+	task_constructor (TASK(item), task_grouplist_destructor, task_grouplist_describe, server, TRUE);
+	task_state_set_need_socket (&TASK(item)->state, server, task_grouplist_run);
 
 	/* construct this class... */
 	item->server = server;
@@ -151,58 +149,70 @@ task_grouplist_describe (const StatusItem* item)
 	return retval;
 }
 
-static gint
-task_grouplist_run (Task *item)
+static void
+task_grouplist_run (Task * task, PanSocket * sock)
 {
-	TaskGroupList *item_g = TASK_GROUPLIST(item);
-	Server *server = item->server;
+	TaskGroupList * task_g = TASK_GROUPLIST(task);
+	Server * server = task->server;
 	int result;
 
-	status_item_emit_status_va (STATUS_ITEM(item),
-		_("Got %d groups from server \"%s\""),
-		(int)item_g->groups->len,
-		server_get_name (server));
+	status_item_emit_status_va (STATUS_ITEM(task),
+	                            _("Got %d groups from server \"%s\""),
+	                            (int)task_g->groups->len,
+	                            server_get_name (server));
 
 	/**
 	***  Try to get the groups from the server
 	**/
 
-	switch (item_g->download_type)
+	result = TASK_SUCCESS;
+	switch (task_g->download_type)
 	{
 		case GROUPLIST_ALL:
-			result = nntp_grouplist_download_all (item_g);
+			result = nntp_grouplist_download_all (task_g, sock);
 			break;
 		case GROUPLIST_NEW:
-			result = nntp_grouplist_download_new (item_g);
-			break;
-		default:
-			pan_warn_if_reached ();
-			result = TASK_FAIL_HOPELESS;
+			result = nntp_grouplist_download_new (task_g, sock);
 			break;
 	}
-	if (result != TASK_SUCCESS)
-		return result;
 
 	/**
-	***  The downloading of groups is done;
-	***  update Pan with the list that we got
+	***  Add any that we got
 	**/
 
-	status_item_emit_status_va (STATUS_ITEM(item),
-		_("Adding groups to server \"%s\""), server_get_name (server));
+	switch (result)
+	{
+		case TASK_SUCCESS:
 
-	/* for the next time we call GROUPLIST_NEW... */
-	server->last_newgroup_list_time = time(0);
+			/* for the next time we call GROUPLIST_NEW... */
+			server->last_newgroup_list_time = time(0);
 
-	/* add the groups we don't already have */
-	if (1) {
-		GPtrArray * unused = g_ptr_array_new ();
-		server_add_groups (server, (Group**)item_g->groups->pdata, item_g->groups->len, NULL, unused);
-		g_ptr_array_free (unused, TRUE);
+			/* let the user know what's going on ... */
+			status_item_emit_status_va (STATUS_ITEM(task),
+			                            _("Adding groups to server \"%s\""),
+			                            server_get_name (server));
+
+			/* add the groups we don't already have */
+			if (1) {
+				GPtrArray * unused = g_ptr_array_new ();
+				server_add_groups (server, (Group**)task_g->groups->pdata, task_g->groups->len, NULL, unused);
+				g_ptr_array_free (unused, TRUE);
+			}
+			g_ptr_array_set_size (task_g->groups, 0);
+
+			task_state_set (&task->state, TASK_SUCCESS);
+			break;
+
+		case TASK_FAIL_HOPELESS:
+			/* something went completely wrong -- unable to log in, maybe? */
+			task_state_set (&task->state, TASK_FAIL_HOPELESS);
+			break;
+
+		default:
+			/* something went wrong but it's not hopeless, so try again */
+			task_state_set_need_socket (&task->state, task->server, task_grouplist_run);
+			break;
 	}
-	g_ptr_array_set_size (item_g->groups, 0);
-
-	return TASK_SUCCESS;
 }
 
 
@@ -225,11 +235,10 @@ compare_ppgroup_ppgroup (gconstpointer a, gconstpointer b, gpointer unused)
 
 
 static int
-nntp_grouplist_download_all (TaskGroupList * item)
+nntp_grouplist_download_all (TaskGroupList * item, PanSocket * sock)
 {
 	GPtrArray * groups = item->groups;
 	const gboolean * const abort = &TASK(item)->hint_abort;
-	PanSocket * sock = TASK(item)->sock;
 	Server * server = TASK(item)->server;
 	int read_err = 0;
 	int description_count = 0;
@@ -397,7 +406,7 @@ nntp_grouplist_download_all (TaskGroupList * item)
  * based on RFC977 - JEL
  *--------------------------------------------------------------------*/
 static int
-nntp_grouplist_download_new (TaskGroupList * item)
+nntp_grouplist_download_new (TaskGroupList * item, PanSocket * sock)
 {
 	GPtrArray * groups = item->groups;
 	const gboolean * const abort = &TASK(item)->hint_abort;
@@ -407,7 +416,6 @@ nntp_grouplist_download_new (TaskGroupList * item)
 	gint val = 0;
 	char datestr[64];
 	struct tm gmt;
-	PanSocket * sock = TASK(item)->sock;
 	StatusItem * status = STATUS_ITEM(item);
 	Group * group = NULL;
 
