@@ -38,6 +38,7 @@
 #include <pan/base/pan-i18n.h>
 
 #include <pan/nntp.h>
+#include <pan/sockets.h>
 #include <pan/task-headers.h>
 #include <pan/rules/rule-manager.h>
 
@@ -59,11 +60,12 @@
 **********************  Private Function Prototypes
 *********************/
 
-static gint task_headers_run (Task* item);
+static void task_headers_run_download (Task * task, PanSocket * sock);
 
 static gchar* task_headers_describe (const StatusItem *item);
 
 static gint task_get_header_range (TaskHeaders   * task,
+                                   PanSocket     * sock,
                                    gulong        * setme_lo_article_in_group,
                                    gulong        * setme_hi_article_in_group,
                                    gulong        * setme_lo_article_to_fetch,
@@ -124,10 +126,9 @@ real_task_headers_new (Group                * group,
 	task_constructor (TASK(item),
 	                  task_headers_destructor,
 	                  task_headers_describe,
-	                  task_headers_run,
 	                  group->server,
-	                  TRUE, /* high priority */
-	                  TRUE);
+	                  TRUE); /* high priority */
+	task_state_set_need_socket (&TASK(item)->state, group->server, task_headers_run_download);
 	TASK(item)->type = TASK_TYPE_HEADERS;
 	item->group = group;
 	item->download_type = dl_type;
@@ -174,8 +175,8 @@ task_headers_new_sample (Group     * group,
 ******
 *****/
 
-static gint
-task_headers_run (Task* task)
+static void
+task_headers_run_download (Task * task, PanSocket * sock)
 {
 	StatusItem * status = STATUS_ITEM(task);
 	TaskHeaders * task_h = TASK_HEADERS(task);
@@ -184,15 +185,15 @@ task_headers_run (Task* task)
 	gulong total_in_group;
 	const char * progress_fmt;
 	gboolean reffed = FALSE;
-	gboolean retval_set = FALSE;
-	gint retval = TASK_SUCCESS;
-	gint result;
+	gboolean state_set = FALSE;
+	TaskStateEnum state = TASK_SUCCESS;
+	int result;
 	debug_enter ("task_headers_run");
 
 	/* get up-to-date information about the group */
 	progress_fmt = NULL;
 	low_in_group = high_in_group = low_to_fetch = high_to_fetch = 0;
-	result = task_get_header_range (task_h,
+	result = task_get_header_range (task_h, sock,
 	                                &low_in_group,
 	                                &high_in_group,
 	                                &low_to_fetch,
@@ -200,8 +201,8 @@ task_headers_run (Task* task)
 	                                &total_in_group,
 	                                &progress_fmt);
 	if (result != TASK_SUCCESS) {
-		retval_set = TRUE;
-		retval = result;
+		state_set = TRUE;
+		state = result;
 	}
 
 
@@ -210,13 +211,13 @@ task_headers_run (Task* task)
 		low_to_fetch = MAX (low_to_fetch, task_h->group->article_high+1);
 
 	/* no articles to fetch */
-	if (!retval_set && (high_to_fetch==0 || low_to_fetch>high_to_fetch)) {
-		retval_set = TRUE;
-		retval = TASK_SUCCESS;
+	if (!state_set && (high_to_fetch==0 || low_to_fetch>high_to_fetch)) {
+		state_set = TRUE;
+		state = TASK_SUCCESS;
 	}
 
 	/* if articles to fetch, try fetching them */
-	if (!retval_set)
+	if (!state_set)
 	{
 		GPtrArray * articles;
 		gint steps;
@@ -247,7 +248,7 @@ task_headers_run (Task* task)
 		/* get the article headers... */
 		articles = g_ptr_array_new ();
 		result = nntp_download_headers (status,
-		                                task->sock,
+		                                sock,
 		                                task_h->group,
 		                                low_to_fetch,
 		                                high_to_fetch,
@@ -255,11 +256,10 @@ task_headers_run (Task* task)
 		                                progress_fmt,
 		                                articles);
 		if (result != TASK_SUCCESS) {
-			retval_set = TRUE;
-			retval = result;
+			state_set = TRUE;
+			state = result;
 		}
 
-
 		if (1)
 		{
 			GPtrArray * a = group_get_article_array (task_h->group);
@@ -331,7 +331,7 @@ task_headers_run (Task* task)
 	}
 
 	/* Download bodies, if any */
-	if (!retval_set && task->identifiers->len!=0)
+	if (!state_set && task->identifiers->len!=0)
 	{
 		/* refresh the ui */
 		status_item_emit_init_steps (status, task->identifiers->len);
@@ -339,15 +339,15 @@ task_headers_run (Task* task)
 
 		/* try downloading the bodies */
 		result = nntp_download_bodies (status,
-		                               task->sock,
+		                               sock,
 		                               &task->hint_abort,
 		                               (MessageIdentifier**) task->identifiers->pdata,
 		                               task->identifiers->len,
 		                               &task_h->body_index,
 		                               FALSE);
 		if (result != TASK_SUCCESS) {
-			retval_set = TRUE;
-			retval = result;
+			state_set = TRUE;
+			state = result;
 		}
 	}
 
@@ -360,11 +360,15 @@ task_headers_run (Task* task)
 	}
 
 	/* if we made it this far without fail, return success. */
-	if (!retval_set)
-		retval = TASK_SUCCESS;
+	if (!state_set)
+		state = TASK_SUCCESS;
+
+	if (state==TASK_SUCCESS || state==TASK_FAIL_HOPELESS)
+		task_state_set (&task->state, state);
+	else
+		task_state_set_need_socket (&task->state, task->server, task_headers_run_download);
 
 	debug_exit ("task_headers_run");
-	return retval;
 }
 
 /*****
@@ -373,6 +377,7 @@ task_headers_run (Task* task)
 
 static int
 task_get_header_range (TaskHeaders   * task,
+                       PanSocket     * sock,
 		       gulong        * setme_lo_article_in_group,
 		       gulong        * setme_hi_article_in_group,
                        gulong        * setme_lo_article_to_fetch,
@@ -381,7 +386,6 @@ task_get_header_range (TaskHeaders   * task,
 		       const char   ** setme_progress_fmt)
 {
 	const gboolean * const abort = &TASK(task)->hint_abort;
-	PanSocket *sock = TASK(task)->sock;
 	Group *group = TASK_HEADERS(task)->group;
 	HeaderDownloadType dl_type = TASK_HEADERS(task)->download_type;
 	const char * progress_fmt;
