@@ -34,6 +34,7 @@
 #include <pan/gui.h>
 #include <pan/prefs.h>
 #include <pan/queue.h>
+#include <pan/sockets.h>
 #include <pan/task-manager.h>
 #include <pan/util.h>
 
@@ -215,7 +216,7 @@ stop_clicked_cb (GtkButton   * button,
 	GSList * tasks = get_selected_task_list (ui);
 
 	if (tasks)
-		queue_abort_tasks (tasks);
+		queue_stop_tasks (tasks);
 }
 
 static void
@@ -246,23 +247,6 @@ requeue_cb (GtkButton   * button,
 ***  Display
 **/
 
-static int
-get_secs_left (const Task * task)
-{
-	int retval = 0;
-
-	if (task->sock)
-	{
-		double elapsed_time = time(0) - task->sock->byte_count_start_time;
-		double progress = status_item_get_progress_of_100 (STATUS_ITEM(task)) / 100.0;
-		double safe_progress = MAX(progress, 0.01); /* don't divide by 0 */
-		const double estimated_total_time = elapsed_time/safe_progress;
-		retval = (int)(estimated_total_time - elapsed_time);
-	}
-
-	return retval;
-}
-
 static void
 get_percent_str (const Task   * task,
                  gchar        * buf,
@@ -284,25 +268,47 @@ get_xfer_str (const Task    * task,
               gchar         * buf,
               gint            buf_size)
 {
-	if (!task->sock)
-	{
+
+	int seconds_remaining;
+	guint i;
+	gulong bytes_total;
+	gulong bytes_left;
+	double KB_left;
+	double progress;
+	double KBps = 0.0;
+	GSList * l;
+
+	/* get the current speed */
+	KBps = 0.0;
+	for (l=task->sockets; l!=NULL; l=l->next)
+		KBps += pan_socket_get_xfer_rate_KBps (PAN_SOCKET(l->data));
+
+	/* get the total byte count of the task */
+	bytes_total = 0ul;
+	for (i=0; i<task->identifiers->len; ++i)
+		bytes_total += MESSAGE_IDENTIFIER (g_ptr_array_index (task->identifiers, i))->byte_qty;
+
+	/* get the remaining byte count of the task */
+	progress = status_item_get_progress_of_100 (STATUS_ITEM(task)) / 100.0;
+	bytes_left = bytes_total * (1.0 - progress);
+	KB_left = bytes_left / 1024.0;
+	seconds_remaining = (int)(KB_left / KBps);
+
+	/* write the string */
+	if (seconds_remaining <= 0)
 		*buf = '\0';
-	}
-	else
-	{
-		int secs_left = get_secs_left (task);
-		const int h = secs_left / 3600;
-		const int m = (secs_left % 3600) / 60;
-		const int s = secs_left % 60;
-		const double KBps = pan_socket_get_xfer_rate_KBps (task->sock);
+	else {
+		const int h = seconds_remaining / 3600;
+		const int m = (seconds_remaining % 3600) / 60;
+		const int s = seconds_remaining % 60;
 		g_snprintf (buf, buf_size, _("%d:%02d:%02d (%.2f KB/s)"), h, m, s, KBps);
 	}
 }
 
 static void
 get_status_str (const Task     * task,
-                gchar          * buf,
-                gint             buf_size)
+                char           * buf,
+                int              buf_size)
 {
 	const char* status_str;
 	QueueTaskStatus status = queue_get_task_status(task);
@@ -318,26 +324,21 @@ get_status_str (const Task     * task,
 		case QUEUE_TASK_STATUS_RUNNING:
 			status_str = _("Running");
 			break;
-		case QUEUE_TASK_STATUS_FAILED:
-			status_str = _("Failed");
+		case QUEUE_TASK_STATUS_STOPPED:
+			status_str = _("Stopped");
 			break;
-		case QUEUE_TASK_STATUS_ABORTING:
-			status_str = _("Aborting");
+		case QUEUE_TASK_STATUS_STOPPING:
+			status_str = _("Stopping");
 			break;
-		case QUEUE_TASK_STATUS_CONNECTING:
-			status_str = _("Connecting");
-			break;
-		default:
-			status_str = _("???");
+		case QUEUE_TASK_STATUS_REMOVING:
+			status_str = _("Removing");
 			break;
 	}
 
 	if (!queue_is_online() && status==QUEUE_TASK_STATUS_QUEUED)
 		g_snprintf (buf, buf_size, _("Offline"));
-	else if (!task->tries)
-		g_snprintf (buf, buf_size, "%s", status_str);
 	else
-		g_snprintf (buf, buf_size, _("%s (%d tries)"), status_str, task->tries);
+		g_snprintf (buf, buf_size, "%s", status_str);
 }
 
 static void
@@ -581,7 +582,7 @@ tasks_moved_cb (gpointer call_obj, gpointer call_arg, gpointer client_arg)
 static void
 update_titlebar_lock (ManagerUI * ui)
 {
-	int running, queued, failed;
+	int running, queued, stopped;
 	guint i;
 	GPtrArray * tasks;
 	char title[1024] = { '\0' };
@@ -589,7 +590,7 @@ update_titlebar_lock (ManagerUI * ui)
 	g_return_if_fail (ui!=NULL);
 
 	/* get information about the tasks */
-	running = queued = failed = 0;
+	running = queued = stopped = 0;
 	tasks = queue_get_tasks ();
 	for (i=0; i<tasks->len; ++i) {
 		Task * t = TASK(g_ptr_array_index(tasks,i));
@@ -599,13 +600,13 @@ update_titlebar_lock (ManagerUI * ui)
 			++queued;
 		else if (status==QUEUE_TASK_STATUS_RUNNING)
 			++running;
-		else if (status==QUEUE_TASK_STATUS_ABORTING || status==QUEUE_TASK_STATUS_FAILED)
-			++failed;
+		else if (status==QUEUE_TASK_STATUS_STOPPED)
+			++stopped;
 	}
 
 	/* create a titlebar */
-	if (failed)
-		g_snprintf (title, sizeof(title), _("Pan %s Task Manager (%d Queued, %d Running, %d Failed)"), VERSION, queued, running, failed);
+	if (stopped)
+		g_snprintf (title, sizeof(title), _("Pan %s Task Manager (%d Queued, %d Running, %d Stopped)"), VERSION, queued, running, stopped);
 	else if (queued || running)
 		g_snprintf (title, sizeof(title), _("Pan %s Task Manager (%d Queued, %d Running)"), VERSION, queued, running);
 	else 
@@ -739,7 +740,7 @@ task_manager_build_ui (GtkWidget * window)
 
 	/* redo */
 	gtk_toolbar_insert_stock (GTK_TOOLBAR(toolbar), GTK_STOCK_REDO,
-	                          _("Restart selected stopped/failed Task(s)"), NULL,
+	                          _("Restart Selected Task(s)"), NULL,
 	                          G_CALLBACK(requeue_cb), ui, -1);
 
         /* cancel */
