@@ -310,17 +310,15 @@ task_post_describe (const StatusItem* si)
 	return g_strdup_printf (fmt, g_mime_message_get_subject(message));
 }
 
-static int
-task_post_run (Task* task)
+static void
+task_post_run (Task * task, PanSocket * sock)
 {
 	int status;
+	TaskPost * post = TASK_POST(task);
 	debug_enter ("task_post_run");
 
 	/* try to send the message */
-	status = send_message_now (STATUS_ITEM(task),
-	                           TASK(task)->sock,
-	                           TASK(task)->server,
-	                           TASK_POST(task)->message);
+	status = send_message_now (STATUS_ITEM(task), sock, task->server, post->message);
 
 	if (status != 0)
 	{
@@ -329,7 +327,7 @@ task_post_run (Task* task)
 
 		/* write the message back to pan.sendlater, because
 		 * PAN_TO or PAN_NEWSGROUPS may have been cleared */
-	       	message = TASK_POST(task)->message;
+	       	message = post->message;
 		folder_add_message (serverlist_get_named_folder(PAN_SENDLATER), message);
 
 	       	text = g_string_new (NULL);
@@ -347,7 +345,7 @@ task_post_run (Task* task)
 	}
 	else /* successful; dispose of the article object. */
 	{
-		GMimeMessage * message = TASK_POST(task)->message;
+		GMimeMessage * message = post->message;
 		folder_remove_message (serverlist_get_named_folder(PAN_SENDLATER), message);
 		folder_add_message (serverlist_get_named_folder(PAN_SENT), message);
 	}
@@ -356,8 +354,8 @@ task_post_run (Task* task)
 	 * the message in pan.sendlater anyway.  This way the user
 	 * can try to correct the problem before resending.
 	 */
+	task_state_set (&task->state, status==0 ? TASK_SUCCESS : TASK_FAIL_HOPELESS);
 	debug_exit ("task_post_run");
-	return status==0 ? TASK_SUCCESS : TASK_FAIL_HOPELESS;
 }
 
 /************
@@ -379,10 +377,8 @@ task_post_new (Server * server, GMimeMessage * message)
         debug1 (DEBUG_PAN_OBJECT, "task_post_new: %p", post);
 
 	/* initialize the parent class */
-	task_constructor (TASK(post), task_post_destructor,
-	                              task_post_describe,
-	                              task_post_run,
-	                              server, TRUE, TRUE);
+	task_constructor (TASK(post), task_post_destructor, task_post_describe, server, TRUE);
+	task_state_set_need_socket (&TASK(post)->state, server, task_post_run);
 	TASK(post)->type = TASK_TYPE_POST;
 
 	/* initialize the task-post */
