@@ -64,7 +64,8 @@
 **********************  Private Function Prototypes
 *********************/
 
-static gint task_save_run (Task* task);
+static void task_save_run_download (Task * task, PanSocket * sock);
+static void task_save_run_decode (Task * task, PanSocket * sock);
 
 static char* task_save_describe (const StatusItem* item);
 
@@ -110,9 +111,40 @@ task_save_describe (const StatusItem* item)
 ******
 *****/
 
+char*
+expand_download_dir (const char * dir, const char * groupname)
+{
+	char * retval = g_strdup (dir);
+
+	if (is_nonempty_string(groupname))
+	{
+		if (strstr (dir, "%g") != NULL)
+		{
+			replace_gstr (&retval, pan_substitute (retval, "%g", groupname));
+		}
+
+		if (strstr (dir, "%G") != NULL)
+		{
+			char tmp[PATH_MAX], *pch;
+			g_snprintf (tmp, sizeof(tmp), "%s.", groupname);
+			for (pch=tmp; *pch; ++pch)
+				if (*pch == '.')
+					*pch = G_DIR_SEPARATOR;
+			replace_gstr (&retval, pan_substitute (retval, "%G", tmp));
+		}
+	}
+
+	return retval;
+}
+
+/*****
+******
+*****/
+
 static void
 task_save_destructor (PanObject* object)
 {
+	gpointer p;
 	Task * task = TASK(object);
 	TaskSave * task_save = TASK_SAVE(object);
 	debug_enter ("task_save_destructor");
@@ -123,6 +155,9 @@ task_save_destructor (PanObject* object)
 	replace_gstr (&task_save->filename_attachments, NULL);
 	replace_gstr (&task_save->path_bodies, NULL);
 	replace_gstr (&task_save->filename_bodies, NULL);
+	while ((p = g_queue_pop_head (task_save->download_mids)))
+		g_object_unref (G_OBJECT(p));
+	g_queue_free (task_save->download_mids);
 	acache_checkin (ACACHE_DEFAULT_KEY, (MessageIdentifier**)task->identifiers->pdata, task->identifiers->len);
 
 	/* destruct the superclass */
@@ -136,8 +171,9 @@ task_save_new (Server              * server,
                int                   mid_qty)
 {
 	int i;
+	int lines_total = 0;
+	int lines_cached = 0;
 	TaskSave * task;
-	gboolean need_socket;
 	debug_enter ("task_save_new");
 
 	/* sanity clause */
@@ -148,30 +184,45 @@ task_save_new (Server              * server,
 	/* checkout the article bodies */
 	acache_checkout (ACACHE_DEFAULT_KEY, mids, mid_qty);
 
-	/* do we need to download any of these articles? */
-	need_socket = FALSE;
-	for (i=0; i<mid_qty && !need_socket; ++i)
-		if (!acache_has_message (ACACHE_DEFAULT_KEY, mids[i]->message_id))
-			need_socket = TRUE;
-
 	/* create the task */
        	task = g_new0 (TaskSave, 1);
         debug1 (DEBUG_PAN_OBJECT, "task_save_new: %p", task);
 	task_constructor (TASK(task),
 			  task_save_destructor,
 			  task_save_describe,
-			  task_save_run,
-			  server, FALSE, need_socket);
+			  server, FALSE);
+	task_add_identifiers (TASK(task), mids, mid_qty);
 
 	/* create the task-save */
 	TASK(task)->type = TASK_TYPE_SAVE;
-	task->runval = TASK_FAIL;
 	task->path_attachments = NULL;
 	task->filename_attachments = NULL;
 	task->path_bodies = NULL;
 	task->filename_bodies = NULL;
-	task_add_identifiers (TASK(task), mids, mid_qty);
+	task->download_mids = g_queue_new ();
+	for (i=0; i<mid_qty; ++i) {
+		lines_total += mids[i]->line_qty;
+		if (acache_has_message (ACACHE_DEFAULT_KEY, mids[i]->message_id))
+			lines_cached += mids[i]->line_qty;
+		else {
+			g_object_ref (mids[i]);
+			g_queue_push_tail (task->download_mids, mids[i]);
+		}
+	}
+	task->download_mids_qty = task->download_mids->length;
 
+	/* set the task status */
+	if (g_queue_is_empty (task->download_mids))
+		task_state_set_need_work (&TASK(task)->state, task_save_run_decode);
+	else
+		task_state_set_need_socket (&TASK(task)->state, server, task_save_run_download);
+
+	/* init the status-item */
+	status_item_emit_init_steps (STATUS_ITEM(task), lines_total);
+	status_item_emit_set_step (STATUS_ITEM(task), lines_cached);
+	status_item_emit_status_va (STATUS_ITEM(task), _("Saving `%s'"), message_identifier_get_readable_name(mids[0]));
+
+	/* return the task */
 	debug_exit ("task_save_new");
 	return PAN_OBJECT(task);
 }
@@ -368,83 +419,44 @@ get_unique_fname (const char * path, const char * fname)
 	return pan_file_normalize_inplace (g_string_free (filename, FALSE));
 }
 
-static int
-task_save_run (Task * task)
+/**
+***
+**/
+
+static void
+task_save_run_decode (Task * task, PanSocket * sock)
 {
-	int index = 0;
-	int retval = TASK_SUCCESS;
-	gboolean have_bodies = FALSE;
-	Server * server;
 	TaskSave * task_save;
-	debug_enter ("task_save_run");
+	TaskStateEnum retval = TASK_SUCCESS;
 
-	/* sanity clause */
-	g_return_val_if_fail (task!=NULL, TASK_SAVE(task)->runval=TASK_FAIL_HOPELESS);
-	g_return_val_if_fail (task->identifiers->len>0, TASK_SAVE(task)->runval=TASK_FAIL_HOPELESS);
-
-	task_save = TASK_SAVE(task);
-	server = task->server;
-
-	/**
-	*** Get the article bodies that we don't already have
-	*** (nntp_download_bodies will just skip over any
-	*** that are already in acache)
-	**/
-
-	if (task->identifiers->len)
-	{
-		int result = nntp_download_bodies (STATUS_ITEM(task),
-		                                   task->sock,
-		                                   &task->hint_abort,
-		                                   (MessageIdentifier **) task->identifiers->pdata,
-		                                   task->identifiers->len,
-		                                   &index,
-		                                   TRUE);
-
-		have_bodies = result == TASK_SUCCESS;
-
-		if (result != TASK_SUCCESS)
-		{
-       			MessageIdentifier * mid = MESSAGE_IDENTIFIER (g_ptr_array_index (task->identifiers, 0));
-			const char * readable = message_identifier_get_readable_name (mid);
-			
-			status_item_emit_error_va (STATUS_ITEM(task),
-				_("Unable to save \"%s\": the article(s) couldn't be downloaded."), readable);
-			debug_exit ("task_save_run");
-			retval = result;
-		}
-	}
-
-	/**
-	***  Save Articles
-	**/
-
-	if (have_bodies && task_save->save_attachments)
+       	task_save = TASK_SAVE(task);
+	if (task_save->save_attachments)
 	{
 		gboolean decode_ok;
+		decode_data dd;
+		status_item_emit_status (STATUS_ITEM(task), _("Saving Attachments"));
 
-		decode_data * dd = g_new0 (decode_data, 1);
-		dd->server = server;
-		dd->acache_key = ACACHE_DEFAULT_KEY;
-		dd->mids = (MessageIdentifier**) task->identifiers->pdata;
-		dd->mid_qty = task->identifiers->len;
-		dd->subject = message_identifier_get_readable_name (dd->mids[0]);
-		dd->item = STATUS_ITEM(task);
-		dd->path = task_save->path_attachments;
-		dd->filename = task_save->filename_attachments;
-		decode_ok = decode_article (dd);
-		g_free (dd);
+		dd.server = task->server;
+		dd.acache_key = ACACHE_DEFAULT_KEY;
+		dd.mids = (MessageIdentifier**) task->identifiers->pdata;
+		dd.mid_qty = task->identifiers->len;
+		dd.subject = message_identifier_get_readable_name (dd.mids[0]);
+		dd.item = STATUS_ITEM(task);
+		dd.path = task_save->path_attachments;
+		dd.filename = task_save->filename_attachments;
+		decode_ok = decode_article (&dd);
 
 		/* if we failed to decode something that we think
 		 * we should've been able to decode, then fail. */
 		if (!decode_ok)
-			retval = TASK_FAIL;
+			retval = TASK_FAIL_HOPELESS;
 	}
 
-	if (have_bodies && task_save->save_bodies)
+	if (task_save->save_bodies)
 	{
 		int i;
 		gboolean bodies_ok = TRUE;
+		status_item_emit_status (STATUS_ITEM(task), _("Saving Articles"));
 
 		for (i=0; i<task->identifiers->len; ++i)
 		{
@@ -497,11 +509,49 @@ task_save_run (Task * task)
 		}
 
 		if (!bodies_ok)
-			retval = TASK_FAIL;
+			retval = TASK_FAIL_HOPELESS;
+	}
+
+	task_state_set (&task->state, retval);
+}
+
+static void
+task_save_run_download (Task * task, PanSocket * sock)
+{
+	int result;
+	MessageIdentifier * mid;
+	TaskSave * task_save = TASK_SAVE(task);
+	debug_enter ("task_save_run");
+
+	mid = MESSAGE_IDENTIFIER (g_queue_pop_head (task_save->download_mids));
+
+	/* let the queue know about any more parts left to downloads */
+	if (!g_queue_is_empty (task_save->download_mids)) {
+		task_state_set_need_socket (&task->state, task->server, task_save_run_download);
+		queue_wakeup ();
+	}
+
+	/* try to download the part... */
+	result = nntp_article_download (STATUS_ITEM(task), sock, mid, &task->hint_abort, NNTP_VERBOSE_NEXT_STEP);
+	switch (result)
+	{
+		case TASK_SUCCESS:
+			g_object_unref (mid);
+			if (!--task_save->download_mids_qty)
+				task_state_set_need_work (&task->state, task_save_run_decode);
+			break;
+
+		case TASK_FAIL_HOPELESS:
+			task_state_set (&task->state, TASK_FAIL_HOPELESS);
+			break;
+
+		default:
+			g_queue_push_head (task_save->download_mids, mid);
+			task_state_set_need_socket (&TASK(task)->state, task->server, task_save_run_download);
+			break;
 	}
 
 	debug_exit ("task_save_run");
-	return task_save->runval = retval;
 }
 
 
