@@ -108,6 +108,8 @@ write_identifier (GString * appendme, int depth, const MessageIdentifier * mid)
 	write_pcdata (appendme, depth+1, "readable_name", mid->readable_name);
 	newline_depth (appendme, depth+1);
 	g_string_append_printf (appendme, "<lines>%lu</lines>", mid->line_qty);
+	newline_depth (appendme, depth+1);
+	g_string_append_printf (appendme, "<bytes>%lu</bytes>", mid->byte_qty);
 
 	for (i=0; i<mid->message_sources->len; ++i)
 	{
@@ -431,6 +433,12 @@ parse_message_identifier (xmlDoc * doc, xmlNodePtr node)
 		g_free (pch);
 	}
 
+	pch = get_child_node_value (doc, node, "bytes");
+	if (pch != NULL) {
+		mid->byte_qty = strtoul (pch, NULL, 10);
+		g_free (pch);
+	}
+
 	/* add the sources */
 	for (tmp=node->xmlChildrenNode; tmp!=NULL; tmp=tmp->next) {
 		if ((!xmlStrcmp (tmp->name, (const xmlChar*)"source"))) {
