@@ -60,6 +60,7 @@ static GtkWidget * scrolled_window = NULL;
 static GtkTextMark * _begin_mark = NULL;
 
 GdkColor text_quoted_color[3];
+GdkColor signature_color;
 GdkColor text_url_color;
 PanCallback * current_article_changed = NULL;
 
@@ -69,6 +70,7 @@ PanCallback * current_article_changed = NULL;
 *****
 ****/
 
+
 /**
  * Returns the quote tag ("quote_0", "quote_1", etc.) appropriate for the line.
  * The right tag is calculated by adding up the number of quote characters
@@ -116,7 +118,6 @@ get_quote_tag (const char * utf8_line, int utf8_byte_len)
 
 	return retval;
 }
-
 /**
  * Convenience function for clearing the specified GtkTextBuffer.
  */
@@ -176,6 +177,7 @@ append_text_buffer_nolock (GtkTextBuffer * text_buffer,
 	GtkTextIter start;
 	GtkTextIter end;
 	GtkTextMark * mark;
+	gboolean is_sig = FALSE;
 	debug_enter ("append_text_buffer_nolock");
 
 	/* sanity checks */
@@ -203,7 +205,19 @@ append_text_buffer_nolock (GtkTextBuffer * text_buffer,
 	while (get_next_token_run (pch, '\n', &pch, &line, &line_len)) {
 		if (!line_len || (line_len==1 && *line=='\n'))
 			continue;
+		
+		if (!is_sig)
+		{
+			int is = pan_is_signature_delimitor (line, line_len);
+			/*support both standard and non standard sigs when highlighting*/
+			is_sig = (is==SIG_STANDARD)||(is==SIG_NON_STANDARD);
+		}
 		quote_tag = get_quote_tag (line, line_len);
+		
+		if (strcmp (quote_tag, "quote_0"))
+			is_sig = FALSE;
+		
+		quote_tag = is_sig?"signature":quote_tag;
 		if (last_quote_tag!=NULL && strcmp (quote_tag, last_quote_tag)) {
 			mark_end = mark_start;
 			gtk_text_iter_forward_chars (&mark_end, g_utf8_strlen(last_quote_begin,line-1-last_quote_begin));
@@ -335,7 +349,7 @@ text_read_next (gboolean more)
 		articlelist_read_prev ();
 }
 
-void
+static void
 text_read_more_impl (gboolean more)
 {
 	GMimeMessage * message = get_current_message ();
@@ -893,7 +907,15 @@ get_url_from_location (GtkWidget * w, int x, int y)
 	if (url_tag == NULL) { 
 		GtkTextTagTable * tag_table = gtk_text_buffer_get_tag_table (text_buffer);
 		url_tag = gtk_text_tag_table_lookup (tag_table, "url");
+		if (url_tag == NULL)
+		{
+			g_assert (url_tag != NULL );
+			return NULL;
+		}
 	}
+	
+	/* ASSERTION FAILED */
+	g_assert( GTK_IS_TEXT_TAG(url_tag));
 	clicked_on_url = gtk_text_iter_has_tag (&pos, url_tag);
 
 	if (clicked_on_url)
@@ -1009,13 +1031,155 @@ static char welcome[] =
 "in Help|About|License. \n"
 };
 
+/*
+ * The following code was "stolen" from the gtk-devel archives
+ */
+static void 
+gtk_text_tag_copy_values (GtkTextTag *dest, GtkTextTag *src)
+{
+	g_return_if_fail (dest);
+	g_return_if_fail (src);
+	g_return_if_fail (GTK_IS_TEXT_TAG (dest));
+	g_return_if_fail (GTK_IS_TEXT_TAG (src));
+
+	gtk_text_attributes_copy_values (src->values, dest->values);
+			      
+#define _COPY_FLAG(flag) dest->flag = src->flag
+	_COPY_FLAG (bg_color_set);
+	_COPY_FLAG (bg_color_set);
+	_COPY_FLAG (bg_stipple_set);
+	_COPY_FLAG (fg_color_set);
+#if 0
+  	_COPY_FLAG (family_set);
+   	_COPY_FLAG (style_set);
+   	_COPY_FLAG (variant_set);
+ 	_COPY_FLAG (weight_set);
+ 	_COPY_FLAG (stretch_set);
+ 	_COPY_FLAG (size_set);
+#endif
+	_COPY_FLAG (fg_stipple_set);
+	_COPY_FLAG (justification_set);
+	_COPY_FLAG (left_margin_set);
+	_COPY_FLAG (indent_set);
+	_COPY_FLAG (rise_set);
+	_COPY_FLAG (strikethrough_set);
+	_COPY_FLAG (right_margin_set);
+	_COPY_FLAG (pixels_above_lines_set);
+	_COPY_FLAG (pixels_below_lines_set);
+	_COPY_FLAG (pixels_inside_wrap_set);
+	_COPY_FLAG (tabs_set);
+	_COPY_FLAG (underline_set);
+	_COPY_FLAG (wrap_mode_set);
+	_COPY_FLAG (bg_full_height_set);
+	_COPY_FLAG (invisible_set);
+	_COPY_FLAG (editable_set);
+	_COPY_FLAG (language_set);
+#undef _COPY_FLAG
+}
+
+
+#if 0
+/**
+ ** gtk_text_tag_copy: -duplicate a tag
+ ** @tag: the #GtkTextTag to duplicate
+ ** 
+ ** Create a new #GtkTextTag with same values as @tag. The returned
+ ** #GtkTextTag doesn't belong to any $GtkTextTagTable.
+ ** 
+ ** Return value: the newly created #GtkTextTag
+ ***/
+static GtkTextTag*
+gtk_text_tag_copy (GtkTextTag *tag)
+{
+	GtkTextTag *ntag;
+
+	g_return_val_if_fail (tag, NULL);
+	g_return_val_if_fail (GTK_IS_TEXT_TAG (tag), NULL);
+
+	ntag = gtk_text_tag_new (tag->name);
+	gtk_text_tag_copy_values (ntag, tag);
+	return ntag;
+}
+#endif
+
+
+/**
+ ** gtk_text_tag_table_install:
+ ** @table: a #GtkTextTagTable
+ ** @tag: a #GtkTextTag
+ ** 
+ ** Add @tag to the tag table @table or, if a tag with the same name
+ ** already exists in @table, update the existing tag in the table with
+ ** the values in @tag. If the tag is anonymous, it is simply added to
+ ** the table.
+ ***/
+static void
+gtk_text_tag_table_install (GtkTextTagTable *table, GtkTextTag *tag)
+{
+	GtkTextTag *existing_tag;
+	g_return_if_fail (table);
+	g_return_if_fail (GTK_IS_TEXT_TAG_TABLE (table));
+	g_return_if_fail (tag);
+	g_return_if_fail (GTK_IS_TEXT_TAG (tag));
+	    
+	if (!tag->name)
+		gtk_text_tag_table_add(table, tag);
+	else {
+		existing_tag = gtk_text_tag_table_lookup(table, tag->name);
+		if (existing_tag) {
+			gtk_text_tag_copy_values(existing_tag, tag);
+			g_object_unref (G_OBJECT(tag));
+		}
+		else
+			gtk_text_tag_table_add(table, tag);
+	}
+}
+
+/* setup the buffer tags */
+void
+text_set_text_buffer_tags (GtkTextBuffer * buffer)
+{
+	GtkTextTag * tag;
+	GtkTextTagTable * table = gtk_text_buffer_get_tag_table (buffer);
+	
+	tag = gtk_text_tag_new ("center");
+	g_object_set (tag, "justification", GTK_JUSTIFY_CENTER, NULL);
+	gtk_text_tag_table_install (table, tag);
+	
+	tag = gtk_text_tag_new ("url");
+	g_object_set (tag, "underline", PANGO_UNDERLINE_SINGLE, "foreground_gdk", &text_url_color, NULL);
+	gtk_text_tag_table_install (table, tag);
+	
+	tag = gtk_text_tag_new ("quote_0");
+	g_object_set (tag, NULL);
+	gtk_text_tag_table_install (table, tag);
+	
+	tag = gtk_text_tag_new ("quote_1");
+	g_object_set (tag, "foreground_gdk", &text_quoted_color[0], NULL);
+	gtk_text_tag_table_install (table, tag);
+	
+	tag = gtk_text_tag_new ("quote_2");
+	g_object_set (tag, "foreground_gdk", &text_quoted_color[1], NULL);
+	gtk_text_tag_table_install (table, tag);
+
+	tag = gtk_text_tag_new ("quote_3");
+	g_object_set (tag, "foreground_gdk", &text_quoted_color[2], NULL);
+	gtk_text_tag_table_install (table, tag);
+
+	tag = gtk_text_tag_new ("signature");
+	g_object_set (tag, "foreground_gdk", &signature_color, NULL);
+	gtk_text_tag_table_install (table, tag);
+	
+}
+
+	
 GtkWidget *
 text_create (void)
 {
 	GtkWidget * text_view;
-
+	
 	/* create the text view */
-        text_view = gtk_text_view_new ();
+	text_view = gtk_text_view_new ();
 	gtk_widget_add_events (text_view, GDK_POINTER_MOTION_MASK|GDK_POINTER_MOTION_HINT_MASK);
 
 	g_signal_connect (text_view, "motion_notify_event",
@@ -1030,15 +1194,7 @@ text_create (void)
 
 	/* set up the buffer tags */
 	_text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(text_view));
-	gtk_text_buffer_create_tag (_text_buffer, "center",
-	                            "justification", GTK_JUSTIFY_CENTER,
-	                            NULL);
-	/* add the new tags */
-	gtk_text_buffer_create_tag (_text_buffer, "url",
-	                            "underline", PANGO_UNDERLINE_SINGLE,
-	                            "foreground_gdk", &text_url_color,
-				    NULL);
-
+	text_set_text_buffer_tags (_text_buffer);
 	/* set a beginning mark that we can always scroll to */
 	if (1) {
 		GtkTextIter start;
@@ -1046,12 +1202,6 @@ text_create (void)
 		_begin_mark = gtk_text_buffer_create_mark  (_text_buffer, "start", &start, TRUE);
 	}
 
-	/* set the quote colors */
-	gtk_text_buffer_create_tag (_text_buffer, "quote_0", NULL);
-	gtk_text_buffer_create_tag (_text_buffer, "quote_1", "foreground_gdk", &text_quoted_color[0], NULL);
-	gtk_text_buffer_create_tag (_text_buffer, "quote_2", "foreground_gdk", &text_quoted_color[1], NULL);
-	gtk_text_buffer_create_tag (_text_buffer, "quote_3", "foreground_gdk", &text_quoted_color[2], NULL);
-	/* FIXME need some way to refresh these tags when user changes text color via prefs */
 
 	current_article_changed = pan_callback_new ();
 
@@ -1118,11 +1268,10 @@ text_get_message_to_reply_to (void)
 	/* no selection, so user is replying to whole message sans signature */
 	if (!has_selection && body!=NULL)
 	{
-		gchar * pch = pan_strstr (body, "\n-- \n");
-		if (pch != NULL)
-			pch[1] = '\0';
+		pan_remove_signature (body);
 	}
-
+	
+	
 	debug_exit ("text_get_message_to_reply_to");
 	return body;
 }
