@@ -86,12 +86,13 @@ extern GdkColor text_bg_color;
 #endif
 extern GdkColor text_url_color;
 extern GdkColor text_quoted_color[3];
+extern GdkColor signature_color;
 
 
 /**
 ***
 **/
-
+void         text_set_text_buffer_tags        (GtkTextBuffer * buffer);
 GtkWidget*   text_create                     (void);
 void         text_read_more                  (void);
 void         text_read_less                  (void);
