@@ -3,6 +3,7 @@
 #include <string.h>
 
 #include <glib.h>
+#include <gmime/gmime.h>
 
 #include <pan/base/article.h>
 #include <pan/base/base-prefs.h>
@@ -11,20 +12,21 @@
 #include <pan/base/pan-glib-extensions.h>
 #include <pan/base/server.h>
 
+
 static void
 pan_init (void)
 {
-	gchar * base;
-	gchar * data_dir;
-	gchar * download_dir;
+	char * base;
+	char * download_dir;
+
+        g_mime_init (0);
 
 	base = getenv ("srcdir");
 	base = g_strdup_printf ("%s/", base!=NULL ? base : getenv("PWD"));
-	data_dir = g_strdup_printf ("%s/data/", base);
 	download_dir = g_strdup_printf ("%s/data/save/", base);
-	base_prefs_init (data_dir, download_dir, ">", 1000, FALSE, FALSE);
-	g_free (data_dir);
+	base_prefs_init (download_dir, ">", 1000, FALSE, FALSE);
 	g_free (download_dir);
+	g_free (base);
 }
 
 
@@ -51,7 +53,6 @@ main (void)
 	++test;
 	a1 = article_new (g);
 	if (a1==NULL) return test;
-	if (a1->crosspost_qty != 0) return test;
 	if (a1->part != 0) return test;
 	if (a1->parts != 0) return test;
 	if (a1->linecount != 0) return test;
@@ -98,27 +99,30 @@ main (void)
 	if (pan_strcmp(buf, "\"joe\" <joe@foo.com>")) return test;
 	article_get_short_author_str (a, buf, sizeof(buf));
 	if (pan_strcmp(buf, "joe")) return test;
+	g_message ("PASS article_set_author_from_header 1");
 
 	article_set_author_from_header (a, "joe@foo.com (Joe Bob)");
 	article_get_author_str (a, buf, sizeof(buf));
 	if (pan_strcmp(buf, "\"Joe Bob\" <joe@foo.com>")) return test;
 	article_get_short_author_str (a, buf, sizeof(buf));
 	if (pan_strcmp(buf, "Joe Bob")) return test;
+	g_message ("PASS article_set_author_from_header 2");
 
 	article_set_author_from_header (a, "Joe Bob <joe@foo.com>");
 	article_get_author_str (a, buf, sizeof(buf));
 	if (pan_strcmp(buf, "\"Joe Bob\" <joe@foo.com>")) return test;
 	article_get_short_author_str (a, buf, sizeof(buf));
 	if (pan_strcmp(buf, "Joe Bob")) return test;
+	g_message ("PASS article_set_author_from_header 3");
 
 	article_set_author_from_header (a, "Joe Bob");
 	article_get_author_str (a, buf, sizeof(buf));
-	if (pan_strcmp(buf, "\"Joe Bob\" <unknown@spammesenseless.net>")) return test;
+	if (pan_strcmp(buf, "\"Joe Bob\" <unknown@spammesenseless.com>")) return test;
 	article_get_short_author_str (a, buf, sizeof(buf));
 	if (pan_strcmp(buf, "Joe Bob")) return test;
-	g_message ("PASS article_set_author_from_header 1");
-
+	g_message ("PASS article_set_author_from_header 4");
 
+#if 0
 	/* encoded authors */
 	++test;
 	article_set_author_from_header (a1,
@@ -143,6 +147,7 @@ main (void)
 	article_get_short_author_str (a, buf, sizeof(buf));
 	if (pan_strcmp (buf, "M. Hlle")) return test;
 	g_message ("PASS encoded author header test");
+#endif
 
 	/* success */
 	g_message ("All article tests passed");
