@@ -83,6 +83,7 @@ decode_from_message_ids (const char ** message_ids, int parts)
 		mids[i] = message_identifier_new (message_ids[i]);
 	
 	dd.server = server;
+	dd.acache_key = ACACHE_DEFAULT_KEY;
 	dd.subject = message_ids[0];
 	dd.mids = mids;
 	dd.mid_qty = parts;
@@ -205,8 +206,8 @@ main (void)
 	message_ids[parts++] = "<collision>";
 	decode_from_message_ids (message_ids, parts);
 	check_md5 ("collision",   "da32d55e3e524200b59d064384449db2");
-	check_md5 ("collision_2", "9b6f6037c580d3cc8bdf3da972ea39d9");
-	check_md5 ("collision_3", "25246baff3f46d51e18d6bbb5398560e");
+	check_md5 ("collision_copy_2", "9b6f6037c580d3cc8bdf3da972ea39d9");
+	check_md5 ("collision_copy_3", "25246baff3f46d51e18d6bbb5398560e");
 	g_message ("PASS: filenamename collision avoided");
 
 	/**
