@@ -42,25 +42,6 @@ int main (void)
 		g_message ("PASS pan_strcmp");
 	}
 
-	/* string-ends-with */
-	++num;
-	if (1)
-	{
-		if (string_ends_with("abcdefg", "cow")) return num;
-		if (!string_ends_with("abcdefg", "abcdefg")) return num;
-		if (string_ends_with("abcdefg", "zabcdefg")) return num;
-		if (!string_ends_with("abcdefg", "bcdefg")) return num;
-		if (!string_ends_with("abcdefg", "cdefg")) return num;
-		if (!string_ends_with("abcdefg", "defg")) return num;
-		if (!string_ends_with("abcdefg", "efg")) return num;
-		if (!string_ends_with("abcdefg", "fg")) return num;
-		if (!string_ends_with("abcdefg", "g")) return num;
-		if (!string_ends_with("abcdefg", "")) return num;
-		if (string_ends_with("abcdefg", NULL)) return num;
-		if (string_ends_with(NULL, "fg")) return num;
-		g_message ("PASS string_ends_with");
-	}
-
 	/* replace-gstr */
 	++num;
 	if (1)
@@ -116,13 +97,19 @@ int main (void)
 	if (1)
 	{
 		GPtrArray * arr = g_ptr_array_new ();
-		gchar * a = "a";
-		gchar * b = "b";
-		gchar * c = "c";
-		gchar * foo[] = {a, b, c};
+		char * a = "a";
+		char * b = "b";
+		char * c = "c";
+		char * foo[3];
+	       
+		foo[0] = a;
+		foo[1] = b;
+		foo[2] = c;
+
 		g_ptr_array_add (arr, a);
 		g_ptr_array_add (arr, b);
 		pan_g_ptr_array_append (arr, (gpointer*)foo, 3);
+
 		if (arr->len != 5) return num;
 		if (g_ptr_array_index(arr,0) != a) return num;
 		if (g_ptr_array_index(arr,1) != b) return num;
