@@ -181,6 +181,26 @@ static ReferencesCheck references [] =
 		"<a@b.uk> <d@f.uk> <h@i.uk> <k@l.uk> <n@o.uk> <q@r.uk>",
 		"<a@b.uk> <q@r.uk>",
 	},
+	/* make sure that twisted domains like [10.0.0.4] don't get stripped.
+	   see comments on pan/base/gnksa.c gnksa_check_message_id() for details. */
+	{       
+		998,
+
+		"<B8CE15E0.2DBE%frederic.platzer@wanadoo.fr> "
+		"<1f9yc83.l59f37ehygn4N%florian@****nachon.net> "
+		"<1f9yzfg.1dxhomt17221j4N%mannucci@wild-works.net> "
+		"<1fa2kwz.14tkecl3qg8uaN%moi@mapetitentreprise.com> "
+		"<1fa7mt7.1t7eiqu1scmm0iN@[10.0.0.4]> "
+		"<enlevezca.michel.depeige-E0EA3B.15534806042002@news.wanadoo.fr>",
+
+		"<B8CE15E0.2DBE%frederic.platzer@wanadoo.fr> "
+		"<1f9yc83.l59f37ehygn4N%florian@****nachon.net> "
+		"<1f9yzfg.1dxhomt17221j4N%mannucci@wild-works.net> "
+		"<1fa2kwz.14tkecl3qg8uaN%moi@mapetitentreprise.com> "
+		"<1fa7mt7.1t7eiqu1scmm0iN@[10.0.0.4]> "
+		"<enlevezca.michel.depeige-E0EA3B.15534806042002@news.wanadoo.fr>"
+	}
+
 };
 
 static AddressCheck addresses [] =
