@@ -193,8 +193,6 @@ int main (void)
 	if (goodness!=OKAY) return test;
 	g_message ("PASS Adrian's Fake Followup");
 
-
-
 	/* body too wide */
 	++test;
 	goodness = OKAY;
@@ -259,6 +257,43 @@ int main (void)
 	if (goodness!=WARN) return test;
 	if (pan_strcmp((gchar*)g_ptr_array_index(errors,0), "WARNING: Unknown group: \"unknown.group\".")) return test;
 	g_message ("PASS unknown followup-to group");
+	g_mime_object_remove_header (GMIME_OBJECT(msg), HEADER_FOLLOWUP_TO);
+
+	/* top posting */
+	++test;
+	goodness = OKAY;
+	g_ptr_array_set_size (errors, 0);
+	g_mime_message_set_header (msg, HEADER_REFERENCES, "<asdf@foo.com>");
+	pch = "How Fascinating!\n"
+	      "\n"
+	      "> Blah blah blah.\n";
+	g_mime_part_set_content (part, pch, strlen(pch));
+	message_check (msg, s, errors, &goodness);
+	if (errors->len!=1) return test;
+	if (goodness!=WARN) return test;
+	if (pan_strcmp((char*)g_ptr_array_index(errors,0), "WARNING: Reply seems to be top-posted.")) return test;
+	g_message ("PASS top-posting warning");
+	g_mime_object_remove_header (GMIME_OBJECT(msg), HEADER_REFERENCES);
+
+	/* top posting */
+	++test;
+	goodness = OKAY;
+	g_ptr_array_set_size (errors, 0);
+	g_mime_message_set_header (msg, HEADER_REFERENCES, "<asdf@foo.com>");
+	pch = "How Fascinating!\n"
+	      "\n"
+	      "> Blah blah blah.\n"
+	      "\n"
+	      "-- \n"
+	      "Pan shouldn't mistake this signature for\n"
+	      "original content in the top-posting check.\n";
+	g_mime_part_set_content (part, pch, strlen(pch));
+	message_check (msg, s, errors, &goodness);
+	if (errors->len!=1) return test;
+	if (goodness!=WARN) return test;
+	if (pan_strcmp((char*)g_ptr_array_index(errors,0), "WARNING: Reply seems to be top-posted.")) return test;
+	g_message ("PASS top-posting warning with signature");
+	g_mime_object_remove_header (GMIME_OBJECT(msg), HEADER_REFERENCES);
 
 	/* success */
 	g_message ("Passed all message-check tests");
