@@ -4,23 +4,28 @@
 #include <string.h>
 
 #include <glib.h>
+#include <pan/base/base-prefs.h>
 #include <pan/base/pan-glib-extensions.h>
 #include <pan/base/util-wrap.h>
 
 
 int main (void)
 {
-	gint num = 0;
-	gint wrap_column;
-	gchar * in;
-	gchar * out;
-	const gchar * expected_out;
+	int num = 0;
+	int wrap_column;
+	char * in;
+	char * out;
+	const char * expected_out;
+
+	/* init pan */
+	g_thread_init (NULL);
+	base_prefs_init (g_get_tmp_dir(), ">", 100, FALSE, FALSE);
 
 	/* blank lines between quotes */
 	++num;
 	wrap_column = 50;
 	in = "> a\n\n> b";
-	out = fill_body (in, wrap_column);
+	out = pan_text_fill (in, wrap_column);
 	expected_out = "> a\n\n> b";
 	if (strcmp(out,expected_out)) return num;
 	replace_gstr (&out, NULL);
@@ -30,7 +35,7 @@ int main (void)
 	++num;
 	wrap_column = 50;
 	in = "> a\n>\n> b";
-	out = fill_body (in, wrap_column);
+	out = pan_text_fill (in, wrap_column);
 	expected_out = "> a\n>\n> b";
 	if (strcmp(out,expected_out)) return num;
 	replace_gstr (&out, NULL);
@@ -40,7 +45,7 @@ int main (void)
 	++num;
 	wrap_column = 50;
 	in = "> a\n> b\n> c";
-	out = fill_body (in, wrap_column);
+	out = pan_text_fill (in, wrap_column);
 	expected_out = "> a\n> b\n> c";
 	if (strcmp(out,expected_out)) return num;
 	replace_gstr (&out, NULL);
@@ -106,7 +111,7 @@ int main (void)
 "furniture.... Software crawls under windows\" :^)\n"
 "\n"
 "Jan Eric";
-	out = fill_body (in, wrap_column);
+	out = pan_text_fill (in, wrap_column);
 	if (strcmp(out,expected_out)) return num;
 	replace_gstr (&out, NULL);
 	g_message ("PASS realworld wrap test 1");
@@ -178,7 +183,7 @@ int main (void)
 "so make sure you get the\n"
 "latest version you can run\n"
 "with your distro.";
-	out = fill_body (in, wrap_column);
+	out = pan_text_fill (in, wrap_column);
 	if (strcmp(out,expected_out)) return num;
 	replace_gstr (&out, NULL);
 	g_message ("PASS realworld wrap test 2");
@@ -188,14 +193,14 @@ int main (void)
 	++num;
 	in = g_strdup ("Rot-13 started with rn, trn and similar newsreaders back in the mid-1980's.  It was common practice for a while for offending messages, and messages with some hint or disclosure (such as the answer to a question or puzzle posed in the message, or for covering spoilers to TV or movie episodes).");
 	out = g_strdup (in);
-	rot13_inplace (out);
+	pan_text_rot13_inplace (out);
 	expected_out = "Ebg-13 fgnegrq jvgu ea, gea naq fvzvyne arjfernqref onpx va gur zvq-1980'f.  Vg jnf pbzzba cenpgvpr sbe n juvyr sbe bssraqvat zrffntrf, naq zrffntrf jvgu fbzr uvag be qvfpybfher (fhpu nf gur nafjre gb n dhrfgvba be chmmyr cbfrq va gur zrffntr, be sbe pbirevat fcbvyref gb GI be zbivr rcvfbqrf).";
 	if (strcmp(out,expected_out)) return num;
 	g_message ("PASS rot13");
 
 	/* rot13 2 */
 	++num;
-	rot13_inplace (out);
+	pan_text_rot13_inplace (out);
 	if (strcmp(in,out)) return num;
 	replace_gstr (&out, NULL);
 	g_message ("PASS rot13 twice for double security");
@@ -203,7 +208,7 @@ int main (void)
 	/* rot13 3 */
 	++num;
 	in = g_strdup ("here is a line with a ,, but the line should not be truncated.");
-	rot13_inplace (in);
+	pan_text_rot13_inplace (in);
 	expected_out = "urer vf n yvar jvgu n ,, ohg gur yvar fubhyq abg or gehapngrq.";
 	if (strcmp (in, expected_out)) return num;
 	g_message ("PASS rot13 with , , or  characters");
@@ -236,7 +241,7 @@ int main (void)
 "the pan website instead.\n"
 "\n"
 "Jan Eric";
-	out = mute_quoted_text_in_body (in);
+	out = pan_text_mute_quoted (in);
 	if (strcmp(out,expected_out)) return num;
 	replace_gstr (&out, NULL);
 	g_message ("PASS mute quoted text realworld 1");
@@ -275,7 +280,7 @@ int main (void)
 "\n"
 "Pan has been going through a lot of modifications recently so make sure\n"
 "you get the latest version you can run with your distro.";
-	out = mute_quoted_text_in_body (in);
+	out = pan_text_mute_quoted (in);
 	if (strcmp(out,expected_out)) return num;
 	replace_gstr (&out, NULL);
 	g_message ("PASS mute quoted text realworld 2");
@@ -283,7 +288,7 @@ int main (void)
 	/* mute quoted text */
 	++num;
 	in = "> This is a bunch\n> of quoted text\n> which should be trimmed\n\nNot quoted.";
-	out = mute_quoted_text_in_body (in);
+	out = pan_text_mute_quoted (in);
 	expected_out = "> [quoted text muted]\n\nNot quoted.";
 	if (strcmp(out,expected_out)) return num;
 	replace_gstr (&out, NULL);
@@ -292,7 +297,7 @@ int main (void)
 	/* mute quoted text */
 	++num;
 	in = "This is a bunch\nof nonquoted text\nwhich should be left alone\n\nNot quoted.";
-	out = mute_quoted_text_in_body (in);
+	out = pan_text_mute_quoted (in);
 	expected_out = in;
 	if (strcmp(out,expected_out)) return num;
 	replace_gstr (&out, NULL);
